@@ -59,7 +59,7 @@ private slots:
 signals:
     //void actionQSODoubleClicked(const int _qsoid);
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
-    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+    void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
     //void recalculateAwardsSignal();
     void requireCurrentLogSignal();
     void requireCurrentYearSignal();
