@@ -31,7 +31,7 @@ StatsQSOsPerBandBarChartWidget::StatsQSOsPerBandBarChartWidget(){}
 
 StatsQSOsPerBandBarChartWidget::StatsQSOsPerBandBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
-      //qDebug() << "StatsQSOsPerBandBarChartWidget::StatsQSOsPerBandBarChartWidget" << endl;
+      //qDebug() << "StatsQSOsPerBandBarChartWidget::StatsQSOsPerBandBarChartWidget" << QT_ENDL;
 
     dataProxy = dp;
     chart = new QChart();
@@ -65,8 +65,8 @@ void StatsQSOsPerBandBarChartWidget::prepareChart(const int _log)
 
     int numberPerX = 0;
     chart->removeAllSeries();
-    categoriesTitle = QString();
-    categoriesElem = QString();
+    //categoriesTitle = QString();
+    //categoriesElem = QString();
     categories.clear();
     axis->clear();
     series->clear();
@@ -77,7 +77,7 @@ void StatsQSOsPerBandBarChartWidget::prepareChart(const int _log)
     QProgressDialog progress(tr("Reading data ... "), tr("Abort reading"), 0, categories.count(), this);
     progress.setWindowModality(Qt::WindowModal);
 
-       //qDebug() << "StatsQSOsPerBandBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << endl;
+       //qDebug() << "StatsQSOsPerBandBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << QT_ENDL;
      categories.append(dataProxy->getBandsInLog(_log));
      categoriesElem = tr("Bands");
      categoriesTitle = tr("QSOs per band distribution");
@@ -86,10 +86,10 @@ void StatsQSOsPerBandBarChartWidget::prepareChart(const int _log)
     for (int i = 0; i < categories.count();i++ )
     {
         numberPerX = dataProxy->getQSOsInBand((categories.at(i)), _log);
-           //qDebug() << categories.at(i) + "-" + QString::number(numberPerX) << endl;
+           //qDebug() << categories.at(i) + "-" + QString::number(numberPerX) << QT_ENDL;
         *set0 << numberPerX;
-        numberPerX = 0;
-           //qDebug() << "StatsQSOsPerBandBarChartWidget::prepareChart QSOs: " << QString::number((categories.at(i)).toInt()) << "/" << QString::number(numberPerX) << endl;
+        //numberPerX = 0;
+           //qDebug() << "StatsQSOsPerBandBarChartWidget::prepareChart QSOs: " << QString::number((categories.at(i)).toInt()) << "/" << QString::number(numberPerX) << QT_ENDL;
         aux = tr("Reading data ...") + "\n" + tr("Bands: ")  + QString::number(i) + "/" + QString::number(categories.count());
         //aux = tr("Reading data ...") + "\n" + tr("Bands: %1/%2").arg(QString::number(i)).arg(QString::number(categories.count()));
         progress.setLabelText(aux);
