@@ -31,7 +31,11 @@ StatsQSOsPerDXCCBarChartWidget::StatsQSOsPerDXCCBarChartWidget(){}
 
 StatsQSOsPerDXCCBarChartWidget::StatsQSOsPerDXCCBarChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
-      //qDebug() << "StatsQSOsPerDXCCBarChartWidget::StatsQSOsPerDXCCBarChartWidget" << endl;
+
+#ifdef QT_DEBUG
+//qDebug() << "StatsQSOsPerDXCCBarChartWidget::StatsQSOsPerDXCCBarChartWidget" << QT_ENDL;
+#else
+#endif
 
     dataProxy = dp;
     chart = new QChart();
@@ -84,7 +88,7 @@ void StatsQSOsPerDXCCBarChartWidget::prepareChart(const int _log)
     entities.clear();
     entities << dataProxy->getEntitiesIds();
 
-       //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << endl;
+       //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << QT_ENDL;
 
      QMap<int, int> map; // key,value = number of QSO, dxcc
      //int qsos = -1;
@@ -94,13 +98,13 @@ void StatsQSOsPerDXCCBarChartWidget::prepareChart(const int _log)
      QList<QList<int>> data;
      data.clear();
     data <<  dataProxy->getTop10QSOPerDXCC(_log);
-    //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart: Length: " << QString::number(data.length()) << endl;
+    //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart: Length: " << QString::number(data.length()) << QT_ENDL;
 
     foreach(QList<int> pair, data)
     {
         map.insert(pair.at(0), pair.at(1));
-        //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart:Pair(0): " << QString::number(pair.at(0)) << endl;
-        //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart:Pair(1): " << QString::number(pair.at(1)) << endl;
+        //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart:Pair(0): " << QString::number(pair.at(0)) << QT_ENDL;
+        //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart:Pair(1): " << QString::number(pair.at(1)) << QT_ENDL;
         categories.append(dataProxy->getEntityMainPrefix(pair.at(0)) + " (" + QString::number(pair.at(1)) + ")");
         set0->append(pair.at(1));
         //*set0 << pair.at(1);
@@ -126,8 +130,8 @@ void StatsQSOsPerDXCCBarChartWidget::prepareChart(const int _log)
                      it.next();
                      if (it.key()< qsos)
                      {
-                            //qDebug() << "Removing: " << QString::number(it.key()) << " / " << QString::number(it.value()) << endl;
-                            //qDebug() << "Replacing by: " << entities.at(i) << " / " << QString::number(qsos) << " - " << dataProxy->getEntityNameFromId((entities.at(i)).toInt()) << endl;
+                            //qDebug() << "Removing: " << QString::number(it.key()) << " / " << QString::number(it.value()) << QT_ENDL;
+                            //qDebug() << "Replacing by: " << entities.at(i) << " / " << QString::number(qsos) << " - " << dataProxy->getEntityNameFromId((entities.at(i)).toInt()) << QT_ENDL;
                          map.remove(it.key());
                          map.insert(qsos, (entities.at(i)).toInt());
                          it.toBack();
@@ -143,7 +147,7 @@ void StatsQSOsPerDXCCBarChartWidget::prepareChart(const int _log)
          {
              i = entities.size();
          }
-         //qDebug() << "End of for iteration" << endl;
+         //qDebug() << "End of for iteration" << QT_ENDL;
      }
     */
     /*
@@ -151,14 +155,14 @@ void StatsQSOsPerDXCCBarChartWidget::prepareChart(const int _log)
      while (it.hasNext()) {
          it.next();
          categories.append(dataProxy->getEntityMainPrefix(it.value()));
-         //qDebug() << "While iteration: " << dataProxy->getEntityMainPrefix(it.value()) << endl;
+         //qDebug() << "While iteration: " << dataProxy->getEntityMainPrefix(it.value()) << QT_ENDL;
 
          numberPerX = it.key();
          *set0 << numberPerX;
          numberPerX = 0;
-            //qDebug() << "End of while iteration" << endl;
+            //qDebug() << "End of while iteration" << QT_ENDL;
      }
-        //qDebug() << "Out of while" << endl;
+        //qDebug() << "Out of while" << QT_ENDL;
     */
      categoriesElem = tr("DXCC");
      categoriesTitle = tr("Top ten DXCC per QSO");
