@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -40,9 +40,9 @@ class StatsQSOsPerMonthBarChartWidget : public StatsGeneralChartWidget
 {
     Q_OBJECT
 public:
-    StatsQSOsPerMonthBarChartWidget(DataProxy_SQLite *dp, QWidget *parent = 0);
+    StatsQSOsPerMonthBarChartWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     StatsQSOsPerMonthBarChartWidget();
-    void prepareChart();
+    void prepareChart(const int _log=-1);
 
 signals:
 
@@ -57,4 +57,4 @@ private:
 
 };
 
-#endif // QSOSPERBANDBARCHARTWIDGET_H
+#endif // QSOSPERMONTHBARCHARTWIDGET_H
