@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -42,7 +42,7 @@ class StatsSentConfirmedPieChartWidget : public StatsGeneralChartWidget
 public:
     StatsSentConfirmedPieChartWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     StatsSentConfirmedPieChartWidget();
-    void prepareChart();
+    void prepareChart(const int _log=-1);
 
 signals:
 
