@@ -30,7 +30,12 @@ StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget(){}
 
 StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget(DataProxy_SQLite *dp, QWidget *parent)
 {
-      //qDebug() << "StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget" << endl;
+
+#ifdef QT_DEBUG
+      //qDebug() << "StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget" << QT_ENDL;
+#else
+#endif
+
 
     dataProxy = dp;
     chart = new QChart();
@@ -58,9 +63,9 @@ void StatsWorkedConfirmedPieChartWidget::prepareChart(const int _log)
     //PieSlice append(string label, real value)
     int qsos = dataProxy->getHowManyQSOInLog(_log);
     int confirmed = dataProxy->getHowManyConfirmedQSLInLog(_log);
-       //qDebug() << "QSOs: " << QString::number(qsos) << endl;
-       //qDebug() << "Confirmed: " << QString::number(confirmed) << endl;
-       //qDebug() << "Worked: " << QString::number(qsos - confirmed) << endl;
+       //qDebug() << "QSOs: " << QString::number(qsos) << QT_ENDL;
+       //qDebug() << "Confirmed: " << QString::number(confirmed) << QT_ENDL;
+       //qDebug() << "Worked: " << QString::number(qsos - confirmed) << QT_ENDL;
 
     series->append(tr("Worked, not confirmed - %1").arg(qsos-confirmed), qsos - confirmed);
     series->append(tr("Confirmed - %2").arg(confirmed), confirmed);
