@@ -29,7 +29,7 @@ email                : jaime@robles.es
 DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
           : QWidget(parent)
 {
-       //qDebug() << "DXClusterWidget::DXClusterWidget" << endl;
+       //qDebug() << "DXClusterWidget::DXClusterWidget" << QT_ENDL;
     dataProxy = dp;
     constrid = 1;
     awards = new Awards(dataProxy, Q_FUNC_INFO);
@@ -38,13 +38,13 @@ DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
 
 
     initClass();
-       //qDebug() << "DXClusterWidget::DXClusterWidget - END" << endl;
+       //qDebug() << "DXClusterWidget::DXClusterWidget - END" << QT_ENDL;
 }
 
 DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent)
           : QWidget(parent)
 {
-      //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect) << endl;
+      //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect) << QT_ENDL;
    constrid = 2;
    util = new Utilities;
    saveSpotsFile = new QFile();
@@ -104,7 +104,7 @@ DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, const QString &clusterToC
     addData();
 
      //TESTADDSPOT();
-       //qDebug() << "DXClusterWidget::DXClusterWidget2 - END"  << endl;
+       //qDebug() << "DXClusterWidget::DXClusterWidget2 - END"  << QT_ENDL;
 
 }
 
@@ -139,7 +139,7 @@ void DXClusterWidget::setMyQRZ(const QString &_qrz)
 
 void DXClusterWidget::addData()
 {
-       //qDebug() << "DXClusterWidget::addData " << endl;
+       //qDebug() << "DXClusterWidget::addData " << QT_ENDL;
 
     /*
                 QTreeWidgetItem *item = new QTreeWidgetItem(searchResultsTreeWidget);
@@ -162,13 +162,13 @@ void DXClusterWidget::addData()
 
 DXClusterWidget::~DXClusterWidget()
 {
-       //qDebug() << "DXClusterWidget::~DXClusterWidget" << endl;
+       //qDebug() << "DXClusterWidget::~DXClusterWidget" << QT_ENDL;
 }
 
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetItem * item )
 {
-      //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: " << item->text() << endl;
+      //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: " << item->text() << QT_ENDL;
 
     QStringList ql;
     ql.clear();
@@ -176,31 +176,31 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetIt
     if (item)
     {
         ql = readItem(item);
-           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Length: " << QString::number(ql.length())  << endl;
+           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Length: " << QString::number(ql.length())  << QT_ENDL;
         if (ql.length()==2)
         {
             ql << "double";
-               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: EMMITED"  << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: EMMITED"  << QT_ENDL;
             emit dxspotclicked(ql);
         }
         else
         {
-               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-1"  << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-1"  << QT_ENDL;
         }
     }
     else
     {
-           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-2 (no item)"  << endl;
+           //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-2 (no item)"  << QT_ENDL;
     }
 
 }
 
 void DXClusterWidget::connectToDXCluster()
 {
-       //qDebug() << "DXClusterWidget::connectToDXCluster" << endl;
+       //qDebug() << "DXClusterWidget::connectToDXCluster" << QT_ENDL;
     if (dxClusterConnected)
     {
-           //qDebug() << "DXClusterWidget::connectToDXCluster: - Already connected!!" << endl;
+           //qDebug() << "DXClusterWidget::connectToDXCluster: - Already connected!!" << QT_ENDL;
         return; // If we are connected we don't want to start another connection
     }
 
@@ -214,14 +214,16 @@ void DXClusterWidget::connectToDXCluster()
     tcpSocket->connectToHost( server, port );
     dxClusterListWidget->setSortingEnabled (false);
 
-    dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Trying to connect to the server") + "\n", awards->getDefaultColor());
+    //dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, tr("Trying to connect to the server") + "\n", awards->getDefaultColor());
+    dxClusterListWidget->addItem (new dxClusterSpotItem(dxClusterListWidget, tr("Trying to connect to the server") + "\n", awards->getDefaultColor()));
+
 
 }
 
 
 void DXClusterWidget::slotClusterDisplayError(QAbstractSocket::SocketError socketError)
 {
-       //qDebug() << "DXClusterWidget:displayError:" << endl;
+       //qDebug() << "DXClusterWidget:displayError:" << QT_ENDL;
      switch (socketError) {
      case QAbstractSocket::RemoteHostClosedError:
          break;
@@ -248,7 +250,7 @@ void DXClusterWidget::slotClusterDisplayError(QAbstractSocket::SocketError socke
 
 bool DXClusterWidget::checkIfNeedsToBePrinted(const QString &_DXEntity, int const _band, const int _mode)
 {
-      //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+      //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< QT_ENDL;
     QStringList qs;
     qs.clear();
     qs << _DXEntity << QString::number(_band) << QString::number(_mode)  << QString::number(currentLog);
@@ -259,63 +261,63 @@ bool DXClusterWidget::checkIfNeedsToBePrinted(const QString &_DXEntity, int cons
 
     if (!showconfirmed)
     {
-          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is confirmed? ("<< QString::number(status)<< ")" << endl;
+          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is confirmed? ("<< QString::number(status)<< ")" << QT_ENDL;
         if (status)
         {
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: It is confirmed: DON'T' print: " << _DXEntity <<"/" << dataProxy->getNameFromBandId(_band) << endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: It is confirmed: DON'T' print: " << _DXEntity <<"/" << dataProxy->getNameFromBandId(_band) << QT_ENDL;
             return false;
         }
     }
 
     if (!showhf)
     {
-          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF?" << endl;
+          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF?" << QT_ENDL;
         if (dataProxy->isHF(_band))
         {
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is it WARC?" << endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is it WARC?" << QT_ENDL;
             if ( (showwarc) && dataProxy->isWARC(_band) )
             {
-                  //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is WARC, print!" << endl;
+                  //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is WARC, print!" << QT_ENDL;
                 return true;
             }
 
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF: DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF: DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< QT_ENDL;
             return false;
         }
         else
         {
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT HF" << endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT HF" << QT_ENDL;
         }
     }
 
     if (!showwarc)
     {
-          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC?" << endl;
+          //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC?" << QT_ENDL;
         if (dataProxy->isWARC(_band))
         {
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< QT_ENDL;
             return false;
         }
         else
         {
-              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT WARC" << endl;
+              //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT WARC" << QT_ENDL;
         }
     }
 
     if (!showvhf)
     {
-           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF?" << endl;
+           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF?" << QT_ENDL;
         if (dataProxy->isVHF(_band))
         {
-               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< QT_ENDL;
             return false;
         }
         else
         {
-               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT VHF " << endl;
+               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT VHF " << QT_ENDL;
         }
     }
-       //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: returns TRUE and will be printed: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+       //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: returns TRUE and will be printed: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< QT_ENDL;
     return true;
 }
 
@@ -334,7 +336,7 @@ void DXClusterWidget::setCurrentLog(const int _log)
 
 void DXClusterWidget::slotClusterDataArrived()
 {
-      //qDebug() << "DXClusterWidget::slotClusterDataArrived" << endl;
+      //qDebug() << "DXClusterWidget::slotClusterDataArrived" << QT_ENDL;
     QStringList qs;
     QString dxClusterString;
     QString dxCall;
@@ -352,17 +354,17 @@ void DXClusterWidget::slotClusterDataArrived()
         dxClusterString = dxClusterString.remove("\a");
         saveSpot(dxClusterString);
 
-        QStringList tokens = dxClusterString.split(" ", QString::SkipEmptyParts);
+        QStringList tokens = dxClusterString.split(" ", QT_SKIP);
         if (tokens.size()<2){
             return;
         }
         // It is a "DX de SP0TTER FREC DXCALL"
         //0 = DX, 1 = de, 2 = spotter, 3 = Freq, 4 = dxcall, 5 = comment
-          //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << "DXCLUSTER->" << dxClusterString << "\nTOKENS: " << tokens << endl;
+          //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << "DXCLUSTER->" << dxClusterString << "\nTOKENS: " << tokens << QT_ENDL;
 
         if ((tokens[0] == "DX") && (tokens[1] == "de"))
         {
-              //qDebug() << "******************** DXClusterWidget::slotClusterDataArrived: DX DE" << endl;
+              //qDebug() << "******************** DXClusterWidget::slotClusterDataArrived: DX DE" << QT_ENDL;
             //isADXSpot = true;
             QString spotter = tokens[2];
             spotter.truncate(spotter.size() - 1);
@@ -379,7 +381,7 @@ void DXClusterWidget::slotClusterDataArrived()
             qs.clear();
             //spotBand = QString::number(world->getBandIdFromFreq(  dxFrequency  ) );
             qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
-               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-2: " << QString::number(dxEntity) << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-2: " << QString::number(dxEntity) << QT_ENDL;
             dxSpotColor = awards->getQRZDXStatusColor(qs);
             if  (showDxMarathon)
             {
@@ -390,19 +392,19 @@ void DXClusterWidget::slotClusterDataArrived()
             }
 
 
-              //qDebug() << "DX de ->" << "Spotter: " << spotter << "Freq: "<< dxFrequency << "DX: " << dxCall << endl;
+              //qDebug() << "DX de ->" << "Spotter: " << spotter << "Freq: "<< dxFrequency << "DX: " << dxCall << QT_ENDL;
 
         }
         else if ((tokens[0] == "To") && (tokens[1] == "ALL"))
         {
-              //qDebug() << "DXClusterWidget::slotClusterDataArrived: TO ALL" << endl;
+              //qDebug() << "DXClusterWidget::slotClusterDataArrived: TO ALL" << QT_ENDL;
             dxSpotColor = awards->getDefaultColor();
         }
         else if ( (dxClusterString.length()>=5) && (world->checkQRZValidFormat(tokens[1])) && (tokens[0]!="login:"))
         { // Freq / DXCall / Date // time
            //_qs << QRZ << Freq in MHz << lognumber;
-             //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5" << endl;
-             //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1] << endl;
+             //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5" << QT_ENDL;
+             //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1] << QT_ENDL;
 
             //isADXSpot = true;
             dxCall = tokens[1];
@@ -412,7 +414,7 @@ void DXClusterWidget::slotClusterDataArrived()
             qs.clear();
             spotBand = QString::number(dataProxy->getBandIdFromFreq(  dxFrequency.toDouble()  ) );
             dxEntity = world->getQRZARRLId(dxCall);
-               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-1: " << QString::number(dxEntity) << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-1: " << QString::number(dxEntity) << QT_ENDL;
             qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
             dxSpotColor = awards->getQRZDXStatusColor(qs);
             if (showDxMarathon)
@@ -427,7 +429,7 @@ void DXClusterWidget::slotClusterDataArrived()
         }
         else
         {
-               //qDebug() << "DXClusterWidget::slotClusterDataArrived: DEFAULT" << endl;
+               //qDebug() << "DXClusterWidget::slotClusterDataArrived: DEFAULT" << QT_ENDL;
             dxSpotColor = awards->getDefaultColor();
         }
 
@@ -436,12 +438,12 @@ void DXClusterWidget::slotClusterDataArrived()
         //qs << dxCall << spotBand << "0";
 
         //dxSpotColor = awards->getQRZDXStatusColor(qs);
-           //qDebug() << "DXClusterWidget::slotClusterDataArrived: Call/dxSpotColor: " << dxCall <<"/"<< dxSpotColor.name() << endl;
+           //qDebug() << "DXClusterWidget::slotClusterDataArrived: Call/dxSpotColor: " << dxCall <<"/"<< dxSpotColor.name() << QT_ENDL;
         //dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, dxClusterString, dxSpotColor);
         //TODO: Change the "-1" by the mode
         if (!checkIfNeedsToBePrinted(QString::number(dxEntity), spotBand.toInt(), -1))
         {
-              //qDebug() << "DXClusterWidget::slotClusterDataArrived - Not to be printed!: " << dxCall << endl;
+              //qDebug() << "DXClusterWidget::slotClusterDataArrived - Not to be printed!: " << dxCall << QT_ENDL;
             return;
         }
 
@@ -483,15 +485,15 @@ void DXClusterWidget::slotClusterDataArrived()
         //dxClusterListWidget->insertItem(0,item);
     }
 
-       //qDebug() << "--------------------- DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
+       //qDebug() << "--------------------- DXClusterWidget::slotClusterDataArrived: " << dxClusterString << QT_ENDL;
 
-      //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
+      //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << dxClusterString << QT_ENDL;
 
 }
 
 void DXClusterWidget::slotClusterSocketConnected()
 {
-       //qDebug() << "DXClusterWidget::slotClusterSocketConnected" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterSocketConnected" << QT_ENDL;
 
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(awards->getDefaultColor()));
@@ -536,7 +538,7 @@ void DXClusterWidget::slotClusterSocketConnected()
 
 void DXClusterWidget::slotClusterSocketConnectionClosed()
 {
-       //qDebug() << "DXClusterWidget::slotClusterSocketConnectionClosed" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterSocketConnectionClosed" << QT_ENDL;
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(awards->getDefaultColor()));
     item->setText(tr("Connection closed by the server"));
@@ -552,7 +554,7 @@ void DXClusterWidget::slotClusterSocketConnectionClosed()
 
 void DXClusterWidget::slotClusterSendToServer()
 {
-       //qDebug() << "DXClusterWidget::slotClusterSendToServer()" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterSendToServer()" << QT_ENDL;
     if (!dxClusterConnected)
     {
 
@@ -562,14 +564,14 @@ void DXClusterWidget::slotClusterSendToServer()
     if (( inputCommand ->text().length() < 1 ) && ( sendButton->text() == tr("Disconnect") ) )
     {
 
-        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Disconnecting" << endl;
+        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Disconnecting" << QT_ENDL;
         QTextStream os(tcpSocket);
         os << "bye\n";
         return;
     }
     else if ( inputCommand ->text().length() < 1 )
     {
-        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Empty" << endl;
+        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Empty" << QT_ENDL;
         return;
     }
 
@@ -582,14 +584,14 @@ void DXClusterWidget::slotClusterSendToServer()
 
 void DXClusterWidget::slotClusterClearLineInput()
 {
-       //qDebug() << "DXClusterWidget::slotClusterClearLineInput" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterClearLineInput" << QT_ENDL;
 
     inputCommand->clear();
 }
 
 void DXClusterWidget::slotClusterInputTextChanged()
 {
-       //qDebug() << "DXClusterWidget::slotClusterInputTextChanged" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterInputTextChanged" << QT_ENDL;
 
     if ( ((inputCommand->text()).length()) <= 0 )
     {
@@ -607,7 +609,7 @@ void DXClusterWidget::slotClusterInputTextChanged()
 
 void DXClusterWidget::setColors (const QString &_newOne, const QString &_needed, const QString &_worked, const QString &_confirmed, const QString &_default)
 {
-       //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default << endl;
+       //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default << QT_ENDL;
     // Just to pass the colors to the awards class
     awards->setColors(_newOne,  _needed, _worked,  _confirmed, _default);
 
@@ -615,7 +617,7 @@ void DXClusterWidget::setColors (const QString &_newOne, const QString &_needed,
 
 void DXClusterWidget::setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _showwarc, bool _showworked, bool _showconfirmed, bool _showann, bool _showwwv, bool _showwcy )
 {
-       //qDebug() << "DXClusterWidget::setDXClusterSpotConfig " << endl;
+       //qDebug() << "DXClusterWidget::setDXClusterSpotConfig " << QT_ENDL;
 
     showhf = _showhf;
     showvhf = _showvhf;
@@ -629,7 +631,7 @@ void DXClusterWidget::setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemSelected()
 {
-       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemSelected " << endl;
+       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemSelected " << QT_ENDL;
     QListWidgetItem * item = dxClusterListWidget->currentItem();
 
     QStringList ql;
@@ -649,7 +651,7 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemSelected()
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemEntered( QListWidgetItem * item )
 {
-       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemEntered" << endl;
+       //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemEntered" << QT_ENDL;
 /*
     This code comes from slotClusterDXClusterWidgetItemDoubleClicked
 */
@@ -684,7 +686,7 @@ bool DXClusterWidget::isConnected()
 
 QStringList DXClusterWidget::readItem(QListWidgetItem * item)
 {
-      //qDebug() << "DXClusterWidget::readItem" << endl;
+      //qDebug() << "DXClusterWidget::readItem" << QT_ENDL;
 
     QStringList fields;
     QString dxClusterString;
@@ -705,7 +707,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
 
             if ( world->getQRZARRLId(fields.at(4))> 0 )
             {
-                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: ARRLid: " << QString::number(world->getQRZARRLId(fields.at(4)))  << endl;
+                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: ARRLid: " << QString::number(world->getQRZARRLId(fields.at(4)))  << QT_ENDL;
                 dxCallsign = (fields.at(4)).toUpper();
                 (fields.at(3)).toFloat(&FirstFrecOK);
                 if (FirstFrecOK)
@@ -727,7 +729,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
             else
             { // The callsign is not from a valid country
               // TODO: if it is from a new entity/prefix it would not work.
-                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Entity not valid"  << endl;
+                   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Entity not valid"  << QT_ENDL;
                 dxCallsign.clear();
                 dxFreq.clear();
                 fields.clear();
@@ -762,7 +764,7 @@ void DXClusterWidget::setDXClusterServer(const QString &clusterToConnect, const
 {
     server = clusterToConnect;
     port = quint16(portToConnect);
-       //qDebug() << "DXClusterWidget::setDXClusterServer: " << server << ":"<< QString::number(port)  << endl;
+       //qDebug() << "DXClusterWidget::setDXClusterServer: " << server << ":"<< QString::number(port)  << QT_ENDL;
 }
 
 void DXClusterWidget::setDXMarathon (const bool _enable)
@@ -800,25 +802,25 @@ bool DXClusterWidget::openFile()
 
 void DXClusterWidget::saveSpot(const QString &_spot)
 {
-      //qDebug() << "DXClusterWidget::saveSpot: " << _spot  << endl;
+      //qDebug() << "DXClusterWidget::saveSpot: " << _spot  << QT_ENDL;
     if (!saveSpots)
     {
-          //qDebug() << "DXClusterWidget::saveSpot: Not saving" << endl;
+          //qDebug() << "DXClusterWidget::saveSpot: Not saving" << QT_ENDL;
         return;
     }
     else
     {
         if (openFile())
         {
-              //qDebug() << "DXClusterWidget::saveSpot: File Open" << endl;
+              //qDebug() << "DXClusterWidget::saveSpot: File Open" << QT_ENDL;
             QTextStream out(saveSpotsFile);
 
-            out << util->getDateTimeSQLiteStringFromDateTime(QDateTime::currentDateTime()) << " - " << _spot  << endl;
+            out << util->getDateTimeSQLiteStringFromDateTime(QDateTime::currentDateTime()) << " - " << _spot  << QT_ENDL;
             saveSpotsFile->close();
         }
         else {
             {
-                  //qDebug() << "DXClusterWidget::saveSpot: File NOT Open" << endl;
+                  //qDebug() << "DXClusterWidget::saveSpot: File NOT Open" << QT_ENDL;
             }
         }
     }
@@ -827,7 +829,7 @@ void DXClusterWidget::saveSpot(const QString &_spot)
 /*
 void DXClusterWidget::TESTADDSPOT()
 {
-       //qDebug() << "DXClusterWidget::TESTADDSPOT "   << endl;
+       //qDebug() << "DXClusterWidget::TESTADDSPOT "   << QT_ENDL;
     ; // Just a test spot
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(dxSpotColor));
@@ -845,7 +847,7 @@ void DXClusterWidget::TESTADDSPOT()
 ** It may be moved to a self .h & .cpp archives                           **
 ****************************************************************************/
 dxClusterSpotItem::dxClusterSpotItem( QListWidget *parent, const QString& spot, const QColor& color ) : QListWidgetItem( parent ){
-       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Constructor" << endl;
+       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Constructor" << QT_ENDL;
     spotColor = color;
     setText(spot);
     // Experimenting with fonts for the cluster
@@ -856,6 +858,6 @@ dxClusterSpotItem::dxClusterSpotItem( QListWidget *parent, const QString& spot,
 
 dxClusterSpotItem::~dxClusterSpotItem()
 {
-       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Destructor" << endl;
+       //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Destructor" << QT_ENDL;
 }
 
