@@ -22,7 +22,7 @@ email                : jaime@robles.es
 *    GNU General Public License for more details.                           *
 *                                                                           *
 *    You should have received a copy of the GNU General Public License      *
-*    along with KLog.  If not, see <http://www.gnu.org/licenses/>.       *
+*    along with KLog.  If not, see <https://www.gnu.org/licenses/>.       *
 *                                                                           *
 *****************************************************************************/
 
@@ -33,7 +33,8 @@ email                : jaime@robles.es
 #include <QObject>
 #include "awards.h"
 #include "world.h"
-#include "dataproxy.h"
+#include "utilities.h"
+#include "dataproxy_sqlite.h"
 
 class QWidget;
 class QTcpSocket;
@@ -43,17 +44,18 @@ class DXClusterWidget : public QWidget
      Q_OBJECT
 
  public:
-    DXClusterWidget(DataProxy *dp, QWidget *parent );
-    DXClusterWidget(DataProxy *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent );
+    DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent );
+    DXClusterWidget(DataProxy_SQLite *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent );
 
-    void setColors (const QString _newOne, const QString _needed, const QString _worked, const QString _confirmed, const QString _default);
+    void setColors (const QString &_newOne, const QString &_needed, const QString &_worked, const QString &_confirmed, const QString &_default);
     void setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _showwarc, bool _showworked, bool _showconfirmed, bool _showann, bool _showwwv, bool _showwcy );
     void setDXClusterServer(const QString &clusterToConnect, const int portToConnect);
     void setCurrentLog(const int _log);
     bool isConnected();
-    void setMyQRZ(const QString _qrz);
+    void setMyQRZ(const QString &_qrz);
     void setDXMarathon (const bool _enable);
-    //void sendSpotToCluster(const QString _dx, const QString _freq);
+    void setSaveSpots (const bool _enable);
+    //void sendSpotToCluster(const QString &_dx, const QString &_freq);
 
 
     ~DXClusterWidget();
@@ -73,7 +75,8 @@ private slots:
     void slotClusterDXClusterWidgetItemSelected();
 
 signals:
-    void dxspotclicked(const QStringList _qs); // DXSpotCall, DX-Freq, doubleClicked
+    void dxspotclicked(const QStringList &_qs); // DXSpotCall, DX-Freq, doubleClicked
+    //void dxspot(const QString &_spot); // The text string to be saved
 
 private:
 
@@ -82,10 +85,12 @@ private:
     void initClass();
     void connectToDXCluster();
     QStringList readItem(QListWidgetItem * item);
-    bool checkIfNeedsToBePrinted(const QString _DXEntity, const int _band, const int _mode);
-
+    bool checkIfNeedsToBePrinted(const QString &_DXEntity, const int _band, const int _mode);
+    void saveSpot (const QString &_spot);
+    bool openFile();
     void addData(); //TO BE DELETED, JUST FOR TESTING PURPOSES
 
+
     QTcpSocket *tcpSocket;
     QListWidget *dxClusterListWidget;
     QLineEdit *inputCommand;
@@ -102,15 +107,20 @@ private:
 
     World *world;
     Awards *awards;
-    DataProxy *dataProxy;
+    DataProxy_SQLite *dataProxy;
+    Utilities *util;
 
     bool showhf, showvhf, showwarc, showworked, showconfirmed, showann,  showwwv, showwcy;
     bool dxClusterShowHF, dxClusterShowVHF, dxClusterShowWARC, dxClusterShowWorked, dxClusterShowConfirmed, dxClusterShowAnn, dxClusterShowWWV, dxClusterShowWCY;
     bool showDxMarathon;
+
     QString myQrz;
     int currentLog;
-
     int constrid; // Just an id for the constructor to check who is being executed at one specific time
+
+    QFile *saveSpotsFile;
+    bool saveSpots; // write/save the spots to a file
+
  };
 
 class dxClusterSpotItem : public QListWidgetItem {
