@@ -35,33 +35,33 @@
 
 eLogClubLog::eLogClubLog()
 {
-     //qDebug()<< "eLogClubLog::eLogClubLog"  << endl;
+     //qDebug()<< "eLogClubLog::eLogClubLog"  << QT_ENDL;
 
-    email = QString();
-    pass = QString();
+    //email = QString();
+    //pass = QString();
     qsos.clear();
     api = "9467beee93377e82a276b0a777d388b5c933d044";
     currentQSO = -1;
     manager = new QNetworkAccessManager(this);
     connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(slotQsoUploadFinished(QNetworkReply*)));
-    stationCallsign = QString();
+    //stationCallsign = QString();
     uploadingFile = false;
     util = new Utilities;
-     //qDebug()<< "eLogClubLog::eLogClubLog - END"  << endl;
+     //qDebug()<< "eLogClubLog::eLogClubLog - END"  << QT_ENDL;
 }
 
 eLogClubLog::~eLogClubLog()
 {
-         //qDebug()<< "eLogClubLog::~eLogClubLog"  << endl;
+         //qDebug()<< "eLogClubLog::~eLogClubLog"  << QT_ENDL;
 }
 
 
  void eLogClubLog::slotQsoUploadFinished(QNetworkReply *data)
 {
-     //qDebug()<< "eLogClubLog::slotQsoUploadFinished"  << endl;
+     //qDebug()<< "eLogClubLog::slotQsoUploadFinished"  << QT_ENDL;
 
     result = data->error();
-     //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = " << QString::number(result) << endl;
+     //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = " << QString::number(result) << QT_ENDL;
 
     const QByteArray sdata = data->readAll();
 
@@ -79,7 +79,7 @@ eLogClubLog::~eLogClubLog()
 
         text = "ClubLog: " + prepareToTranslate(sdata);
          //qDebug()<< sdata;
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - NO ERROR" << endl;
+         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - NO ERROR" << QT_ENDL;
         if (uploadingFile)
         {
             uploadingFile = false;
@@ -92,13 +92,13 @@ eLogClubLog::~eLogClubLog()
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = Host Not found! = " << QString::number(result)  << endl;
+         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = Host Not found! = " << QString::number(result)  << QT_ENDL;
         text = "ClubLog: " + tr("Host not found!");
         //TODO: Mark the previous QSO as not sent to clublog
     }
     else if (result == QNetworkReply::TimeoutError)
     {
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = Time out error! = " << QString::number(result)  << endl;
+         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = Time out error! = " << QString::number(result)  << QT_ENDL;
         text = "ClubLog: " + tr("Timeout error!");
         //TODO: Mark the previous QSO as not sent to clublog
     }
@@ -115,7 +115,7 @@ eLogClubLog::~eLogClubLog()
     }
     else if (result == 202)
     {
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = Password Error! = " << QString::number(result)  << endl;
+         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = Password Error! = " << QString::number(result)  << QT_ENDL;
         text = "ClubLog: " + tr("It seems to be a PASSWORD ERROR; check your password.");
 
         int i = QMessageBox::warning(nullptr, tr("KLog - ClubLog"),
@@ -131,16 +131,16 @@ eLogClubLog::~eLogClubLog()
     else if (result == 203)
     {
         text = "ClubLog: " + tr("QSO dupe or not existing (#%1)... ").arg(result);
-        int i = QMessageBox::warning(nullptr, tr("KLog - ClubLog"),
+        QMessageBox::warning(nullptr, tr("KLog - ClubLog"),
                                        tr("We have received an undefined error from Clublog (%1)").arg(result) + "\n" +
                                           tr("This error may be caused for the QSO being duplicated or, if removing, trying to remove a non existing QSO."),
                                        QMessageBox::Ok);
     }
     else
     {
-         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = UNDEFINED = " << QString::number(result)  << endl;
+         //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = UNDEFINED = " << QString::number(result)  << QT_ENDL;
         text = "ClubLog: " + tr("Undefined error number (#%1)... ").arg(result);
-        int i = QMessageBox::warning(nullptr, tr("KLog - ClubLog"),
+        QMessageBox::warning(nullptr, tr("KLog - ClubLog"),
                                        tr("We have received an undefined error from Clublog (%1)").arg(result) + "\n" +
                                           tr("Please check your config in the setup and contact the KLog development team if you can't fix it. ClubLog uploads will be disabled."),
                                        QMessageBox::Ok);
@@ -148,8 +148,8 @@ eLogClubLog::~eLogClubLog()
         //TODO: Mark the previous QSO as not sent to clublog
     }
 
-     //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = " << QString::number(result) << endl;
-     //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result Text = " << text << endl;
+     //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result = " << QString::number(result) << QT_ENDL;
+     //qDebug()<< "eLogClubLog::slotQsoUploadFinished - Result Text = " << text << QT_ENDL;
     //emit done();
     //emit signalFileUploaded(result, qsos);
     emit showMessage(text);
@@ -158,48 +158,46 @@ eLogClubLog::~eLogClubLog()
 
 void eLogClubLog::slotFileUploadFinished(QNetworkReply *data)
 {
-        //qDebug()<< "eLogClubLog::slotFileUploadFinished"  << endl;
+        //qDebug()<< "eLogClubLog::slotFileUploadFinished"  << QT_ENDL;
 
     result = data->error();
-         //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = " << QString::number(result) << endl;
+         //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = " << QString::number(result) << QT_ENDL;
 
     const QByteArray sdata = data->readAll();
 
-    QString text = QString();
+    QString text;
 
 
     if (result == QNetworkReply::NoError)
     {
 
         text = "ClubLog: " + prepareToTranslate(sdata);
-            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = NoError = " << QString::number(result)  << endl;
+            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = NoError = " << QString::number(result)  << QT_ENDL;
             //qDebug()<< sdata;
-
-
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = Host Not found! = " << QString::number(result)  << endl;
+            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = Host Not found! = " << QString::number(result)  << QT_ENDL;
         text = "ClubLog: " + tr("Host not found!");
     }
     else if (result == QNetworkReply::TimeoutError)
     {
-            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = Time out error! = " << QString::number(result)  << endl;
+            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = Time out error! = " << QString::number(result)  << QT_ENDL;
         text = "ClubLog: " + tr("Timeout error!");
     }
     else
     {
-            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = UNDEFINED = " << QString::number(result)  << endl;
+            //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = UNDEFINED = " << QString::number(result)  << QT_ENDL;
         text = "ClubLog: " + tr("Undefined error...");
     }
 
-         //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = " << QString::number(result) << endl;
+         //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = " << QString::number(result) << QT_ENDL;
     //emit done();
     emit  showMessage(text);
 }
 
 void eLogClubLog::downloadProgress(qint64 received, qint64 total) {
-        //qDebug()<< "eLogClubLog::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << endl;
+        //qDebug()<< "eLogClubLog::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << QT_ENDL;
 
         //qDebug()<< received << total;
     emit actionShowProgres(received, total);
@@ -207,7 +205,7 @@ void eLogClubLog::downloadProgress(qint64 received, qint64 total) {
 
 void eLogClubLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
 {
-        //qDebug()<< "eLogClubLog::slotErrorManagement: " << QString::number(networkError) << endl;
+        //qDebug()<< "eLogClubLog::slotErrorManagement: " << QString::number(networkError) << QT_ENDL;
     result = networkError;
 
     if (result == QNetworkReply::NoError)
@@ -215,11 +213,11 @@ void eLogClubLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-             //qDebug()<< "eLogClubLog::slotErrorManagement: Host not found" << endl;
+             //qDebug()<< "eLogClubLog::slotErrorManagement: Host not found" << QT_ENDL;
     }
     else
     {
-             //qDebug()<< "eLogClubLog::slotErrorManagement: ERROR!" << endl;
+             //qDebug()<< "eLogClubLog::slotErrorManagement: ERROR!" << QT_ENDL;
     }
 
     //actionError(result);
@@ -228,39 +226,39 @@ void eLogClubLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
 
 int eLogClubLog::sendQSO(QStringList _qso)
 {
-     //qDebug() << "eLogClubLog::sendQSO: " << email << "/" << pass << "/" << api  << endl;
-      //qDebug()<< "eLogClubLog::sendQSO:: length = " << QString::number(_qso.length()) << endl;
+     //qDebug() << "eLogClubLog::sendQSO: " << email << "/" << pass << "/" << api  << QT_ENDL;
+      //qDebug()<< "eLogClubLog::sendQSO:: length = " << QString::number(_qso.length()) << QT_ENDL;
     // First Data in the QStringList is the QSO id, not to be sent to clublog but used in the signal actionReturnDownload(const int _i, const int _qsoId);
    for(int i = 0; i<_qso.length(); i++)
     {
-        //qDebug()<< "eLogClubLog::sendQSO = qso-at: "<< QString::number(i) << "- " << _qso.at(i) << endl;
+        //qDebug()<< "eLogClubLog::sendQSO = qso-at: "<< QString::number(i) << "- " << _qso.at(i) << QT_ENDL;
     }
     if (_qso.length()!=18)
     {
-         //qDebug() << "eLogClubLog::sendQSO:: length - END" << endl;
+         //qDebug() << "eLogClubLog::sendQSO:: length - END" << QT_ENDL;
         return -1;
     }
 
     currentQSO = (_qso.at(0)).toInt();
     _qso.removeFirst();
     //_qso.removeFirst();
-    //qDebug()<< "eLogClubLog::sendQSO CALL TO USE (before checking): " << _qso.at(16) << endl;
-    //qDebug()<< "eLogClubLog::sendQSO default StationCallsign): " << stationCallsign << endl;
+    //qDebug()<< "eLogClubLog::sendQSO CALL TO USE (before checking): " << _qso.at(16) << QT_ENDL;
+    //qDebug()<< "eLogClubLog::sendQSO default StationCallsign): " << stationCallsign << QT_ENDL;
 
     QString tempCall = _qso.at(16);
     if (tempCall.length()<1)
     {
         tempCall = stationCallsign;
     }
-    //qDebug()<< "eLogClubLog::sendQSO CALL TO USE: " << tempCall << endl;
+    //qDebug()<< "eLogClubLog::sendQSO CALL TO USE: " << tempCall << QT_ENDL;
     _qso.removeLast();
 
     QString qso = getClubLogAdif(_qso);
-     //qDebug()<< "eLogClubLog::sendQSO: " << qso << endl;
+     //qDebug()<< "eLogClubLog::sendQSO: " << qso << QT_ENDL;
     QUrlQuery params;
     params.addQueryItem("adif",qso);
-    //qDebug() << "eLogClubLog::sendQSO: QSO: " << qso << endl;
-     //qDebug() << "eLogClubLog::sendQSO: END" << endl;
+    //qDebug() << "eLogClubLog::sendQSO: QSO: " << qso << QT_ENDL;
+     //qDebug() << "eLogClubLog::sendQSO: END" << QT_ENDL;
     uploadingFile = false;
     return sendDataParams(tempCall, params, true);
     //return sendData(tempCall, qso);
@@ -269,7 +267,7 @@ int eLogClubLog::sendQSO(QStringList _qso)
 /*
 int eLogClubLog::deleteQSOid(const int _qsoId)
 {
-    //qDebug()<< "eLogClubLog::deleteQSOid: " << QString::number(_qsoId) << endl;
+    //qDebug()<< "eLogClubLog::deleteQSOid: " << QString::number(_qsoId) << QT_ENDL;
    // email, password, callsign, dxcall, datetime, bandid, api
     QString dxcall, datatime, bandid;
     QUrlQuery params;
@@ -280,10 +278,10 @@ int eLogClubLog::deleteQSOid(const int _qsoId)
 
 int eLogClubLog::sendDataParams(const QString &_clublogCall, const QUrlQuery &_params, bool _adding)
 {
-     //qDebug()<< "eLogClubLog::sendDataParams: Call: " << _clublogCall << endl;
-     //qDebug()<< "eLogClubLog::sendDataParams: Params: " << _params.query(QUrl::FullyEncoded).toUtf8() << endl;
-     //qDebug()<< "eLogClubLog::sendDataParams: email = " << email << endl;
-     //qDebug()<< "eLogClubLog::sendDataParams: Pass = " << pass << endl;
+     //qDebug()<< "eLogClubLog::sendDataParams: Call: " << _clublogCall << QT_ENDL;
+     //qDebug()<< "eLogClubLog::sendDataParams: Params: " << _params.query(QUrl::FullyEncoded).toUtf8() << QT_ENDL;
+     //qDebug()<< "eLogClubLog::sendDataParams: email = " << email << QT_ENDL;
+     //qDebug()<< "eLogClubLog::sendDataParams: Pass = " << pass << QT_ENDL;
 
     QUrl serviceUrl;
     if (_adding)
@@ -304,14 +302,14 @@ int eLogClubLog::sendDataParams(const QString &_clublogCall, const QUrlQuery &_p
     if  (_clublogCall.length()>2)
     {
         params.addQueryItem("callsign",_clublogCall);
-          //qDebug()<< "eLogClubLog::sendDataParams - callsign 1: " << _clublogCall << endl;
+          //qDebug()<< "eLogClubLog::sendDataParams - callsign 1: " << _clublogCall << QT_ENDL;
     }
     else
     {
         params.addQueryItem("callsign",stationCallsign);
     }
 
-     //qDebug()<< "eLogClubLog::sendDataParams - query before send/delete: " << params.query(QUrl::FullyEncoded).toUtf8() << endl;
+     //qDebug()<< "eLogClubLog::sendDataParams - query before send/delete: " << params.query(QUrl::FullyEncoded).toUtf8() << QT_ENDL;
     if (_adding)
     {
         params.addQueryItem("api",api);
@@ -339,14 +337,14 @@ int eLogClubLog::sendDataParams(const QString &_clublogCall, const QUrlQuery &_p
 
 
     manager->post(request, postData);
-     //qDebug()<< "eLogClubLog::sendDataParams - END" << endl;
+     //qDebug()<< "eLogClubLog::sendDataParams - END" << QT_ENDL;
     return -1;
 }
 
 /*
 int eLogClubLog::sendData(const QString &_clublogCall, const QString &_q)
 {
-     //qDebug()<< "eLogClubLog::sendData: " << _q << endl;
+     //qDebug()<< "eLogClubLog::sendData: " << _q << QT_ENDL;
 
     QUrl serviceUrl = QUrl("https://secure.clublog.org/realtime.php");
     QByteArray postData;
@@ -359,7 +357,7 @@ int eLogClubLog::sendData(const QString &_clublogCall, const QString &_q)
     if  (_clublogCall.length()>2)
     {
         params.addQueryItem("callsign",_clublogCall);
-            //qDebug()<< "eLogClubLog::sendData - callsign 1: " << _clublogCall << endl;
+            //qDebug()<< "eLogClubLog::sendData - callsign 1: " << _clublogCall << QT_ENDL;
     }
     else
     {
@@ -371,7 +369,7 @@ int eLogClubLog::sendData(const QString &_clublogCall, const QString &_q)
     params.addQueryItem("adif",_q);
 
     postData = params.query(QUrl::FullyEncoded).toUtf8();
-      //qDebug()<< "eLogClubLog::sendData - query: " << postData << endl;
+      //qDebug()<< "eLogClubLog::sendData - query: " << postData << QT_ENDL;
     //postData = params.encodedQuery();
 
     // Call the webservice
@@ -392,7 +390,7 @@ int eLogClubLog::sendData(const QString &_clublogCall, const QString &_q)
 QString eLogClubLog::getClubLogAdif(const QStringList _q)
 
 {
-     //qDebug() << "eLogClubLog::getClubLogAdif: " << QString::number(_q.length()) << endl;
+     //qDebug() << "eLogClubLog::getClubLogAdif: " << QString::number(_q.length()) << QT_ENDL;
     // _qso must include 16 ordered fields than can be empty or contain data. This function builds the ADIF QSO
 /* http://clublog.freshdesk.com/support/solutions/articles/53202-which-adif-fields-does-club-log-use-
 ClubLog only accepts the following ADIF fields:
@@ -423,48 +421,48 @@ NOTES
     }
     for (int i = 0; i< _q.length(); i++)
     {
-         //qDebug()<< QString("eLogClubLog::getClubLogAdif: (%1): %2").arg(i).arg(_q.at(i)) << endl;
+         //qDebug()<< QString("eLogClubLog::getClubLogAdif: (%1): %2").arg(i).arg(_q.at(i)) << QT_ENDL;
     }
 
     QString qso, aux1;
     qso.clear();
     aux1 = _q.at(0);
-     //qDebug()<< "eLogClubLog::getClubLogAdif: Date: " << _q.at(0)  << endl;
+     //qDebug()<< "eLogClubLog::getClubLogAdif: Date: " << _q.at(0)  << QT_ENDL;
     if (QDate::fromString(aux1, "yyyyMMdd").isValid()){
 
         qso = "<QSO_DATE:" + QString::number(aux1.length()) + ">" +  aux1  +  " ";
     }
     else
     {
-         //qDebug() << "eLogClubLog::getClubLogAdif: END error " << endl;
+         //qDebug() << "eLogClubLog::getClubLogAdif: END error " << QT_ENDL;
         return QString();
     }
 
     //qso = "<QSO_DATE:" + QString::number((_q.at(0)).length()) + ">" + _q.at(0) + " ";
     qso = qso + "<TIME_ON:" + QString::number((_q.at(1)).length()) + ">" + _q.at(1) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 10"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 10"  << QT_ENDL;
     if ((_q.at(2)).length()>0)
     {
         qso = qso + "<QSLRDATE:" + QString::number((_q.at(2)).length()) + ">" + _q.at(2) + " ";
     }
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 20"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 20"  << QT_ENDL;
     if ((_q.at(3)).length()>0)
     {
         qso = qso + "<QSLSDATE:" + QString::number((_q.at(3)).length()) + ">" + _q.at(3) + " ";
     }
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 30"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 30"  << QT_ENDL;
     qso = qso + "<CALL:" + QString::number((_q.at(4)).length()) + ">" + _q.at(4) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 40"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 40"  << QT_ENDL;
     if ((_q.at(5)).length()>0)
     {
         qso = qso + "<OPERATOR:" + QString::number((_q.at(5)).length()) + ">" + _q.at(5) + " ";
     }
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 50"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 50"  << QT_ENDL;
     qso = qso + "<MODE:" + QString::number((_q.at(6)).length()) + ">" + _q.at(6) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 60"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 60"  << QT_ENDL;
     qso = qso + "<BAND:" + QString::number((_q.at(7)).length()) + ">" + _q.at(7) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 70"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 70"  << QT_ENDL;
     if ((_q.at(8)).length()> 2)
     {
         qso = qso + "<BAND_RX:" + QString::number((_q.at(8)).length()) + ">" + _q.at(8) + " ";
@@ -476,41 +474,41 @@ NOTES
     }
 
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 90"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 90"  << QT_ENDL;
     qso = qso + "<QSL_RCVD:" + QString::number((_q.at(10)).length()) + ">" + _q.at(10) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 100"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 100"  << QT_ENDL;
     qso = qso + "<LOTW_QSL_RCVD:" + QString::number((_q.at(11)).length()) + ">" + _q.at(11) + " ";
-     //qDebug()<< "eLogClubLog::getClubLogAdif: 110"  << endl;
+     //qDebug()<< "eLogClubLog::getClubLogAdif: 110"  << QT_ENDL;
     //qso = qso + "<QSL_SENT:" + QString::number((_q.at(12)).length()) + ">" + _q.at(12) + " ";
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 120"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 120"  << QT_ENDL;
     if ((_q.at(13)).toInt()> 0)
     {
         qso = qso + "<DXCC:" + QString::number((_q.at(13)).length()) + ">" + _q.at(13) + " ";
     }
 
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 130'"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 130'"  << QT_ENDL;
     if ((_q.at(14)).toInt()> 0)
     {
         qso = qso + "<PROP_MODE:" + QString::number((_q.at(14)).length()) + ">" + _q.at(14) + " ";
     }
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 140"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 140"  << QT_ENDL;
     if ((_q.at(15)).length()>0)
     {
         qso = qso + "<CREDIT_GRANTED:" + QString::number((_q.at(15)).length()) + ">" + _q.at(15) + " ";
     }
 
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 150"  << endl;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 150"  << QT_ENDL;
     qso = qso + "<EOR>";
-     //qDebug()<< "eLogClubLog:: - QSO: "  << qso << endl;
-      //qDebug()<< "eLogClubLog::getClubLogAdif: 100"  << endl;
+     //qDebug()<< "eLogClubLog:: - QSO: "  << qso << QT_ENDL;
+      //qDebug()<< "eLogClubLog::getClubLogAdif: 100"  << QT_ENDL;
     return qso;
 }
 
-void eLogClubLog::setCredentials(const QString &_email, const QString &_pass, const QString _defaultStationCallsign)
+void eLogClubLog::setCredentials(const QString &_email, const QString &_pass, const QString &_defaultStationCallsign)
 {
-     //qDebug()<< "eLogClubLog::setCredentials: email: " << _email << " / Pass: " << _pass << " / StationCallsign: " << _defaultStationCallsign << endl;
+     //qDebug()<< "eLogClubLog::setCredentials: email: " << _email << " / Pass: " << _pass << " / StationCallsign: " << _defaultStationCallsign << QT_ENDL;
     stationCallsign = _defaultStationCallsign;
     email = _email;
     pass = _pass;
@@ -520,10 +518,10 @@ void eLogClubLog::setCredentials(const QString &_email, const QString &_pass, co
 
 int eLogClubLog::deleteQSO(QStringList _qso)
 {
-     //qDebug()<< "eLogClubLog::deleteQSO: length = " << QString::number(_qso.length()) << endl;
-     //qDebug()<< "eLogClubLog::deleteQSO: " << email << "/" << pass << "/" << api  << endl;
-     //qDebug()<< "eLogClubLog::deleteQSO: email = " << email << endl;
-     //qDebug()<< "eLogClubLog::deleteQSO: Pass = " << pass << endl;
+     //qDebug()<< "eLogClubLog::deleteQSO: length = " << QString::number(_qso.length()) << QT_ENDL;
+     //qDebug()<< "eLogClubLog::deleteQSO: " << email << "/" << pass << "/" << api  << QT_ENDL;
+     //qDebug()<< "eLogClubLog::deleteQSO: email = " << email << QT_ENDL;
+     //qDebug()<< "eLogClubLog::deleteQSO: Pass = " << pass << QT_ENDL;
 
     // email, password, callsign, dxcall, datetime (sqlite format, not ADIF), bandid (only the number, not ADIF), api
     if (_qso.length()!=18)
@@ -532,7 +530,7 @@ int eLogClubLog::deleteQSO(QStringList _qso)
     }
     for (int i = 0; i<_qso.length(); i++)
     {
-         //qDebug()<< QString("eLogClubLog::deleteQSO: qso.at(%1) = %2").arg(i).arg(_qso.at(i)) << endl;
+         //qDebug()<< QString("eLogClubLog::deleteQSO: qso.at(%1) = %2").arg(i).arg(_qso.at(i)) << QT_ENDL;
     }
 
     QString dxcall, sdateTime, bandid;
@@ -554,18 +552,18 @@ int eLogClubLog::deleteQSO(QStringList _qso)
     }
 
     sdateTime = dateTime.toString("yyyy-MM-dd HH:mm:ss");
-     //qDebug()<< QString("eLogClubLog::deleteQSO: DateTime = %1").arg(sdateTime) << endl;
-      //qDebug()<< QString("eLogClubLog::deleteQSO: band-1: ") << _qso.at(8) << endl;
+     //qDebug()<< QString("eLogClubLog::deleteQSO: DateTime = %1").arg(sdateTime) << QT_ENDL;
+      //qDebug()<< QString("eLogClubLog::deleteQSO: band-1: ") << _qso.at(8) << QT_ENDL;
     bandid = (_qso.at(8)).chopped(1);
-      //qDebug()<< QString("eLogClubLog::deleteQSO: band-2: ") << bandid << endl;
+      //qDebug()<< QString("eLogClubLog::deleteQSO: band-2: ") << bandid << QT_ENDL;
     bool ok;
-    int a = bandid.toInt(&ok);
+    bandid.toInt(&ok);
     if (!ok)
     { // This check is to capture potential QSOs in 222Mhz (AKA 1.25)
         bandid = bandid.chopped(1);
-         //qDebug()<< QString("eLogClubLog::deleteQSO: band-3: ") << bandid << endl;
+         //qDebug()<< QString("eLogClubLog::deleteQSO: band-3: ") << bandid << QT_ENDL;
     }
-     //qDebug()<< QString("eLogClubLog::deleteQSO: bandid = %1").arg(bandid) << endl;
+     //qDebug()<< QString("eLogClubLog::deleteQSO: bandid = %1").arg(bandid) << QT_ENDL;
     if (bandid.toInt()<=0)
     {
         return -2;
@@ -585,7 +583,7 @@ int eLogClubLog::deleteQSO(QStringList _qso)
 
 QString eLogClubLog::prepareToTranslate(const QString &_m)
 {
-        //qDebug()<< "eLogClubLog:: = prepareToTranslate" << _m << endl;
+        //qDebug()<< "eLogClubLog:: = prepareToTranslate" << _m << QT_ENDL;
     if (_m == "Callsign missing")
     {
         return tr("Callsign missing");
@@ -691,7 +689,7 @@ QString eLogClubLog::prepareToTranslate(const QString &_m)
 
 int eLogClubLog::modifyQSO (QStringList _oldQSO, QStringList _newQSO)
 {
-      //qDebug()<< QString("eLogClubLog::modifyQSO") << endl;
+      //qDebug()<< QString("eLogClubLog::modifyQSO") << QT_ENDL;
    int x = -1;
 
     x = deleteQSO(_oldQSO);
@@ -701,7 +699,7 @@ int eLogClubLog::modifyQSO (QStringList _oldQSO, QStringList _newQSO)
 
 void eLogClubLog::sendLogFile(const QString &_file, QList<int> _qso, bool _overwrite)
 {
-      //qDebug()<< "eLogClubLog::sendLogFile: " << _file << endl;
+      //qDebug()<< "eLogClubLog::sendLogFile: " << _file << QT_ENDL;
     qsos.clear();
     qsos.append(_qso);
     QUrl serviceUrl;
@@ -725,15 +723,15 @@ void eLogClubLog::sendLogFile(const QString &_file, QList<int> _qso, bool _overw
     }
     else
     {
-          //qDebug()<< "eLogClubLog::sendLogFile: ERROR File not opened" << endl;
+          //qDebug()<< "eLogClubLog::sendLogFile: ERROR File not opened" << QT_ENDL;
         return;
     }
     file->close();
     // The rest of the form goes as usual
-      //qDebug()<< "eLogClubLog::sendLogFile: email: " << email << endl;
-      //qDebug()<< "eLogClubLog::sendLogFile: pass: " << pass << endl;
-      //qDebug()<< "eLogClubLog::sendLogFile: stationcall: " << stationCallsign << endl;
-      //qDebug()<< "eLogClubLog::sendLogFile: api: " << api << endl;
+      //qDebug()<< "eLogClubLog::sendLogFile: email: " << email << QT_ENDL;
+      //qDebug()<< "eLogClubLog::sendLogFile: pass: " << pass << QT_ENDL;
+      //qDebug()<< "eLogClubLog::sendLogFile: stationcall: " << stationCallsign << QT_ENDL;
+      //qDebug()<< "eLogClubLog::sendLogFile: api: " << api << QT_ENDL;
 
     QHttpPart emailPart;
     emailPart.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant("form-data; name=\"email\""));
@@ -784,7 +782,7 @@ void eLogClubLog::sendLogFile(const QString &_file, QList<int> _qso, bool _overw
     manager->post(request, multiPart);
     //multiPart->setParent(reply);
 
-      //qDebug()<< "eLogClubLog::sendLogFile - END" << endl;
+      //qDebug()<< "eLogClubLog::sendLogFile - END" << QT_ENDL;
 
 }
 
