@@ -33,12 +33,16 @@
 
 eLogQrzLog::eLogQrzLog(DataProxy_SQLite *dp, const QString &_parentFunction, const QString &_klogVersion)
 {
-   //qDebug()<< QString("eLogQrzLog::eLogQrzLog (%1) ").arg(_parentFunction)  << endl;
+#ifdef QT_DEBUG
+  //qDebug() << Q_FUNC_INFO << ": " << _parentFunction;
+#endif
+
     klogVersion = _klogVersion;
     dataProxy = dp;
     errorWhileSendingLog = false;
     sendingQSO = false;
     lastQSO = false;
+    subscriptionOK = true;
 
     qsos.clear();
     sessionkey = QString();
@@ -54,26 +58,37 @@ eLogQrzLog::eLogQrzLog(DataProxy_SQLite *dp, const QString &_parentFunction, con
     util = new Utilities;
     serviceUrl = QUrl("https://xmldata.qrz.com/xml/current/");
     //serviceUrl = QUrl("https://xmldata.qrz.com/xml/1.31/ ");
-   //qDebug()<< "eLogQrzLog::eLogQrzLog - END"  << endl;
+   //qDebug()<< "eLogQrzLog::eLogQrzLog - END"  << QT_ENDL;
 }
 
 eLogQrzLog::~eLogQrzLog()
 {
-        //qDebug()<< "eLogQrzLog::~eLogQrzLog"  << endl;
+    showDebugLog (Q_FUNC_INFO, "END");
+}
+
+void eLogQrzLog::showDebugLog(const QString &_func, const QString &_log)
+{
+#ifdef QT_DEBUG
+  //qDebug() << _func << ": " << _log;
+#else
+#endif
 }
 
 void eLogQrzLog::setLogBookKey(const QString &_key)
 {
-    //qDebug()<< "eLogQrzLog::setLogBookKey: " << _key  << endl;
+    //qDebug()<< "eLogQrzLog::setLogBookKey: " << _key  << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start: key: " + _key);
     if (_key.length()>0)
     {
         logbookkey = _key;
     }
+    showDebugLog (Q_FUNC_INFO, "END");
 }
 
 void eLogQrzLog::parseNetworkError(QNetworkReply::NetworkError _error)
 {
 
+    showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(_error));
     QString text;
     switch (_error) {
         case QNetworkReply::NoError:
@@ -90,31 +105,35 @@ void eLogQrzLog::parseNetworkError(QNetworkReply::NetworkError _error)
 
     //return text;
 
-    int i = QMessageBox::warning(nullptr, tr("KLog - QRZ.com"),
+    QMessageBox::warning(nullptr, tr("KLog - QRZ.com"),
                                            tr("We have received the following error from QRZ.com (%1)").arg(result) + "\n" +
                                               text,
                                            QMessageBox::Ok);
 
+    showDebugLog (Q_FUNC_INFO, "END");
 }
 
 void eLogQrzLog::slotManagerLogFinished(QNetworkReply *data)
 {
-    //qDebug()<< "eLogQrzLog::slotLogManagerFinished"  << endl;
+    //qDebug()<< "eLogQrzLog::slotLogManagerFinished"  << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start");
     sendingQSO = false;
     result = data->error();
-    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result = " << QString::number(result) << endl;
+    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result = " << QString::number(result) << QT_ENDL;
 
     const QByteArray sdata = data->readAll();
     //qDebug() << "eLogQrzLog::slotManagerLogFinished: Received: " << sdata;
 
     QString text = QString();
 
-    //qDebug() << "eLogQrzLog::slotManagerLogFinished - 00010" << endl;
+    //qDebug() << "eLogQrzLog::slotManagerLogFinished - 00010" << QT_ENDL;
     if (result == QNetworkReply::NoError)
     {
         QString dataReply(sdata);
-        parseAppAnswer(1, dataReply);
-       //qDebug()<< "eLogQrzLog::slotManageLogFinished - NO ERROR" << endl;
+        //parseAppAnswer(1, dataReply);
+        parseAppAnswer(dataReply);
+        showDebugLog (Q_FUNC_INFO, "No error");
+       //qDebug()<< "eLogQrzLog::slotManageLogFinished - NO ERROR" << QT_ENDL;
     }
     else {
         parseNetworkError(result);
@@ -128,15 +147,17 @@ void eLogQrzLog::slotManagerLogFinished(QNetworkReply *data)
         sendSignal(result, qsos);
     }
 
-    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result = " << QString::number(result) << endl;
-    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result Text = " << text << endl;
+    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result = " << QString::number(result) << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::slotManagerLogFinished - Result Text = " << text << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Text: " + text);
     emit showMessage(text);
-
+    showDebugLog (Q_FUNC_INFO, "END");
 }
 
 void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
 {
-    //qDebug() << "eLogQrzLog::parseXMLAnswer: " << xml.text() << endl;
+    //qDebug() << Q_FUNC_INFO << xml.text();
+    showDebugLog (Q_FUNC_INFO, "Start: " + xml.text());
     QString tdata = QString();
 
     while (!xml.atEnd())
@@ -145,22 +166,22 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
         QXmlStreamReader::TokenType t = xml.readNext();
         if (t == QXmlStreamReader::StartDocument)
         {
-            //qDebug() << "eLogQrzLog::parseXMLAnswer - quick read version: " << xml.documentVersion().toString() << endl;
-            //qDebug() << "eLogQrzLog::parseXMLAnswer - quick read encoding: " << xml.documentEncoding().toString() << endl;
+            //qDebug() << Q_FUNC_INFO << " - quick read version: " << xml.documentVersion().toString() << QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << " - quick read encoding: " << xml.documentEncoding().toString() << QT_ENDL;
         }
 
         if (t == QXmlStreamReader::StartElement)
         {
             QString name = xml.name().toString();
-            //qDebug() << "eLogQrzLog::parseXMLAnswer - quick read name: " << name << endl;
+            //qDebug() << Q_FUNC_INFO << " - quick read name: " << name << QT_ENDL;
             if (name == "QRZDatabase" || name == "Session" || name == "Callsign")
             {
-                //qDebug() << "eLogQrzLog::parseXMLAnswer - No data: " << name << endl;
+                //qDebug() << Q_FUNC_INFO << " - No data: " << name << QT_ENDL;
             }
             else if (name == "Key")
             {
                 tdata = xml.readElementText();
-                //qDebug() << "eLogQrzLog::parseXMLAnswer: API-Key: " << tdata << endl;
+                //qDebug() << Q_FUNC_INFO << " - API-Key: " << tdata << QT_ENDL;
                 if (tdata.length()>0)
                 {
                     sessionkey = tdata;
@@ -173,14 +194,14 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 tdata = xml.readElementText();
                 if (tdata.length()>0)
                 {
-                   //qDebug() << "eLogQrzLog::parseXMLAnswer: CALL: " << tdata << endl;
+                   //qDebug() << Q_FUNC_INFO << " - CALL: " << tdata << QT_ENDL;
                 }
                 continue;
             }
             else if (name == "Error")
             {
                 tdata = xml.readElementText();
-                //qDebug() << "eLogQrzLog::parseXMLAnswer: Error: " << tdata << endl;
+                //qDebug() << Q_FUNC_INFO << " - Error: " << tdata << QT_ENDL;
                 if (tdata == "Username/password incorrect ")
                 {
                     pass = QString();
@@ -191,7 +212,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
             else if (name == "Message")
              {
                  tdata = xml.readElementText();
-                 //qDebug() << "eLogQrzLog::parseXMLAnswer: Message: " << tdata << endl;
+                 //qDebug() << Q_FUNC_INFO << " - Message: " << tdata << QT_ENDL;
                  emit dataFoundSignal("message", tdata);
                  continue;
              }
@@ -202,7 +223,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 if (tdata.length()>0)
                 {
                     emit dataFoundSignal("name", tdata);
-                    //qDebug() << "eLogQrzLog::parseXMLAnswer: Name: " << tdata << endl;
+                    //qDebug() << Q_FUNC_INFO << " - Name: " << tdata << QT_ENDL;
                 }
                 continue;
             }
@@ -212,7 +233,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 if (tdata.length()>0)
                 {
                     //emit dataFoundSignal("grid", tdata);
-                   //qDebug() << "eLogQrzLog::parseXMLAnswer: addr1: " << tdata << endl;
+                   //qDebug() << Q_FUNC_INFO << " - addr1: " << tdata << QT_ENDL;
                 }
                 continue;
             }
@@ -222,7 +243,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 if (tdata.length()>0)
                 {
                     emit dataFoundSignal("qth", tdata);
-                   //qDebug() << "eLogQrzLog::parseXMLAnswer: addr2: " << tdata << endl;
+                   //qDebug() << Q_FUNC_INFO << " - addr2: " << tdata;
                 }
                 continue;
             }
@@ -231,6 +252,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 tdata = xml.readElementText();
                 if (tdata.length()>0)
                 {
+                    //qDebug() << Q_FUNC_INFO << " - grid: " << tdata;
                       emit dataFoundSignal("grid", tdata);
                 }
                 continue;
@@ -240,58 +262,67 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 tdata = xml.readElementText();
                 if (tdata.length()>0)
                 {
+                    //qDebug() << Q_FUNC_INFO << " - qslmgr: " << tdata;
                     emit dataFoundSignal("qslmgr", tdata);
                 }
                 continue;
             }
             else if (name == "Remark")
             {
-                //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: "  << endl;
                 tdata = xml.readElementText();
+                //qDebug() << Q_FUNC_INFO << " - Remark: " << tdata ;
                 if (tdata.length()>0)
                 {
-                    //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: " << tdata << endl;
+                    //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: " << tdata << QT_ENDL;
                 }
                 continue;
             }
+            else if ((xml.readElementText() == "non-subscriber") && (subscriptionOK))
+            {
+                //qDebug() << Q_FUNC_INFO << " - Not Subscribed QRZ.com user";
+                showDebugLog (Q_FUNC_INFO, "Non Subscribed");
+                emit showMessage(tr("You are not subscribed to QRZ.com."));
+                //emit disableQRZAction(true);
+                subscriptionOK = false;
+            }
             else
             {
-                //qDebug() << "eLogQrzLog::parseXMLAnswer - name =  " << name << endl;
-                //qDebug() << "eLogQrzLog::parseXMLAnswer - quick read data: " << xml.readElementText() << endl;
+                //qDebug() << Q_FUNC_INFO << " - ELSE quick read data: " << xml.readElementText() << QT_ENDL;
             }
         }
     }
     if (xml.hasError())
     {
-        //qDebug() << "eLogQrzLog::parseXMLAnswer - ERROR: " << xml.errorString()  << endl;
+        showDebugLog (Q_FUNC_INFO, "Error: " + xml.errorString());
+        //qDebug() << Q_FUNC_INFO << " - ERROR: " << xml.errorString()  << QT_ENDL;
     }
     else if (xml.atEnd())
     {
-        //qDebug() << "eLogQrzLog::parseXMLAnswer - XML END"  << endl;
+        //qDebug() << Q_FUNC_INFO << " - XML END"  << QT_ENDL;
     }
 /*
      QString tname, tdata;
      while(!xml.atEnd() && !xml.hasError())
      {
-         //qDebug() << "eLogQrzLog::parseXMLAnswer - 00012" << endl;
+         //qDebug() << "eLogQrzLog::parseXMLAnswer - 00012" << QT_ENDL;
          QXmlStreamReader::TokenType token = xml.readNext();
 
          if (token == QXmlStreamReader::StartDocument)
          {
-             //qDebug() << "eLogQrzLog::parseXMLAnswer - StartDocument" << endl;
+             //qDebug() << "eLogQrzLog::parseXMLAnswer - StartDocument" << QT_ENDL;
              continue;
          }
-         //qDebug() << "eLogQrzLog::parseXMLAnswer - 00014" << endl;
+         //qDebug() << "eLogQrzLog::parseXMLAnswer - 00014" << QT_ENDL;
          if (token == QXmlStreamReader::StartElement)
          {
              tname = xml.name().toString();
 
-            //qDebug() << "eLogQrzLog::parseXMLAnswer - tname = " << tname << endl;
+            //qDebug() << "eLogQrzLog::parseXMLAnswer - tname = " << tname << QT_ENDL;
 
             if (tname == "Key")
             {
                 tdata = xml.readElementText();
-                //qDebug() << "eLogQrzLog::parseXMLAnswer: API-Key: " << tdata << endl;
+                //qDebug() << "eLogQrzLog::parseXMLAnswer: API-Key: " << tdata << QT_ENDL;
                 if (tdata.length()>0)
                 {
                     sessionkey = tdata;
@@ -302,13 +333,13 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
             if (tname == "Error")
             {
                 tdata = xml.readElementText();
-                //qDebug() << "eLogQrzLog::parseXMLAnswer: Error: " << tdata << endl;
+                //qDebug() << "eLogQrzLog::parseXMLAnswer: Error: " << tdata << QT_ENDL;
                 emit dataFoundSignal("error", tdata);
             }
             if (tname == "Message")
              {
                  tdata = xml.readElementText();
-                 //qDebug() << "eLogQrzLog::parseXMLAnswer: Message: " << tdata << endl;
+                 //qDebug() << "eLogQrzLog::parseXMLAnswer: Message: " << tdata << QT_ENDL;
                  emit dataFoundSignal("message", tdata);
              }
             if (tname == "call")
@@ -316,7 +347,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                   tdata = xml.readElementText();
                   if (tdata.length()>0)
                   {
-                     //qDebug() << "eLogQrzLog::parseXMLAnswer: CALL: " << tdata << endl;
+                     //qDebug() << "eLogQrzLog::parseXMLAnswer: CALL: " << tdata << QT_ENDL;
                   }
                   continue;
               }
@@ -326,7 +357,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                   if (tdata.length()>0)
                   {
                       emit dataFoundSignal("name", tdata);
-                     //qDebug() << "eLogQrzLog::parseXMLAnswer: Name: " << tdata << endl;
+                     //qDebug() << "eLogQrzLog::parseXMLAnswer: Name: " << tdata << QT_ENDL;
                   }
                   continue;
               }
@@ -336,7 +367,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                   if (tdata.length()>0)
                   {
                       //emit dataFoundSignal("grid", tdata);
-                     //qDebug() << "eLogQrzLog::parseXMLAnswer: addr1: " << tdata << endl;
+                     //qDebug() << "eLogQrzLog::parseXMLAnswer: addr1: " << tdata << QT_ENDL;
                   }
                   continue;
               }
@@ -346,7 +377,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                   if (tdata.length()>0)
                   {
                       emit dataFoundSignal("qth", tdata);
-                     //qDebug() << "eLogQrzLog::parseXMLAnswer: addr2: " << tdata << endl;
+                     //qDebug() << "eLogQrzLog::parseXMLAnswer: addr2: " << tdata << QT_ENDL;
                   }
                   continue;
               }
@@ -370,54 +401,55 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
               }
             if (tname == "Remark")
               {
-                  //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: "  << endl;
+                  //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: "  << QT_ENDL;
                   tdata = xml.readElementText();
                   if (tdata.length()>0)
                   {
-                      //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: " << tdata << endl;
+                      //qDebug() << "eLogQrzLog::parseXMLAnswer: Remark: " << tdata << QT_ENDL;
                   }
                   continue;
               }
             if (tname == "Session")
               {
-                  //qDebug() << "eLogQrzLog::parseXMLAnswer: Session: "  << endl;
+                  //qDebug() << "eLogQrzLog::parseXMLAnswer: Session: "  << QT_ENDL;
                   tdata = xml.readElementText();
                   if (tdata.length()>0)
                   {
-                      //qDebug() << "eLogQrzLog::parseXMLAnswer: Session: " << tdata << endl;
+                      //qDebug() << "eLogQrzLog::parseXMLAnswer: Session: " << tdata << QT_ENDL;
                   }
                   continue;
               }
 
-              //qDebug() << "eLogQrzLog::parseXMLAnswer: Unknown: " << tname << endl;
+              //qDebug() << "eLogQrzLog::parseXMLAnswer: Unknown: " << tname << QT_ENDL;
          }
      }
      if (xml.hasError())
      {
-           //qDebug() << "eLogQrzLog::parseXMLAnswer XML error: " << "XML error: " << xml.errorString() << endl;
+           //qDebug() << "eLogQrzLog::parseXMLAnswer XML error: " << "XML error: " << xml.errorString() << QT_ENDL;
      }
      else if (xml.atEnd())
      {
-           //qDebug() << "eLogQrzLog::parseXMLAnswer XML END: " << "Reached end, done" << endl;
+           //qDebug() << "eLogQrzLog::parseXMLAnswer XML END: " << "Reached end, done" << QT_ENDL;
      }
      */
-    //qDebug() << "eLogQrzLog::parseXMLAnswer: END of token while" << endl;
-    //qDebug()<< "eLogQrzLog::parseXMLAnswer - NO ERROR" << endl;
+    //qDebug() << "eLogQrzLog::parseXMLAnswer: END of token while" << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - NO ERROR" ;
+    showDebugLog (Q_FUNC_INFO, "END");
 }
 
 void eLogQrzLog::slotManagerFinished(QNetworkReply *data)
 {
-    //qDebug()<< "eLogQrzLog::slotManagerFinished"  << endl;
-
+    //qDebug() << Q_FUNC_INFO;
+    showDebugLog (Q_FUNC_INFO, "Start");
     result = data->error();
-    //qDebug()<< "eLogQrzLog::slotManagerFinished - Result = " << QString::number(result) << endl;
+    //qDebug() << Q_FUNC_INFO << " - Result = " << QString::number(result) << QT_ENDL;
 
     const QByteArray sdata = data->readAll();
-   //qDebug() << "eLogQrzLog::slotManagerFinished: Received: " << sdata;
+   //qDebug() << Q_FUNC_INFO << " - Received: " << sdata;
 
     QString text = QString();
 
-   //qDebug() << "eLogQrzLog::slotManagerFinished - 00010" << endl;
+   //qDebug() << Q_FUNC_INFO << " - 00010" << QT_ENDL;
     if (result == QNetworkReply::NoError)
     {
         //QXmlStreamReader reader(sdata);
@@ -430,23 +462,27 @@ void eLogQrzLog::slotManagerFinished(QNetworkReply *data)
         //parseNetworkError(result);
     }
 
-    //qDebug()<< "eLogQrzLog::slotManagerFinished - Result = " << QString::number(result) << endl;
-    //qDebug()<< "eLogQrzLog::slotManagerFinished - Result Text = " << text << endl;
+    //qDebug() << Q_FUNC_INFO << " - Result = " << QString::number(result) << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Result Text = " << text << QT_ENDL;
 
     emit showMessage(text);
+    showDebugLog (Q_FUNC_INFO, "Text: " + text);
+    showDebugLog (Q_FUNC_INFO, "END");
 
 }
 
 void eLogQrzLog::downloadProgress(qint64 received, qint64 total) {
-       //qDebug()<< "eLogQrzLog::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << endl;
-
+       //qDebug()<< "eLogQrzLog::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(received) +"/"+QString::number(total));
        //qDebug()<< received << total;
     emit actionShowProgres(received, total);
+    showDebugLog (Q_FUNC_INFO, "END");
 }
 
 void eLogQrzLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
 {
-       //qDebug()<< "eLogQrzLog::slotErrorManagement: " << QString::number(networkError) << endl;
+       //qDebug()<< "eLogQrzLog::slotErrorManagement: " << QString::number(networkError) << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(networkError));
     result = networkError;
 
     if (result == QNetworkReply::NoError)
@@ -454,90 +490,99 @@ void eLogQrzLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-            //qDebug()<< "eLogQrzLog::slotErrorManagement: Host not found" << endl;
+            //qDebug()<< "eLogQrzLog::slotErrorManagement: Host not found" << QT_ENDL;
     }
     else
     {
-            //qDebug()<< "eLogQrzLog::slotErrorManagement: ERROR!" << endl;
+            //qDebug()<< "eLogQrzLog::slotErrorManagement: ERROR!" << QT_ENDL;
     }
 
     //actionError(result);
+    showDebugLog (Q_FUNC_INFO, "END");
 }
 
 bool eLogQrzLog::canConnect()
 {
-   //qDebug()<< "eLogQrzLog::canConnect: "  << endl;
+   showDebugLog (Q_FUNC_INFO, "Start");
    if (!logged)
    {
-       //qDebug()<< "eLogQrzLog::canConnect: 10"  << endl;
+       //qDebug() << Q_FUNC_INFO << " - 10";
        login();
        if (!logged)
        {
-            //qDebug()<< "eLogQrzLog::canConnect: Not logged"  << endl;
+            //qDebug() << Q_FUNC_INFO << " - Not logged";
+           showDebugLog (Q_FUNC_INFO, "END-false-1");
             return false;
        }
    }
    if (sessionkey.length()<1)
    {
-        //qDebug()<< "eLogQrzLog::canConnect: API not valid"  << endl;
+       //qDebug() << Q_FUNC_INFO << " - API not valid";
+       showDebugLog (Q_FUNC_INFO, "END-false-2");
        return false;
    }
-   //qDebug()<< "eLogQrzLog::canConnect: END"  << endl;
+   showDebugLog (Q_FUNC_INFO, "END-true");
    return true;
 }
 
 void eLogQrzLog::fetchData()
 {
-    //qDebug()<< "eLogQrzLog::fetchData"  << endl;
+    //qDebug() << Q_FUNC_INFO;
+    showDebugLog (Q_FUNC_INFO, "Start");
     if (!canConnect())
     {
+        showDebugLog (Q_FUNC_INFO, "END- can't connect");
         return;
     }
-   //qDebug()<< "eLogQrzLog::checkQRZ: Preparing the query"  << endl;
     QUrlQuery params;
 
-
     params.addQueryItem("action", "fetch");
     params.addQueryItem("option", "all");
     params.addQueryItem("agent", util->getGlobalAgent(klogVersion));
 
     sendDataParams(params);
+    showDebugLog (Q_FUNC_INFO, "END");
 }
 
 void eLogQrzLog::checkQRZ(const QString &_qrz)
 {
-    //qDebug()<< "eLogQrzLog::checkQRZ: " << _qrz << endl;
+    showDebugLog (Q_FUNC_INFO, "Start: " + _qrz);
     if (!util->isValidCall(_qrz))
     {
-        //qDebug()<< "eLogQrzLog::checkQRZ: CALL not valid"  << endl;
+        //qDebug()<< "eLogQrzLog::checkQRZ: CALL not valid"  << QT_ENDL;
+        showDebugLog (Q_FUNC_INFO, "CALL not valid");
         return;
     }
     serviceUrl = QUrl("https://xmldata.qrz.com/xml/current/");
 
     if (!canConnect())
     {
+        showDebugLog (Q_FUNC_INFO, "END-can't connect");
         return;
     }
 
-    //qDebug()<< "eLogQrzLog::checkQRZ: Preparing the query"  << endl;
+    //qDebug() << Q_FUNC_INFO << " - Preparing the query"  << QT_ENDL;
     QUrlQuery params;
     params.addQueryItem("s", sessionkey);
     params.addQueryItem("callsign", _qrz);
     params.addQueryItem("agent", util->getGlobalAgent(klogVersion));
     sendDataParams(params);
+    showDebugLog (Q_FUNC_INFO, "END");
 }
 
 int eLogQrzLog::sendQSOs(QList<int> _qsos)
 {
-    //qDebug()<< "eLogQrzLog::sendQSOs: QSOs: " << QString::number(_qsos.length()) << endl;
+    //qDebug()<< "eLogQrzLog::sendQSOs: QSOs: " << QString::number(_qsos.length()) << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start");
     errorWhileSendingLog = false;
     if (logbookkey.length()<1)
     {
-        //qDebug()<< "eLogQrzLog::sendQSOs: No valid KEY (-2)" << endl;
-        int i = QMessageBox::warning(nullptr, tr("KLog - QRZ.com"),
+        //qDebug()<< "eLogQrzLog::sendQSOs: No valid KEY (-2)" << QT_ENDL;
+        QMessageBox::warning(nullptr, tr("KLog - QRZ.com"),
                                        tr("Not valid KEY found") + "\n" +
                                           tr("Please configure your QRZ.com API key. You will find it in your QRZ.com Logbook settings webpage.\nYou need a QRZ.com subscription to use this feature."),
                                        QMessageBox::Ok);
+        showDebugLog (Q_FUNC_INFO, "END-2");
         return -2;
     }
     qsos.clear();
@@ -551,24 +596,25 @@ int eLogQrzLog::sendQSOs(QList<int> _qsos)
             lastQSO = true;
         }
     }
+    showDebugLog (Q_FUNC_INFO, "END");
     return 1;
 }
 
 int eLogQrzLog::sendQSO(const int _qsoID)
 {
-    //qDebug() << "eLogQrzLog::sendQSO: "  << QString::number(_qsoID) << endl;
-
+    //qDebug() << "eLogQrzLog::sendQSO: "  << QString::number(_qsoID) << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(_qsoID));
     QString adifQSO = dataProxy->getADIFQSO(_qsoID);
 
-    //qDebug()<< "eLogQrzLog::sendQSO: (ADIF) :" << adifQSO << endl;
-    //qDebug()<< "eLogQrzLog::sendQSO: (KEY) :" << logbookkey << endl;
+    //qDebug()<< "eLogQrzLog::sendQSO: (ADIF) :" << adifQSO << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::sendQSO: (KEY) :" << logbookkey << QT_ENDL;
     QUrlQuery params;
 
     params.addQueryItem("KEY", logbookkey);
     params.addQueryItem("ACTION", "INSERT");
     params.addQueryItem("ADIF",adifQSO);
     params.addQueryItem("agent", util->getGlobalAgent(klogVersion));
-    //qDebug() << "eLogQrzLog::sendQSO: END" << endl;
+    //qDebug() << "eLogQrzLog::sendQSO: END" << QT_ENDL;
 
     QByteArray postData;
 
@@ -577,23 +623,28 @@ int eLogQrzLog::sendQSO(const int _qsoID)
 
     QNetworkRequest requestLog(QUrl("https://logbook.qrz.com/api"));
     requestLog.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
+    showDebugLog (Q_FUNC_INFO, "postData: " + QString(postData));
 
-    //qDebug()<< "eLogQrzLog::sendQSO: postData: " << postData << endl;
+    //qDebug()<< "eLogQrzLog::sendQSO: postData: " << postData << QT_ENDL;
     while (sendingQSO)
     {
-        //qDebug() << "eLogQrzLog::sendQSO: sending QSO... just wait!" << endl;
+        //qDebug() << "eLogQrzLog::sendQSO: sending QSO... just wait!" << QT_ENDL;
     }
     managerLog->post(requestLog, postData);
+    showDebugLog (Q_FUNC_INFO, "END");
     return 1;
 }
 bool eLogQrzLog::hasLogBookKey()
 {
+    showDebugLog (Q_FUNC_INFO, "Start");
     if (logbookkey.length()>0)
     {
+        showDebugLog (Q_FUNC_INFO, "END-true");
         return true;
     }
     else
     {
+        showDebugLog (Q_FUNC_INFO, "END-false");
      return false;
     }
 }
@@ -601,10 +652,12 @@ bool eLogQrzLog::hasLogBookKey()
 
 void eLogQrzLog::login()
 {
-    //qDebug()<< "eLogQrzLog::login"  << endl;
+    //qDebug()<< "eLogQrzLog::login"  << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start");
     if (logged)
     {
-        //qDebug()<< "eLogQrzLog::login Already logged!"  << endl;
+        //qDebug()<< "eLogQrzLog::login Already logged!"  << QT_ENDL;
+        showDebugLog (Q_FUNC_INFO, "END-1");
         return;
     }
 
@@ -617,7 +670,8 @@ void eLogQrzLog::login()
         pass = QInputDialog::getText(nullptr, tr("KLog - QRZ.com password needed"),                                                   tr("Please enter your QRZ.com password: "), QLineEdit::Password, "", &ok);
         if (!ok)
         {
-             //qDebug() << "eLogQrzLog::login - END 1" <<  endl;
+             //qDebug() << "eLogQrzLog::login - END 1" <<  QT_ENDL;
+            showDebugLog (Q_FUNC_INFO, "END-2");
             return;
         }
     }
@@ -625,7 +679,7 @@ void eLogQrzLog::login()
 
     if ((user.length()<1) || (pass.length()<1))
     {
-        //qDebug()<< "eLogQrzLog::login error 2"  << endl;
+        //qDebug()<< "eLogQrzLog::login error 2"  << QT_ENDL;
         //if (!savePassword)
         //{// We delete the password as soon as possible if the user is not willing to save it
         //    pass = QString();
@@ -644,13 +698,15 @@ void eLogQrzLog::login()
     //{// We delete the password as soon as possible if the user is not willing to save it
     //        pass = QString();
     //}
-    //qDebug()<< "eLogQrzLog::login - END"  << endl;
+    //qDebug()<< "eLogQrzLog::login - END"  << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "END");
 
 }
 
 int eLogQrzLog::sendDataParams(const QUrlQuery &_params)
 {
-    //qDebug()<< "eLogQrzLog::sendDataParams: Params: " << _params.query(QUrl::FullyEncoded).toUtf8() << endl;
+    //qDebug()<< "eLogQrzLog::sendDataParams: Params: " << _params.query(QUrl::FullyEncoded).toUtf8() << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start");
 
     QByteArray postData;
 
@@ -665,22 +721,26 @@ int eLogQrzLog::sendDataParams(const QUrlQuery &_params)
     QNetworkRequest request(serviceUrl);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
 
-    //qDebug()<< "eLogQrzLog::sendDataParams: postData: " << postData << endl;
+    //qDebug()<< "eLogQrzLog::sendDataParams: postData: " << postData << QT_ENDL;
     manager->post(request, postData);
-     //qDebug()<< "eLogQrzLog::sendDataParams - END" << endl;
+     //qDebug()<< "eLogQrzLog::sendDataParams - END" << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "END");
     return -1;
 }
 
 void eLogQrzLog::setCredentials(const QString &_user, const QString &_pass)
 {
-    //qDebug()<< "eLogQrzLog::setCredentials: user: " << _user << " / Pass: " << _pass  << endl;
+    //qDebug()<< "eLogQrzLog::setCredentials: user: " << _user << " / Pass: " << _pass  << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start: " + _user + "/" + _pass);
     user = _user;
     pass = _pass;
+    showDebugLog (Q_FUNC_INFO, "END");
 }
 
 QString eLogQrzLog::prepareToTranslate(const QString &_m)
 {
-       //qDebug()<< "eLogQrzLog:: = prepareToTranslate" << _m << endl;
+       //qDebug()<< "eLogQrzLog:: = prepareToTranslate" << _m << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start: " + _m);
     if (_m == "Callsign missing")
     {
         return tr("Callsign missing");
@@ -691,21 +751,22 @@ QString eLogQrzLog::prepareToTranslate(const QString &_m)
     }
 }
 
-void eLogQrzLog::parseAppAnswer (const int howManyQSOs, const QString &_m)
+void eLogQrzLog::parseAppAnswer (const QString &_m)
 {
-    //qDebug()<< "eLogQrzLog::parseAppAnswer: " << _m  << endl;
+    //qDebug()<< "eLogQrzLog::parseAppAnswer: " << _m  << QT_ENDL;
+    showDebugLog (Q_FUNC_INFO, "Start: " + _m);
     QStringList response;
     response.clear();
     response << _m.split('&');
 
     QString responseType = response.at(0).split('=').at(0);
     QString responseResult = response.at(0).split('=').at(1);
-    //qDebug()<< "eLogQrzLog::parseAppAnswer: responseType: " << responseType  << endl;
-    //qDebug()<< "eLogQrzLog::parseAppAnswer: responseResult: " << responseResult << endl;
+    //qDebug()<< "eLogQrzLog::parseAppAnswer: responseType: " << responseType  << QT_ENDL;
+    //qDebug()<< "eLogQrzLog::parseAppAnswer: responseResult: " << responseResult << QT_ENDL;
 
     if ((responseType == "STATUS") && (responseResult == "OK"))
     {
-        //qDebug()<< "eLogQrzLog::parseAppAnswer: OK"  << endl;
+        //qDebug()<< "eLogQrzLog::parseAppAnswer: OK"  << QT_ENDL;
     }
     else if ((responseType == "STATUS") && (responseResult == "FAIL"))
     {
@@ -713,7 +774,7 @@ void eLogQrzLog::parseAppAnswer (const int howManyQSOs, const QString &_m)
         if (response.at(1).split('=').at(0) == "REASON")
         {
             QString reason = response.at(1).split('=').at(1);
-           //qDebug()<< "eLogQrzLog::parseAppAnswer: " << reason  << endl;
+           //qDebug()<< "eLogQrzLog::parseAppAnswer: " << reason  << QT_ENDL;
         }
     }
     else if ((responseType == "STATUS") && (responseResult == "AUTH"))
@@ -722,7 +783,7 @@ void eLogQrzLog::parseAppAnswer (const int howManyQSOs, const QString &_m)
         if (response.at(1).split('=').at(0) == "REASON")
         {
             QString reason = response.at(1).split('=').at(1);
-            //qDebug()<< "eLogQrzLog::parseAppAnswer: " << reason  << endl;
+            //qDebug()<< "eLogQrzLog::parseAppAnswer: " << reason  << QT_ENDL;
             //onlineMessage->showMessage(QNetworkReply::NoError, QRZ, Fail, Other, reason);
         }
     }
@@ -731,9 +792,20 @@ void eLogQrzLog::parseAppAnswer (const int howManyQSOs, const QString &_m)
 
 void eLogQrzLog::sendSignal(QNetworkReply::NetworkError _error, QList<int> _qsos)
 {
+    showDebugLog (Q_FUNC_INFO, "Error: " + QString::number(_error) + " - List: " + QString::number(_qsos.length ()));
     errorWhileSendingLog = false;
     emit signalLogUploaded(_error, _qsos);
 }
 
 
+void eLogQrzLog::setSubcription(const bool _ok)
+{
+    //showDebugLog (Q_FUNC_INFO, util->boolToQString (_ok));
+    subscriptionOK = _ok;
+}
 
+bool eLogQrzLog::getSubscription()
+{
+    showDebugLog (Q_FUNC_INFO, util->boolToQString (subscriptionOK));
+    return subscriptionOK;
+}
