@@ -35,7 +35,11 @@
 
 eQSLUtilities::eQSLUtilities(const QString &_parentFunction)
 {
-    //qDebug()<< "eQSLUtilities::eQSLUtilities"  << endl;
+    //qDebug()<< "eQSLUtilities::eQSLUtilities"  << QT_ENDL;
+#ifdef QT_DEBUG
+  //qDebug() << Q_FUNC_INFO << ": " << _parentFunction;
+#else
+#endif
 
     user = QString();
     pass = QString();
@@ -47,35 +51,35 @@ eQSLUtilities::eQSLUtilities(const QString &_parentFunction)
     stationCallsign = QString();
     uploadingFile = false;
     util = new Utilities;
-    //qDebug()<< "eQSLUtilities::eQSLUtilities - END"  << endl;
+    //qDebug()<< "eQSLUtilities::eQSLUtilities - END"  << QT_ENDL;
 }
 
 eQSLUtilities::~eQSLUtilities()
 {
-        //qDebug()<< "eQSLUtilities::~eQSLUtilities"  << endl;
+        //qDebug()<< "eQSLUtilities::~eQSLUtilities"  << QT_ENDL;
 }
 
 void eQSLUtilities::setUser(const QString &_call)
 {
-     //qDebug() << "eQSLUtilities::setUser: " << _call << endl;
+     //qDebug() << "eQSLUtilities::setUser: " << _call << QT_ENDL;
     user = _call;
-     //qDebug() << "eQSLUtilities::setUser: END" << endl;
+     //qDebug() << "eQSLUtilities::setUser: END" << QT_ENDL;
 }
 
 void eQSLUtilities::setPass(const QString &_pass)
 {
-     //qDebug() << "eQSLUtilities::setPass: " << _pass << endl;
+     //qDebug() << "eQSLUtilities::setPass: " << _pass << QT_ENDL;
     pass = _pass;
-     //qDebug() << "eQSLUtilities::setPass: END" << endl;
+     //qDebug() << "eQSLUtilities::setPass: END" << QT_ENDL;
 }
 
 void eQSLUtilities::slotQsoUploadFinished(QNetworkReply *data)
 {
-    //qDebug()<< "eQSLUtilities::slotQsoUploadFinished"  << endl;
+    //qDebug()<< "eQSLUtilities::slotQsoUploadFinished"  << QT_ENDL;
     QStringList parsedAnswer;
     parsedAnswer.clear();
     result = data->error();
-    //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = " << QString::number(result) << endl;
+    //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = " << QString::number(result) << QT_ENDL;
 
     const QByteArray sdata = data->readAll();
     QString text = QString();
@@ -86,7 +90,7 @@ void eQSLUtilities::slotQsoUploadFinished(QNetworkReply *data)
         parsedAnswer << prepareToTranslate(sdata);
         if (parsedAnswer.at(0).contains("Error"))
         {
-            //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - error detected" << endl;
+            //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - error detected" << QT_ENDL;
             QMessageBox::warning(nullptr, tr("KLog - eQSL"), tr("eQSL has sent the following message:\n%1").arg(parsedAnswer.at(1)), QMessageBox::Ok);
             qsos.clear();
             return;
@@ -96,7 +100,7 @@ void eQSLUtilities::slotQsoUploadFinished(QNetworkReply *data)
 
         }
         //qDebug()<< sdata;
-        //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - NO ERROR" << endl;
+        //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - NO ERROR" << QT_ENDL;
         if (uploadingFile)
         {
             uploadingFile = false;
@@ -107,28 +111,28 @@ void eQSLUtilities::slotQsoUploadFinished(QNetworkReply *data)
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-        //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = Host Not found! = " << QString::number(result)  << endl;
+        //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = Host Not found! = " << QString::number(result)  << QT_ENDL;
         text = "eQSL: " + tr("Host not found!");
         //TODO: Mark the previous QSO as not sent to clublog
     }
     else if (result == QNetworkReply::TimeoutError)
     {
-        //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = Time out error! = " << QString::number(result)  << endl;
+        //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = Time out error! = " << QString::number(result)  << QT_ENDL;
         text = "eQSL: " + tr("Timeout error!");
         //TODO: Mark the previous QSO as not sent to clublog
     }
     else
     {
-        //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = UNDEFINED = " << QString::number(result)  << endl;
+        //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = UNDEFINED = " << QString::number(result)  << QT_ENDL;
         text = "eQSL: " + tr("Undefined error number (#%1)... ").arg(result);
-        int i = QMessageBox::warning(nullptr, tr("KLog - eQSL"),
+        QMessageBox::warning(nullptr, tr("KLog - eQSL"),
                                        tr("We have received an undefined error from eQSL (%1)").arg(result) + "\n" +
                                           tr("Please check your config in the setup and contact the KLog development team if you can't fix it. eQSL uploads will be disabled."),
                                        QMessageBox::Ok);
         //TODO: Mark the previous QSO as not sent to clublog
     }
 
-    //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = " << QString::number(result) << endl;
+    //qDebug()<< "eQSLUtilities::slotQsoUploadFinished - Result = " << QString::number(result) << QT_ENDL;
     //emit done();
     emit signalFileUploaded(result, qsos);
     emit showMessage(text);
@@ -136,7 +140,7 @@ void eQSLUtilities::slotQsoUploadFinished(QNetworkReply *data)
 }
 
 void eQSLUtilities::downloadProgress(qint64 received, qint64 total) {
-       //qDebug()<< "eQSLUtilities::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << endl;
+       //qDebug()<< "eQSLUtilities::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << QT_ENDL;
 
        //qDebug()<< received << total;
     emit actionShowProgres(received, total);
@@ -144,7 +148,7 @@ void eQSLUtilities::downloadProgress(qint64 received, qint64 total) {
 
 void eQSLUtilities::slotErrorManagement(QNetworkReply::NetworkError networkError)
 {
-       //qDebug()<< "eQSLUtilities::slotErrorManagement: " << QString::number(networkError) << endl;
+       //qDebug()<< "eQSLUtilities::slotErrorManagement: " << QString::number(networkError) << QT_ENDL;
     result = networkError;
 
     if (result == QNetworkReply::NoError)
@@ -152,19 +156,19 @@ void eQSLUtilities::slotErrorManagement(QNetworkReply::NetworkError networkError
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-            //qDebug()<< "eQSLUtilities::slotErrorManagement: Host not found" << endl;
+            //qDebug()<< "eQSLUtilities::slotErrorManagement: Host not found" << QT_ENDL;
     }
     else
     {
-            //qDebug()<< "eQSLUtilities::slotErrorManagement: ERROR!" << endl;
+            //qDebug()<< "eQSLUtilities::slotErrorManagement: ERROR!" << QT_ENDL;
     }
 
     //actionError(result);
 }
 
-void eQSLUtilities::setCredentials(const QString &_user, const QString &_pass, const QString _defaultStationCallsign)
+void eQSLUtilities::setCredentials(const QString &_user, const QString &_pass, const QString &_defaultStationCallsign)
 {
-    //qDebug()<< "eQSLUtilities::setCredentials: user: " << _user << " / Pass: " << _pass << " / StationCallsign: " << _defaultStationCallsign << endl;
+    //qDebug()<< "eQSLUtilities::setCredentials: user: " << _user << " / Pass: " << _pass << " / StationCallsign: " << _defaultStationCallsign << QT_ENDL;
     stationCallsign = _defaultStationCallsign;
     user = _user;
     pass = _pass;
@@ -172,7 +176,7 @@ void eQSLUtilities::setCredentials(const QString &_user, const QString &_pass, c
 
 QStringList eQSLUtilities::prepareToTranslate(const QString &_m)
 {
-    //qDebug()<< "eQSLUtilities:: = prepareToTranslate" << _m << endl;
+    //qDebug()<< "eQSLUtilities:: = prepareToTranslate" << _m << QT_ENDL;
     QString msg = _m;
     QStringList result;
     result.clear();
@@ -196,7 +200,7 @@ QStringList eQSLUtilities::prepareToTranslate(const QString &_m)
     {
         result << "Unknown" << "Unknown";
     }
-    //qDebug()<< "eQSLUtilities:: = prepareToTranslate returning... "  << endl;
+    //qDebug()<< "eQSLUtilities:: = prepareToTranslate returning... "  << QT_ENDL;
 
 
     return result;
@@ -204,7 +208,7 @@ QStringList eQSLUtilities::prepareToTranslate(const QString &_m)
 
 void eQSLUtilities::sendLogFile(const QString &_file, QList<int> _qso)
 {
-     //qDebug()<< "eQSLUtilities::sendLogFile: " << _file << endl;
+     //qDebug()<< "eQSLUtilities::sendLogFile: " << _file << QT_ENDL;
     qsos.clear();
     qsos.append(_qso);
     QUrl serviceUrl;
@@ -224,18 +228,18 @@ void eQSLUtilities::sendLogFile(const QString &_file, QList<int> _qso)
     if (file->open(QIODevice::ReadOnly)) /* Flawfinder: ignore */
     {
          blob = file->readAll();
-        //qDebug()<< "eQSLUtilities::sendLogFile: FILE OPEN: " << blob << endl;
+        //qDebug()<< "eQSLUtilities::sendLogFile: FILE OPEN: " << blob << QT_ENDL;
     }
     else
     {
-         //qDebug()<< "eQSLUtilities::sendLogFile: ERROR File not opened" << endl;
+         //qDebug()<< "eQSLUtilities::sendLogFile: ERROR File not opened" << QT_ENDL;
         return;
     }
     file->close();
     // The rest of the form goes as usual
-     //qDebug()<< "eQSLUtilities::sendLogFile: e: " << user << endl;
-     //qDebug()<< "eQSLUtilities::sendLogFile: pass: " << pass << endl;
-     //qDebug()<< "eQSLUtilities::sendLogFile: stationcall: " << stationCallsign << endl;
+     //qDebug()<< "eQSLUtilities::sendLogFile: e: " << user << QT_ENDL;
+     //qDebug()<< "eQSLUtilities::sendLogFile: pass: " << pass << QT_ENDL;
+     //qDebug()<< "eQSLUtilities::sendLogFile: stationcall: " << stationCallsign << QT_ENDL;
 
     QHttpPart userPart;
     userPart.setHeader(QNetworkRequest::ContentDispositionHeader, QVariant("form-data; name=\"eqsl_user\""));
@@ -267,11 +271,11 @@ void eQSLUtilities::sendLogFile(const QString &_file, QList<int> _qso)
 
     uploadingFile = true;
     QNetworkRequest request(serviceUrl);
-    //qDebug()<< "eQSLUtilities::sendLogFile: Before sending" << endl;
+    //qDebug()<< "eQSLUtilities::sendLogFile: Before sending" << QT_ENDL;
     manager->post(request, multiPart);
-    //qDebug()<< "eQSLUtilities::sendLogFile: After sending" << endl;
+    //qDebug()<< "eQSLUtilities::sendLogFile: After sending" << QT_ENDL;
     //multiPart->setParent(reply);
-    //qDebug()<< "eQSLUtilities::sendLogFile - END" << endl;
+    //qDebug()<< "eQSLUtilities::sendLogFile - END" << QT_ENDL;
 
 }
 
