@@ -35,19 +35,19 @@ FileAwardManager::FileAwardManager(DataProxy_SQLite *dp, const QString &_parentF
 
 bool FileAwardManager::importNewAwardFile()
 {
-    //qDebug() << "FileAwardManager::importNewAwardFile"  << endl;
+    //qDebug() << "FileAwardManager::importNewAwardFile"  << QT_ENDL;
     QString fileName = QFileDialog::getOpenFileName(nullptr, tr("Open Award file"), util->getHomeDir(), tr("Award files (*.awa)"));
-    //qDebug() << "FileAwardManager::importNewAwardFile - file: " << fileName  << endl;
+    //qDebug() << "FileAwardManager::importNewAwardFile - file: " << fileName  << QT_ENDL;
     QFile file( fileName );
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) /* Flawfinder: ignore */
     {
-        //qDebug() << "FileAwardManager::importNewAwardFile File not found" << fileName << endl;
+        //qDebug() << "FileAwardManager::importNewAwardFile File not found" << fileName << QT_ENDL;
         showError(tr("Award file not opened"), tr("KLog was not able to read the award file"), QString(tr("It was not possible to open the file %1 for reading.") ).arg(fileName));
         return false;
     }
     else
     {
-        //qDebug() << "FileAwardManager::importNewAwardFile File opened" << endl;
+        //qDebug() << "FileAwardManager::importNewAwardFile File opened" << QT_ENDL;
     }
 
     QString line = QString();
@@ -71,18 +71,18 @@ bool FileAwardManager::importNewAwardFile()
 
     while ( !file.atEnd() )
     { // KLog first read the full file, to detect potential format errors and counting the number of references
-        //qDebug() << "FileAwardManager::importNewAwardFile: First read, counting and looking for errors: " << line << endl;
+        //qDebug() << "FileAwardManager::importNewAwardFile: First read, counting and looking for errors: " << line << QT_ENDL;
 
         line = file.readLine().trimmed().toUpper();
-        //qDebug() << "FileAwardManager::importNewAwardFile: " << line << endl;
+        //qDebug() << "FileAwardManager::importNewAwardFile: " << line << QT_ENDL;
         number = number + line.count("EOR>");
         if ((line.count("<EOH>")>0) )
         {
             hasEOH = true;
         }
-        //qDebug() << " //FileAwardManager::importNewAwardFile in the while, end of loop"  << endl;
+        //qDebug() << " //FileAwardManager::importNewAwardFile in the while, end of loop"  << QT_ENDL;
     }
-    //qDebug() << "FileAwardManager::importNewAwardFile: While finished "  << endl;
+    //qDebug() << "FileAwardManager::importNewAwardFile: While finished "  << QT_ENDL;
     if (!hasEOH)
     {
         showError(tr("AWA wrong format"), tr("The AWA file does not have the right format"), QString(tr("AWA file does not have an <EOH> field") ));
@@ -99,7 +99,7 @@ bool FileAwardManager::importNewAwardFile()
     {
         line = (file.readLine()).toUpper();
         fields.clear();
-        fields << line.split("<", QString::SkipEmptyParts);
+        fields << line.split("<", QT_SKIP);
         if (!hasEOH)
         { // Lets read the HEADER
             // IF EOH
@@ -110,7 +110,7 @@ bool FileAwardManager::importNewAwardFile()
 
             foreach (aux, fields)
             {
-                //qDebug() << "FileAwardManager::importNewAwardFile: Reading header: " << aux << endl;
+                //qDebug() << "FileAwardManager::importNewAwardFile: Reading header: " << aux << QT_ENDL;
                 aux = aux.trimmed();
                 aux = "<" + aux;
                 QStringList adifField;
@@ -141,7 +141,7 @@ bool FileAwardManager::importNewAwardFile()
 
                     else
                     {
-                        //qDebug() << "FileAwardManager::importNewAwardFile: Invalid AWA field found HEADER" << adifField.at(0) << endl;
+                        //qDebug() << "FileAwardManager::importNewAwardFile: Invalid AWA field found HEADER" << adifField.at(0) << QT_ENDL;
                     }
 
                 }
@@ -151,7 +151,7 @@ bool FileAwardManager::importNewAwardFile()
         else
         { // NOT in EOH
             // Read line, MODIFY AWARD
-            //qDebug() << "FileAwardManager::importNewAwardFile: Parsing : " << line << endl;
+            //qDebug() << "FileAwardManager::importNewAwardFile: Parsing : " << line << QT_ENDL;
             foreach (aux, fields)
             {
                 aux = aux.trimmed();
@@ -159,10 +159,10 @@ bool FileAwardManager::importNewAwardFile()
                 QStringList adifField;
                 adifField.clear();
                 adifField << util->getValidADIFFieldAndData(aux);
-                //qDebug() << "FileAwardManager::importNewAwardFile: Length: " << QString::number(adifField.count()) << endl;
+                //qDebug() << "FileAwardManager::importNewAwardFile: Length: " << QString::number(adifField.count()) << QT_ENDL;
                 if (adifField.count()==2)
                 {
-                    //qDebug() << "FileAwardManager::importNewAwardFile: Parsing : (" << adifField.at(0) << "/" << adifField.at(1) << ")" << endl;
+                    //qDebug() << "FileAwardManager::importNewAwardFile: Parsing : (" << adifField.at(0) << "/" << adifField.at(1) << ")" << QT_ENDL;
                     if (adifField.at(0) == "SUBDIV_REFNUMBER" )
                     {
                         sub_regionalID = adifField.at(1).toInt();
@@ -197,7 +197,7 @@ bool FileAwardManager::importNewAwardFile()
                     }
                     else if (adifField.at(0) == "EOR")
                     {// END OF REGISTRY
-                        //qDebug() << "FileAwardManager::importNewAwardFile: EOR FOUND!\nLet's add the reference." << endl;
+                        //qDebug() << "FileAwardManager::importNewAwardFile: EOR FOUND!\nLet's add the reference." << QT_ENDL;
                         QStringList _subDiv;
                         dataProxy->addDXCCEntitySubdivision(sub_name, sub_shortname, sub_prefix, sub_regionalGroup,
                                                             sub_regionalID, sub_dxcc, sub_cqz, sub_ituz, sub_startDate, sub_endDate, sub_deleted);
@@ -215,7 +215,7 @@ bool FileAwardManager::importNewAwardFile()
                     }
                  else
                 {
-                    //qDebug() << "FileAwardManager::importNewAwardFile: Invalid AWA field found in BODY" << adifField.at(0) << endl;
+                    //qDebug() << "FileAwardManager::importNewAwardFile: Invalid AWA field found in BODY" << adifField.at(0) << QT_ENDL;
                 }
             }}
         }
@@ -224,9 +224,9 @@ bool FileAwardManager::importNewAwardFile()
     return false;
 }
 
-void FileAwardManager::showError(const QString _header, const QString _msg, const QString _detailedMsg)
+void FileAwardManager::showError(const QString &_header, const QString &_msg, const QString &_detailedMsg)
 {
-    //qDebug() << "FileAwardManager::showError: " << _msg << endl;
+    //qDebug() << "FileAwardManager::showError: " << _msg << QT_ENDL;
     QMessageBox msgBox;
     msgBox.setIcon(QMessageBox::Warning);
     msgBox.setWindowTitle(tr("KLog - %1").arg(_header));
