@@ -31,11 +31,13 @@
 #include <QTimer>
 #include <QMap>
 #include <QDebug>
-#include <QSerialPort>
+//#include <QSerialPort>
+#include <QtSerialPort/QSerialPort>
 #include <hamlib/rig.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include "klogdefinitions.h"
 
 // Potential fix of hamlib 4.2 migration
 #ifndef HAMLIB_FILPATHLEN
@@ -60,11 +62,11 @@ public:
     void setPort(const QString &_port);
     void setPoll(const int _milsecs);
 
-    void setData(const QString &_data);
-    void setStop(const QString &_stop);
+    void setDataBits(const int data);
+    void setStop(const int _stop);
     void setFlow(const QString &_flow);
     void setParity(const QString &_parity);
-    void setSpeed(const QString &_speed);
+    void setSpeed(const int _speed);
     void setRTS(const QString &_state);
     void setDTR(const QString &_state);
 
@@ -74,16 +76,17 @@ public:
     bool isModeADIFMode(const QString &_m);
     void setNetworkAddress(const QString &_address);
     void setNetworkPort(const int _port);
-   // bool isModeExisting(const QString &_m);
-
 
     bool init(bool _active);
     bool stop();
     bool readRadio(bool _forceRead);
     bool isRunning();
+    void initClass();
     void clean();
     void checkErrorCountAndStop();
 
+    double getFrequency();
+    //void showDebugLog(const QString &_func, const QString &_log);
     //bool openSerialPort();
     //bool closeSerialPort();
 
@@ -99,6 +102,7 @@ private:
     bool readRadioInternal(bool _forceRead);
     static int addRigToList(const struct rig_caps* caps, void* data);
     QString hamlibMode2Mode(rmode_t _rmode);
+    bool errorManage(const QString &_func, const int _errorcode);
     //rmode_t mode2HamlibMode(const QString &_m);
     QStringList strings;
     QTimer *timer;
@@ -112,7 +116,6 @@ private:
     serial_handshake_e shandshake;
     serial_control_state_e srts, sdtr;
 
-
     int retcode;                // generic return code from functions
 
     rig_model_t myrig_model;    // Integer radio model
@@ -120,10 +123,8 @@ private:
 
 
     pbwidth_t width;
-    vfo_t vfo;              /* vfo selection */
-    int strength;           /* S-Meter level */
-
-
+    //vfo_t vfo;              /* vfo selection */
+    //int strength;           /* S-Meter level */
 
     int bauds;                  // default 9600
     int dataBits;               // default 8
@@ -138,6 +139,7 @@ private:
     bool rigLaunched;
     bool readOnlyMode;          // If true, KLog will not modify any parameter (freq/mode...) in the radio. KLog just will follow the radio.
     bool justEmitted;
+    bool reading;   // Just a semaphore to prevent several readings
     //bool active;
 
     //QSerialPort *m_serial;
