@@ -29,7 +29,7 @@
 MainWindowInputEQSL::MainWindowInputEQSL(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
 {
-       //qDebug() << "MainWindowInputEQSL::MainWindowInputEQSL"   << endl;
+       //qDebug() << "MainWindowInputEQSL::MainWindowInputEQSL"   << QT_ENDL;
     util = new Utilities;
     dataProxy = dp;
 
@@ -50,7 +50,7 @@ MainWindowInputEQSL::MainWindowInputEQSL(DataProxy_SQLite *dp, QWidget *parent)
     createUI();
     setDefaultData();
     clear();
-       //qDebug() << "MainWindowInputEQSL::MainWindowInputEQSL - END"   << endl;
+       //qDebug() << "MainWindowInputEQSL::MainWindowInputEQSL - END"   << QT_ENDL;
 }
 
 void MainWindowInputEQSL::createUI()
@@ -129,12 +129,12 @@ void MainWindowInputEQSL::createUI()
     //eqslInputTabWidgetLayout->setSizeConstraint(QLayout::SetFixedSize);
     setLayout(eqslInputTabWidgetLayout);
 
-    connect(clublogComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotClubLogComboBoxChanged() ) )  ;
-    connect(eqslSentComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(sloteQSLSentComboBoxChanged() ) )  ;
-    connect(eqslRecComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(sloteQSLRecvComboBoxChanged() ) ) ;
-    connect(lotwSentComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotLotwSentComboBoxChanged() ) )  ;
-    connect(lotwRecComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotLotwRecvComboBoxChanged() ) ) ;
-    connect(qrzcomComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotQRZCOMComboBoxChanged() ) )  ;
+    connect(clublogComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotClubLogComboBoxChanged() ) )  ;
+    connect(eqslSentComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(sloteQSLSentComboBoxChanged() ) )  ;
+    connect(eqslRecComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(sloteQSLRecvComboBoxChanged() ) ) ;
+    connect(lotwSentComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotLotwSentComboBoxChanged() ) )  ;
+    connect(lotwRecComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotLotwRecvComboBoxChanged() ) ) ;
+    connect(qrzcomComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotQRZCOMComboBoxChanged() ) )  ;
 
 }
 
@@ -169,7 +169,7 @@ void MainWindowInputEQSL::setDefaultData()
 }
 void MainWindowInputEQSL::clear()
 {
-      //qDebug() << "MainWindowInputEQSL::clear"  << endl;
+      //qDebug() << "MainWindowInputEQSL::clear"  << QT_ENDL;
      // Do not upload
     if (queueSentByDefault)
     {
@@ -202,7 +202,7 @@ void MainWindowInputEQSL::clear()
 QString MainWindowInputEQSL::getClubLogStatus()
 {
     QString _pm = QString();
-    //qDebug() << "MainWindowInputEQSL::getClubLogStatus:" << clublogComboBox->currentText() << endl;
+    //qDebug() << "MainWindowInputEQSL::getClubLogStatus:" << clublogComboBox->currentText() << QT_ENDL;
      _pm = (((clublogComboBox->currentText()).split('-')).at(0)).simplified();
      return _pm;
 }
@@ -217,9 +217,9 @@ QString MainWindowInputEQSL::getQRZCOMStatus()
 QString MainWindowInputEQSL::getEQSLRecStatus()
 {
    QString _pm = QString();
-    //qDebug() << "MainWindowInputEQSL::getEQSLRecStatus:" << eqslRecComboBox->currentText() << endl;
+    //qDebug() << "MainWindowInputEQSL::getEQSLRecStatus:" << eqslRecComboBox->currentText() << QT_ENDL;
     _pm = (((eqslRecComboBox->currentText()).split('-')).at(0)).simplified();
-    //qDebug() << "MainWindowInputEQSL::getEQSLRecStatus: " << _pm << endl;
+    //qDebug() << "MainWindowInputEQSL::getEQSLRecStatus: " << _pm << QT_ENDL;
     //if (_pm == "Not")
     //{
     //    return QString();
@@ -231,9 +231,9 @@ QString MainWindowInputEQSL::getEQSLRecStatus()
 QString MainWindowInputEQSL::getEQSLSenStatus()
 {
     QString _pm = QString();
-     //qDebug() << "MainWindowInputEQSL::getEQSLSenStatus:" << eqslSentComboBox->currentText() << endl;
+     //qDebug() << "MainWindowInputEQSL::getEQSLSenStatus:" << eqslSentComboBox->currentText() << QT_ENDL;
      _pm = (((eqslSentComboBox->currentText()).split('-')).at(0)).simplified();
-     //qDebug() << "MainWindowInputEQSL::getEQSLSenStatus: " << _pm << endl;
+     //qDebug() << "MainWindowInputEQSL::getEQSLSenStatus: " << _pm << QT_ENDL;
      //if (_pm == "Not")
      //{
      //    return QString();
@@ -244,9 +244,9 @@ QString MainWindowInputEQSL::getEQSLSenStatus()
 QString MainWindowInputEQSL::getLOTWRecStatus()
 {
     QString _pm = QString();
-     //qDebug() << "MainWindowInputEQSL::getLOTWRecStatus:" << lotwRecComboBox->currentText() << endl;
+     //qDebug() << "MainWindowInputEQSL::getLOTWRecStatus:" << lotwRecComboBox->currentText() << QT_ENDL;
      _pm = (((lotwRecComboBox->currentText()).split('-')).at(0)).simplified();
-     //qDebug() << "MainWindowInputEQSL::getLOTWRecStatus: " << _pm << endl;
+     //qDebug() << "MainWindowInputEQSL::getLOTWRecStatus: " << _pm << QT_ENDL;
      //if (_pm == "Not")
      //{
      //    return QString();
@@ -257,9 +257,9 @@ QString MainWindowInputEQSL::getLOTWRecStatus()
 QString MainWindowInputEQSL::getLOTWSenStatus()
 {
     QString _pm = QString();
-     //qDebug() << "MainWindowInputEQSL::getLOTWSenStatus:" << lotwSentComboBox->currentText() << endl;
+     //qDebug() << "MainWindowInputEQSL::getLOTWSenStatus:" << lotwSentComboBox->currentText() << QT_ENDL;
      _pm = (((lotwSentComboBox->currentText()).split('-')).at(0)).simplified();
-     //qDebug() << "MainWindowInputEQSL::getLOTWSenStatus: " << _pm << endl;
+     //qDebug() << "MainWindowInputEQSL::getLOTWSenStatus: " << _pm << QT_ENDL;
      //if (_pm == "Not")
      //{
      //    return QString();
@@ -268,9 +268,9 @@ QString MainWindowInputEQSL::getLOTWSenStatus()
 }
 
 
-void MainWindowInputEQSL::setClubLogStatus(const QString _qs)
+void MainWindowInputEQSL::setClubLogStatus(const QString &_qs)
 {
-       //qDebug() << "MainWindowInputEQSL::setClubLogStatus: " << _qs << endl;
+       //qDebug() << "MainWindowInputEQSL::setClubLogStatus: " << _qs << QT_ENDL;
     if((( clublogComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
      {
          clublogComboBox->setCurrentIndex( clublogComboBox->findText(_qs+" -", Qt::MatchStartsWith));
@@ -281,9 +281,9 @@ void MainWindowInputEQSL::setClubLogStatus(const QString _qs)
      }
 }
 
-void MainWindowInputEQSL::setQRZCOMStatus(const QString _qs)
+void MainWindowInputEQSL::setQRZCOMStatus(const QString &_qs)
 {
-       //qDebug() << "MainWindowInputEQSL::setClubLogStatus: " << _qs << endl;
+       //qDebug() << "MainWindowInputEQSL::setClubLogStatus: " << _qs << QT_ENDL;
     if((( qrzcomComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
      {
          qrzcomComboBox->setCurrentIndex( qrzcomComboBox->findText(_qs+" -", Qt::MatchStartsWith));
@@ -294,9 +294,9 @@ void MainWindowInputEQSL::setQRZCOMStatus(const QString _qs)
      }
 }
 
-void MainWindowInputEQSL::setEQSLRecStatus(const QString _qs)
+void MainWindowInputEQSL::setEQSLRecStatus(const QString &_qs)
 {
-       //qDebug() << "MainWindowInputEQSL::setEQSLRecStatus: " << _qs << endl;
+       //qDebug() << "MainWindowInputEQSL::setEQSLRecStatus: " << _qs << QT_ENDL;
      //if(( eqslRecComboBox->findText(_qs+" -", Qt::MatchStartsWith))>=0)
     if((( eqslRecComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
      {
@@ -308,39 +308,39 @@ void MainWindowInputEQSL::setEQSLRecStatus(const QString _qs)
      }
 }
 
-void MainWindowInputEQSL::setEQSLSenStatus(const QString _qs)
+void MainWindowInputEQSL::setEQSLSenStatus(const QString &_qs)
 {
-    //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: #" << _qs+" -" << endl;
+    //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: #" << _qs+" -" << QT_ENDL;
 
      if((( eqslSentComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
      {
-         //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: found: " << _qs << " - Index: " << QString::number(eqslSentComboBox->findText(_qs, Qt::MatchStartsWith)) << endl;
+         //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: found: " << _qs << " - Index: " << QString::number(eqslSentComboBox->findText(_qs, Qt::MatchStartsWith)) << QT_ENDL;
          eqslSentComboBox->setCurrentIndex( eqslSentComboBox->findText(_qs, Qt::MatchStartsWith));
      }
      else
      {
-        //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: NOT found" << endl;
+        //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: NOT found" << QT_ENDL;
          if (queueSentByDefault)
          {
-             //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: NOT found - Q is defined by default" << endl;
+             //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: NOT found - Q is defined by default" << QT_ENDL;
               eqslSentComboBox->setCurrentIndex( eqslSentComboBox->findText("Q", Qt::MatchStartsWith));
          }
          else
          {
-             //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: NOT found - Q is NOT defined by default" << endl;
+             //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: NOT found - Q is NOT defined by default" << QT_ENDL;
              eqslSentComboBox->setCurrentIndex( eqslSentComboBox->findText("N", Qt::MatchStartsWith));
              eqslSentComboBox->setCurrentIndex(1);
          }
 
-        //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: NOT found" << endl;
+        //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: NOT found" << QT_ENDL;
          //eqslSentComboBox->setCurrentIndex(1);
      }
-     //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus - END" << endl;
+     //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus - END" << QT_ENDL;
 }
 
-void MainWindowInputEQSL::setLOTWRecStatus(const QString _qs)
+void MainWindowInputEQSL::setLOTWRecStatus(const QString &_qs)
 {
-      //qDebug() << "MainWindowInputEQSL::setLOTWRecStatus: " << _qs << endl;
+      //qDebug() << "MainWindowInputEQSL::setLOTWRecStatus: " << _qs << QT_ENDL;
     if((( lotwRecComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
      //if(( lotwRecComboBox->findText(_qs+" -", Qt::MatchStartsWith))>=0)
      {
@@ -353,9 +353,9 @@ void MainWindowInputEQSL::setLOTWRecStatus(const QString _qs)
 }
 
 
-void MainWindowInputEQSL::setLOTWSenStatus(const QString _qs)
+void MainWindowInputEQSL::setLOTWSenStatus(const QString &_qs)
 {
-      //qDebug() << "MainWindowInputEQSL::setLOTWSenStatus: " << _qs << endl;
+      //qDebug() << "MainWindowInputEQSL::setLOTWSenStatus: " << _qs << QT_ENDL;
     if((( lotwSentComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
      //if(( lotwSentComboBox->findText(_qs+" -", Qt::MatchStartsWith))>=0)
      {
@@ -378,7 +378,7 @@ void MainWindowInputEQSL::setLOTWSenStatus(const QString _qs)
 
 
 void MainWindowInputEQSL::slotLotwRecvComboBoxChanged(){
-       //qDebug() << "MainWindowInputEQSL::slotLotwRecvComboBoxChanged" << endl;
+       //qDebug() << "MainWindowInputEQSL::slotLotwRecvComboBoxChanged" << QT_ENDL;
 
 //QSLRDATE (only valid if QSL_RCVD is Y-0, I-3, or V-4)
 //Y-Yes-0
@@ -417,7 +417,7 @@ void MainWindowInputEQSL::slotLotwRecvComboBoxChanged(){
 
 
 void MainWindowInputEQSL::slotLotwSentComboBoxChanged(){
-       //qDebug() << "MainWindowInputEQSL::slotLotwSentComboBoxChanged" << endl;
+       //qDebug() << "MainWindowInputEQSL::slotLotwSentComboBoxChanged" << QT_ENDL;
 
     int i = lotwSentComboBox->currentIndex();
 //{Y, N, R, I, V}
@@ -454,7 +454,7 @@ void MainWindowInputEQSL::slotLotwSentComboBoxChanged(){
 
 
 void MainWindowInputEQSL::sloteQSLRecvComboBoxChanged(){
-       //qDebug() << "MainWindowInputEQSL::sloteQSLRecvComboBoxChanged" << endl;
+       //qDebug() << "MainWindowInputEQSL::sloteQSLRecvComboBoxChanged" << QT_ENDL;
 
 //QSLRDATE (only valid if QSL_RCVD is Y-0, I-3, or V-4)
 //Y-Yes-0
@@ -494,7 +494,7 @@ void MainWindowInputEQSL::sloteQSLRecvComboBoxChanged(){
 
 
 void MainWindowInputEQSL::sloteQSLSentComboBoxChanged(){
-       //qDebug() << "MainWindowInputEQSL::sloteQSLSentComboBoxChanged" << endl;
+       //qDebug() << "MainWindowInputEQSL::sloteQSLSentComboBoxChanged" << QT_ENDL;
 
     int i = eqslSentComboBox->currentIndex();
 //{Y, N, R, I, V}
