@@ -30,7 +30,7 @@
 MainWindowInputOthers::MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
 {
-       //qDebug() << "MainWindowInputOthers::MainWindowInputOthers" << endl;
+       //qDebug() << "MainWindowInputOthers::MainWindowInputOthers" << QT_ENDL;
     entitiesList.clear();
     propModeList.clear();
     adifValidTypes.clear();
@@ -39,7 +39,7 @@ MainWindowInputOthers::MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *pare
     propModeList = dataProxy->getPropModeList();
     sota_ref = QString();
     age = 0;
-
+    util = new Utilities;
     //QLabel *entityPrimLabel, *entitySecLabel, *iotaAwardLabel, *entityNameLabel, *propModeLabel;
     iotaContinentComboBox = new QComboBox();
     entityPrimDivComboBox = new QComboBox();
@@ -54,20 +54,20 @@ MainWindowInputOthers::MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *pare
     // TODO: I should find the way to connect the SAT tabwidget's signal to set the propmode in this widget
     //       Now it is done though the mainwindow but I should avoid depending on that class for that, if possible
     //connect(satTabWidget, SIGNAL(setPropModeSat(QString)), this, SLOT(slotSetPropMode(QString)) ) ;
-    connect(propModeComboBox, SIGNAL(currentIndexChanged (int)), this, SLOT(slotPropModeComboBoxChanged() ) ) ;
-    connect(userDefinedADIFComboBox, SIGNAL(currentIndexChanged (int)), this, SLOT(slotUSerDefinedADIFComboBoxChanged() ) ) ;
+    connect(propModeComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotPropModeComboBoxChanged() ) ) ;
+    connect(userDefinedADIFComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUSerDefinedADIFComboBoxChanged() ) ) ;
     connect(userDefinedADIFValueLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotSetCurrentUSerData() ) );
 
     createUI();
     setInitialADIFValues ();
-       //qDebug() << "MainWindowInputOthers::MainWindowInputOthers - END" << endl;
+       //qDebug() << "MainWindowInputOthers::MainWindowInputOthers - END" << QT_ENDL;
 }
 
 MainWindowInputOthers::~MainWindowInputOthers(){}
 
 void MainWindowInputOthers::createUI()
 {
-      //qDebug() << "MainWindowInputOthers::createUI" << endl;
+      //qDebug() << "MainWindowInputOthers::createUI" << QT_ENDL;
 
     palRed.setColor(QPalette::Text, Qt::red);
     palBlack.setColor(QPalette::Text, Qt::black);
@@ -154,7 +154,7 @@ void MainWindowInputOthers::createUI()
 
 void MainWindowInputOthers::clear(bool _full)
 {
-      //qDebug() << "MainWindowInputOthers::clear" << endl;
+      //qDebug() << "MainWindowInputOthers::clear" << QT_ENDL;
     entityNameComboBox->setCurrentIndex(0);
     userDefinedADIFComboBox->setCurrentIndex (0);
     userDefinedADIFValueLineEdit->clear ();
@@ -175,7 +175,7 @@ void MainWindowInputOthers::clear(bool _full)
 
 void MainWindowInputOthers::setEntitiesList(const QStringList _qs)
 {
-      //qDebug() << "MainWindowInputOthers::setEntitiesList: " << QString::number(_qs.length()) << endl;
+      //qDebug() << "MainWindowInputOthers::setEntitiesList: " << QString::number(_qs.length()) << QT_ENDL;
     entitiesList.clear();
     entitiesList << _qs;
     if (entitiesList.size()>1)
@@ -188,7 +188,7 @@ void MainWindowInputOthers::setEntitiesList(const QStringList _qs)
 
 void MainWindowInputOthers::setEntity(const int _ent)
 {// Select the appropriate entity in the ComboBox
-       //qDebug() << "MainWindowInputOthers::setEntity: " << QString::number(_ent) << endl;
+       //qDebug() << "MainWindowInputOthers::setEntity: " << QString::number(_ent) << QT_ENDL;
     if (_ent<=0)
     {
         entityNameComboBox->setCurrentIndex(0);
@@ -201,12 +201,12 @@ void MainWindowInputOthers::setEntity(const int _ent)
         aux = (QString::number(_ent)).right(3);
     }
 
-    QString pref = dataProxy->getEntityNameFromId(_ent);
+    //QString pref = dataProxy->getEntityNameFromId(_ent);
 
     //int indexC = entityNameComboBox->f
     int indexC = entityNameComboBox->findText("(" + aux + ")", Qt::MatchEndsWith);
 
-       //qDebug() << "MainWindow::selectCorrectEntity: " << pref << "/" << QString::number(indexC) << endl;
+       //qDebug() << "MainWindow::selectCorrectEntity: " << pref << "/" << QString::number(indexC) << QT_ENDL;
     entityNameComboBox->setCurrentIndex(indexC);
     setIOTAContinentFromEntity(_ent);
 
@@ -219,19 +219,24 @@ int MainWindowInputOthers::getEntity()
     {
         return -1;
     }
-    return (aux.split('(').at(1).chopped (1)).toInt ();
+    //qDebug() << Q_FUNC_INFO << ": " << (aux.split('(').at(1).chopped(1));
+    //return (aux.split('(').at(1).chopped(1)).toInt ();
+    QString a = aux.split('(').at(1);
+    a.chop(1);
+    //qDebug() << Q_FUNC_INFO << ": " << a;
+    return a.toInt ();
 }
 
 QString MainWindowInputOthers::getEntityPrefix()
 {
-    //qDebug() << "MainWindowInputOthers::getEntityPrefix: " << (entityNameComboBox->currentText()).split('-').at(0) << endl;
+    //qDebug() << "MainWindowInputOthers::getEntityPrefix: " << (entityNameComboBox->currentText()).split('-').at(0) << QT_ENDL;
     return (entityNameComboBox->currentText()).split('-').at(0);
     //return world->getQRZARRLId(pref);
 }
 
-void MainWindowInputOthers::setPropMode(const QString _qs, bool _keep)
+void MainWindowInputOthers::setPropMode(const QString &_qs, bool _keep)
 {
-      //qDebug() << "MainWindowInputOthers::setPropMode: " << _qs << endl;
+      //qDebug() << "MainWindowInputOthers::setPropMode: " << _qs << QT_ENDL;
     autoUpdating = true;
     if(( propModeComboBox->findText(_qs+" -", Qt::MatchContains))>0)
     {
@@ -249,10 +254,10 @@ void MainWindowInputOthers::setPropMode(const QString _qs, bool _keep)
 QString MainWindowInputOthers::getPropModeFromComboBox()
 {
     QString _pm = QString();
-      //qDebug() << "MainWindow::getPropModeFromComboBox:" << propModeComboBox->currentText() << endl;
+      //qDebug() << "MainWindow::getPropModeFromComboBox:" << propModeComboBox->currentText() << QT_ENDL;
     _pm = (((propModeComboBox->currentText()).split('-')).at(1)).simplified();
     QString _n = (((propModeComboBox->currentText()).split('-')).at(0)).simplified();
-      //qDebug() << "MainWindow::getPropModeFromComboBox: " << _pm << endl;
+      //qDebug() << "MainWindow::getPropModeFromComboBox: " << _pm << QT_ENDL;
 
     if (_n == "00")
     {
@@ -294,11 +299,11 @@ bool MainWindowInputOthers::isIOTAModified()
 
 }
 
-void MainWindowInputOthers::setIOTA(const QString _qs)
+void MainWindowInputOthers::setIOTA(const QString &_qs)
 {//TODO: Seems to be better to send the color info like in: (it is much more flexible as I can send any color!)
 
-    //void MainWindowInputQSL::setQSLVia(const QString _qs, QColor qColor)
-      //qDebug() << "MainWindow::setIOTA: " << _qs << endl;
+    //void MainWindowInputQSL::setQSLVia(const QString &_qs, QColor qColor)
+      //qDebug() << "MainWindow::setIOTA: " << _qs << QT_ENDL;
     if ( (checkIfValidIOTA(_qs)).length() !=6 )
     {
         iotaNumberLineEdit->setPalette(palRed);
@@ -306,8 +311,8 @@ void MainWindowInputOthers::setIOTA(const QString _qs)
     }
     else
     {
-        QStringList values = _qs.split("-", QString::SkipEmptyParts);
-          //qDebug() << "MainWindowInputOthers::setIOTA: IOTA " << _qs << endl;
+        QStringList values = _qs.split("-", QT_SKIP);
+          //qDebug() << "MainWindowInputOthers::setIOTA: IOTA " << _qs << QT_ENDL;
         iotaContinentComboBox->setCurrentIndex( iotaContinentComboBox->findText(values.at(0) ) );
         iotaNumberLineEdit->setText(values.at(1));
         if (getDarkMode())
@@ -329,27 +334,27 @@ QString MainWindowInputOthers::getIOTA()
 
 void MainWindowInputOthers::setIOTAContinentFromEntity(const int _n)
 {
-      //qDebug() << "MainWindow::setIOTAContinentFromEntity:" << QString::number(_n) << endl;
+      //qDebug() << "MainWindow::setIOTAContinentFromEntity:" << QString::number(_n) << QT_ENDL;
     setIOTAContinent(dataProxy->getContinentShortNameFromEntity(_n)) ;
 }
 
-void MainWindowInputOthers::setIOTAContinent(const QString _qs)
+void MainWindowInputOthers::setIOTAContinent(const QString &_qs)
 {
-       //qDebug() << "MainWindowInputOthers::setIOTAContinent: " << _qs << endl;
-       //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index(a): " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
+       //qDebug() << "MainWindowInputOthers::setIOTAContinent: " << _qs << QT_ENDL;
+       //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index(a): " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << QT_ENDL;
     if(( iotaContinentComboBox->findText(_qs, Qt::MatchContains))>0)
     {
-          //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
+          //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << QT_ENDL;
         iotaContinentComboBox->setCurrentIndex( iotaContinentComboBox->findText(_qs, Qt::MatchContains));
     }
     else
     {
-           //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: 00" << endl;
+           //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: 00" << QT_ENDL;
         iotaContinentComboBox->setCurrentIndex(0);
     }
 }
 
-QString MainWindowInputOthers::checkIfValidIOTA(const QString _tiota)
+QString MainWindowInputOthers::checkIfValidIOTA(const QString &_tiota)
 {
 /**********************************
   IOTA should be always with this format: CC-NNN
@@ -364,14 +369,14 @@ QString MainWindowInputOthers::checkIfValidIOTA(const QString _tiota)
 Returns a valid format IOTA if possible and "" in other cases.
 
 ************************************/
-      //qDebug() << "MainWindowInputOthers::checkIfValidIOTA: " << _tiota << endl;
+      //qDebug() << "MainWindowInputOthers::checkIfValidIOTA: " << _tiota << QT_ENDL;
     //bool _valid = false;
     QString _continent;
     QString _number;
 
     if (_tiota.count("-") == 1)
     {
-        QStringList _values = _tiota.split("-", QString::SkipEmptyParts);
+        QStringList _values = _tiota.split("-", QT_SKIP);
         _continent = _values.at(0);
         _number = _values.at(1);
     }
@@ -380,8 +385,8 @@ Returns a valid format IOTA if possible and "" in other cases.
         return "";
     }
 
-      //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (cont) " << _continent << endl;
-      //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (numb): " << _number << endl;
+      //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (cont) " << _continent << QT_ENDL;
+      //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (numb): " << _number << QT_ENDL;
 
     // Check if continent is valid
 
@@ -466,6 +471,8 @@ QString MainWindowInputOthers::getUserADIFTypeComboBox()
         return "SOTA_REF";
     case 2:
         return "AGE";
+    case 3:
+        return "VUCC_GRIDS";
     default:
         return QString();
     }
@@ -485,7 +492,7 @@ QString MainWindowInputOthers::getUserADIFValue()
 
 bool MainWindowInputOthers::setInitialADIFValues()
 {
-    adifValidTypes << "01-" + tr("SOTA Ref") << "02-" + tr ("Age");
+    adifValidTypes << "01-" + tr("SOTA Ref") << "02-" + tr ("Age") << "03-" + tr ("VUCC grids");
     userDefinedADIFComboBox->clear ();
     userDefinedADIFComboBox->addItems (adifValidTypes);
     return true;
@@ -493,11 +500,11 @@ bool MainWindowInputOthers::setInitialADIFValues()
 
 void MainWindowInputOthers::slotUSerDefinedADIFComboBoxChanged()
 {
-
-
     //qDebug() << Q_FUNC_INFO << ": " << getUserADIFTypeComboBox ();
     QString currentTag = getUserADIFTypeComboBox ();
 
+    setColorsForUserDefinedADIFValueLineEdit();
+
     if (currentTag == "SOTA_REF")
     {
         userDefinedADIFValueLineEdit->setText (sota_ref);
@@ -506,16 +513,74 @@ void MainWindowInputOthers::slotUSerDefinedADIFComboBoxChanged()
     {
         userDefinedADIFValueLineEdit->setText (QString::number(age));
     }
+    else if (currentTag == "VUCC_GRIDS")
+    {
+        userDefinedADIFValueLineEdit->setText (vucc_grids);
+    }
+}
+
+bool MainWindowInputOthers::setVUCCGrids(const QString &_op)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _op;
+    if (checkVUCC_GRIDS(_op))
+    {
+        vucc_grids = _op;
+        slotUSerDefinedADIFComboBoxChanged();
+        return true;
+    }
+    return false;
+}
+
+bool MainWindowInputOthers::checkVUCC_GRIDS(const QString &_string)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _string;
+
+    if (util->isValidVUCCGrids (_string))
+    {
+        setColorsForUserDefinedADIFValueLineEdit();
+        return true;
+    }
+    else
+    {
+        userDefinedADIFValueLineEdit->setPalette (palRed);
+        return false;
+    }
 
 }
 
-bool MainWindowInputOthers::setSOTA(const QString _op)
+QString MainWindowInputOthers::getVUCCGrids()
+{
+    if (checkVUCC_GRIDS (vucc_grids))
+    {
+        return vucc_grids;
+    }
+    else
+    {
+        return QString();
+    }
+}
+
+void MainWindowInputOthers::setColorsForUserDefinedADIFValueLineEdit()
+{
+    if (getDarkMode())
+    {
+        userDefinedADIFValueLineEdit->setPalette(palWhite);
+    }
+    else
+    {
+        userDefinedADIFValueLineEdit->setPalette(palBlack);
+    }
+}
+
+
+bool MainWindowInputOthers::setSOTA(const QString &_op)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _op;
     sota_ref = _op;
     slotUSerDefinedADIFComboBoxChanged();
     return true;
 }
+
 QString MainWindowInputOthers::getSOTA()
 {
     //qDebug() << Q_FUNC_INFO;
@@ -546,6 +611,13 @@ void MainWindowInputOthers::slotSetCurrentUSerData()
     {
         age = userDefinedADIFValueLineEdit->text().toDouble();
     }
+    else if (currentTag == "VUCC_GRIDS")
+    {
+        //if (checkVUCC_GRIDS(userDefinedADIFValueLineEdit->text()))
+        //{}
+        vucc_grids = userDefinedADIFValueLineEdit->text().toUpper();
+        userDefinedADIFValueLineEdit->setText (vucc_grids);
+    }
 }
 
 bool MainWindowInputOthers::getDarkMode()
