@@ -32,7 +32,7 @@
 MainWindowInputQSO::MainWindowInputQSO(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
 {
-       //qDebug() << "MainWindowInputQSO::MainWindowInputQSO"   << endl;
+       //qDebug() << "MainWindowInputQSO::MainWindowInputQSO"   << QT_ENDL;
     dataProxy = dp;
     locator = new Locator();
 
@@ -52,11 +52,14 @@ MainWindowInputQSO::MainWindowInputQSO(DataProxy_SQLite *dp, QWidget *parent) :
     setDefaultData();
     //installEventFilter (this);
     clear();
-       //qDebug() << "MainWindowInputQSO::MainWindowInputQSO - END"   << endl;
+       //qDebug() << "MainWindowInputQSO::MainWindowInputQSO - END"   << QT_ENDL;
 
 }
 
-MainWindowInputQSO::~MainWindowInputQSO(){}
+MainWindowInputQSO::~MainWindowInputQSO()
+{
+    delete(locator);
+}
 
 void MainWindowInputQSO::setModifying(const bool _m)
 {
@@ -226,6 +229,7 @@ void MainWindowInputQSO::setDefaultData()
 
 void MainWindowInputQSO::clear()
 {
+    //qDebug() << Q_FUNC_INFO ;
     qthLineEdit->clear();
     nameLineEdit->clear();
     locatorLineEdit->clear();
@@ -235,6 +239,7 @@ void MainWindowInputQSO::clear()
 
 void MainWindowInputQSO::cleanQRZCOM()
 {
+    //qDebug() << Q_FUNC_INFO ;
     qthLineEdit->clear();
     nameLineEdit->clear();
     locatorLineEdit->clear();
@@ -252,6 +257,7 @@ void MainWindowInputQSO::clearQTH()
 
 void MainWindowInputQSO::clearDXLocator()
 {
+    //qDebug() << Q_FUNC_INFO ;
     locatorLineEdit->clear ();
 }
 
@@ -262,14 +268,14 @@ void MainWindowInputQSO::slotReturnPressed()
 
 void MainWindowInputQSO::slotLocatorTextChanged()
 {//TO BE REMOVED ONCE InfoWidget is FINISHED - At least modified
-    //qDebug() << Q_FUNC_INFO << ": " << locatorLineEdit->text() << endl;
+    //qDebug() << Q_FUNC_INFO << ": " << locatorLineEdit->text() << QT_ENDL;
     int cursorP = locatorLineEdit->cursorPosition();
 
     locatorLineEdit->setText((util->getClearSQLi(locatorLineEdit->text())).toUpper());
 
     if ( locator->isValidLocator((locatorLineEdit->text()).toUpper()) || locatorLineEdit->text ().isEmpty ())
     {
-        //qDebug() << Q_FUNC_INFO << ": VALID: " << locatorLineEdit->text() << endl;
+        //qDebug() << Q_FUNC_INFO << ": VALID: " << locatorLineEdit->text() << QT_ENDL;
         setPaletteRightDXLocator(true);
         emit dxLocatorChanged (locatorLineEdit->text());
 
@@ -277,12 +283,12 @@ void MainWindowInputQSO::slotLocatorTextChanged()
         //infoWidget->showDistanceAndBearing(myDataTabWidget->getMyLocator(), dxLocator);
         //satTabWidget->setLocator(dxLocator);
         locatorLineEdit->setToolTip(tr("DX QTH locator."));
-        //qDebug() << Q_FUNC_INFO << ": " << locator->getLat(locatorLineEdit->text()) << endl;
-        //qDebug() << Q_FUNC_INFO << ": LON: " << locator->getLon(locatorLineEdit->text()) << endl;
+        //qDebug() << Q_FUNC_INFO << ": " << locator->getLat(locatorLineEdit->text()) << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << ": LON: " << locator->getLon(locatorLineEdit->text()) << QT_ENDL;
     }
     else
     {
-        //qDebug() << Q_FUNC_INFO << ": NOT VALID: " << locatorLineEdit->text() << endl;
+        //qDebug() << Q_FUNC_INFO << ": NOT VALID: " << locatorLineEdit->text() << QT_ENDL;
         setPaletteRightDXLocator(false);
         locatorLineEdit->setToolTip(tr("DX QTH locator. Format should be Maidenhead like IN70AA up to 10 characters."));
         locatorLineEdit->setCursorPosition(cursorP);
@@ -293,11 +299,13 @@ void MainWindowInputQSO::slotLocatorTextChanged()
 
 QString MainWindowInputQSO::getDXLocator()
 {
+    //qDebug() << Q_FUNC_INFO << " - returning: " << locatorLineEdit->text ();
     return locatorLineEdit->text();
 }
 
 void MainWindowInputQSO::setDXLocator(const QString &_loc)
 {
+    //qDebug() << Q_FUNC_INFO << ": " << _loc;
     if (locator->isValidLocator (_loc))
     {
         locatorLineEdit->setText (_loc.toUpper ());
@@ -321,19 +329,19 @@ double MainWindowInputQSO::getTXFreq()
 
 void MainWindowInputQSO::setTXFreq(const double _ft)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << QString::number(_ft) << endl;
+    //qDebug() << Q_FUNC_INFO << ": " << QString::number(_ft) << QT_ENDL;
 
     if ( (_ft >= double(0)) && (_ft <= txFreqSpinBox->maximum()))
     {
-        //qDebug() << Q_FUNC_INFO << ": defining FR: " << QString::number(_ft) << endl;
+        //qDebug() << Q_FUNC_INFO << ": defining FR: " << QString::number(_ft) << QT_ENDL;
         txFreqSpinBox->setValue(_ft);
     }
     else
     {
-        //qDebug() << Q_FUNC_INFO << ": defining FR: 0"  << endl;
+        //qDebug() << Q_FUNC_INFO << ": defining FR: 0"  << QT_ENDL;
         txFreqSpinBox->setValue(0);
     }
-    //qDebug() << Q_FUNC_INFO << endl;
+    //qDebug() << Q_FUNC_INFO << QT_ENDL;
 }
 
 double MainWindowInputQSO::getRXFreq()
@@ -403,7 +411,7 @@ void MainWindowInputQSO::setRSTToMode(const QString &_m, const bool _reading)
 
     if ((_m == "SSB") || (_m== "LSB") || (_m=="USB") || (_m == "FM") || (_m == "AM") )
     {
-         //qDebug() << Q_FUNC_INFO << ": Detected SSB/LSB/USB"  << endl;
+         //qDebug() << Q_FUNC_INFO << ": Detected SSB/LSB/USB"  << QT_ENDL;
         rstTXLineEdit->setInputMask("#DD");
         rstRXLineEdit->setInputMask("#DD");
 
@@ -450,7 +458,7 @@ void MainWindowInputQSO::setRSTToMode(const QString &_m, const bool _reading)
     }
     if (!_reading)
     {
-         //qDebug() << Q_FUNC_INFO << ": reading the UI" << endl;
+         //qDebug() << Q_FUNC_INFO << ": reading the UI" << QT_ENDL;
         rstTXLineEdit->setText(util->getDefaultRST(_m));
         rstRXLineEdit->setText(util->getDefaultRST(_m));
     }
@@ -527,7 +535,7 @@ void MainWindowInputQSO::setPaletteRightDXLocator(const bool _ok)
 
 void MainWindowInputQSO::setPropModeFromSat(const QString &_p)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << _p << endl;
+    //qDebug() << Q_FUNC_INFO << ": " << _p << QT_ENDL;
     propMode = _p;
     if (propMode == "SAT")
     {
@@ -541,10 +549,10 @@ void MainWindowInputQSO::setPropModeFromSat(const QString &_p)
 
 void MainWindowInputQSO::slotFreqTXChanged (double _f)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f) << endl;
+    //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f) << QT_ENDL;
     if (util->isSameFreq (_f, freqTX))
     {
-        //qDebug() << Q_FUNC_INFO << ": Same Freq return"  << endl;
+        //qDebug() << Q_FUNC_INFO << ": Same Freq return"  << QT_ENDL;
         return;
     }
     freqTX = _f;
@@ -560,21 +568,21 @@ void MainWindowInputQSO::slotFreqTXChanged (double _f)
         {
             txFreqSpinBox->setPalette(palBlack);
         }
-        //qDebug() << Q_FUNC_INFO << ": emitting: " << QString::number(_f) << endl;
+        //qDebug() << Q_FUNC_INFO << ": emitting: " << QString::number(_f) << QT_ENDL;
         emit txFreqChanged (_f);
     }
     else
     {
         txFreqSpinBox->setToolTip(tr("TX Frequency in MHz.\nFrequency is not in a hamradio band!"));
         txFreqSpinBox->setPalette(palRed);
-         //qDebug() << Q_FUNC_INFO << ":RED - Not in band "  << endl;
+         //qDebug() << Q_FUNC_INFO << ":RED - Not in band "  << QT_ENDL;
     }
     if ((!splitCheckBox->isChecked()) || modify )
     {
         rxFreqSpinBox->setValue (_f);
-        //qDebug() << Q_FUNC_INFO << ": copying to RX Freq "  << endl;
+        //qDebug() << Q_FUNC_INFO << ": copying to RX Freq "  << QT_ENDL;
     }
-    //qDebug() << Q_FUNC_INFO << " - END"  << endl;
+    //qDebug() << Q_FUNC_INFO << " - END"  << QT_ENDL;
     setSplitCheckBox();
 }
 
@@ -611,7 +619,7 @@ void MainWindowInputQSO::slotFreqRXChanged(double _f)
     {
         rxFreqSpinBox->setToolTip(tr("RX Frequency in MHz.\nFrequency is not in a hamradio band!"));
         rxFreqSpinBox->setPalette(palRed);
-         //qDebug() << "MainWindow::slotFreqRXChanged Freq is not in ANY ham band" << endl;
+         //qDebug() << "MainWindow::slotFreqRXChanged Freq is not in ANY ham band" << QT_ENDL;
     }
     if ((!splitCheckBox->isChecked()) && !modify)
     {
@@ -629,15 +637,15 @@ void MainWindowInputQSO::slotFreqRXChanged(double _f)
     {
         rxFreqSpinBox->setToolTip(tr("RX Frequency in MHz.\nFrequency is not in a hamradio band!"));
         rxFreqSpinBox->setPalette(palRed);
-                //qDebug() << "MainWindow::slotFreqRXChanged Freq is not in ANY ham band" << endl;
+                //qDebug() << "MainWindow::slotFreqRXChanged Freq is not in ANY ham band" << QT_ENDL;
     }
     if (!rxFreqBeingAutoChanged)
     {
-                //qDebug() << "MainWindow::slotFreqTXChanged: Updating SAT Downlink" << endl;
+                //qDebug() << "MainWindow::slotFreqTXChanged: Updating SAT Downlink" << QT_ENDL;
         emit rxFreqChangedForSat(rxFreqSpinBox->value());
     }
     */
-    //qDebug() << "MainWindow::slotFreqRXChanged: END" << endl;
+    //qDebug() << "MainWindow::slotFreqRXChanged: END" << QT_ENDL;
     setSplitCheckBox();
 }
 
