@@ -29,7 +29,7 @@
 MainWindowMyDataTab::MainWindowMyDataTab(QWidget *parent) :
     QWidget(parent)
 {
-       //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab"   << endl;
+       //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab"   << QT_ENDL;
     myPowerSpinBox = new QDoubleSpinBox;
     operatorLineEdit = new QLineEdit;
     stationCallSignLineEdit = new QLineEdit;
@@ -45,7 +45,7 @@ MainWindowMyDataTab::MainWindowMyDataTab(QWidget *parent) :
     //lastStationQRZ = QString();     // Last QRZ used by the user, will remain if the button is checked and removed if not
     lastMyLocator = QString();      // Last locator used by the user, will remain if the button is checked and removed if not
 
-    stationQRZ = QString();         // Defined in the configuration by the user, will be used if the user configured so in the setup
+    stationCallsign = QString();    // Defined in the configuration by the user, will be used if the user configured so in the setup
     operatorQRZ = QString();        // Defined in the configuration by the user, will be used if the user configured so in the setup
     myLocator = QString();          // Defined in the configuration by the user, will be used if the user configured so in the setup
     util = new Utilities;
@@ -54,7 +54,7 @@ MainWindowMyDataTab::MainWindowMyDataTab(QWidget *parent) :
     setInitialADIFValues();
     myPower = 0;
     lastPower = 0;
-       //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab - END"   << endl;
+       //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab - END"   << QT_ENDL;
 
 }
 
@@ -112,7 +112,7 @@ void MainWindowMyDataTab::createUI()
     connect(operatorLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotOperatorTextChanged()) );
     connect(stationCallSignLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed() ) );
     connect(stationCallSignLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotStationCallSignTextChanged() ) );
-    connect(myUserADIFComboBox, SIGNAL(currentIndexChanged (QString)), this, SLOT(slotMyUserADIFComboBoxChanged() ) ) ;
+    connect(myUserADIFComboBox, SIGNAL(currentIndexChanged(QString)), this, SLOT(slotMyUserADIFComboBoxChanged() ) ) ;
 
     connect(myUserADIFLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotSetCurrentMyUSerData() ) );
 }
@@ -123,7 +123,7 @@ void MainWindowMyDataTab::clear(bool _full)
     modify = false;
     if (!keepThisDataForNextQSOQCheckbox->isChecked())
     {
-        //qDebug() << "MainWindowMyDataTab::clear: NOT checked"  << endl;
+        //qDebug() << "MainWindowMyDataTab::clear: NOT checked"  << QT_ENDL;
         myPowerSpinBox->setValue(myPower);
         if (util->isValidCall(operatorQRZ))
         {
@@ -134,9 +134,9 @@ void MainWindowMyDataTab::clear(bool _full)
         {
             operatorLineEdit->clear();
         }
-        if (util->isValidCall(stationQRZ))
+        if (util->isValidCall(stationCallsign))
         {
-            stationCallSignLineEdit->setText(stationQRZ);
+            stationCallSignLineEdit->setText(stationCallsign);
         }
         else
         {
@@ -166,6 +166,7 @@ void MainWindowMyDataTab::clear(bool _full)
         my_rig = QString();
         my_sota = QString();
         my_antenna = QString();
+        my_vucc_grids = QString();
         myUserADIFComboBox->setCurrentIndex(0);
         myUserADIFLineEdit->clear();
         keepThisDataForNextQSOQCheckbox->setChecked (false);
@@ -175,11 +176,11 @@ void MainWindowMyDataTab::clear(bool _full)
 void MainWindowMyDataTab::show()
 {
     //qDebug() << Q_FUNC_INFO;
-    //qDebug() << "MainWindowMyDataTab::show: " << QString::number(myPower) << "/" << operatorQRZ << "/" << stationQRZ << "/" << myLocator << endl;
+    //qDebug() << "MainWindowMyDataTab::show: " << QString::number(myPower) << "/" << operatorQRZ << "/" << stationCallsign << "/" << myLocator << QT_ENDL;
     myPowerSpinBox->setValue(myPower);
     operatorLineEdit->setText(operatorQRZ);
-    stationCallSignLineEdit->setText(stationQRZ);
-    //qDebug() << "MainWindowMyDataTab::show: setMyLocator: " << myLocator  << endl;
+    stationCallSignLineEdit->setText(stationCallsign);
+    //qDebug() << "MainWindowMyDataTab::show: setMyLocator: " << myLocator  << QT_ENDL;
     myLocatorLineEdit->setText(myLocator);
 
 }
@@ -187,11 +188,11 @@ void MainWindowMyDataTab::show()
 void MainWindowMyDataTab::slotMyLocatorTextChanged()
 {
     //qDebug() << Q_FUNC_INFO;
-     //qDebug() << "MainWindowMyDataTab::slotMyLocatorTextChanged: " << myLocatorLineEdit->text() << endl;
+     //qDebug() << "MainWindowMyDataTab::slotMyLocatorTextChanged: " << myLocatorLineEdit->text() << QT_ENDL;
     //logEvent(Q_FUNC_INFO, "Start", logSeverity);
     int cursorP = myLocatorLineEdit->cursorPosition();
     myLocatorLineEdit->setText(util->getClearSQLi(myLocatorLineEdit->text()).toUpper());
-    //qDebug() << "MainWindowMyDataTab::clear: setMyLocator: " << myLocatorLineEdit->text()  << endl;
+    //qDebug() << "MainWindowMyDataTab::clear: setMyLocator: " << myLocatorLineEdit->text()  << QT_ENDL;
     if ( locator->isValidLocator(myLocatorLineEdit->text()))
     {
         if (!modify)
@@ -207,12 +208,13 @@ void MainWindowMyDataTab::slotMyLocatorTextChanged()
         {
             myLocatorLineEdit->setPalette(palBlack);
         }
+
         myLocatorLineEdit->setToolTip(tr("My QTH locator."));
         myLocatorLineEdit->setCursorPosition(cursorP);
         emit myLocChangedSignal(myLocatorLineEdit->text());
 
         //dxccStatusWidget->setMyLocator(myLocator);
-              //qDebug() << "MainWindowMyDataTab::slotMyLocatorTextChanged: My LOCATOR CHANGED TO: " << myLocator << endl;
+              //qDebug() << "MainWindowMyDataTab::slotMyLocatorTextChanged: My LOCATOR CHANGED TO: " << myLocator << QT_ENDL;
         //slotLocatorTextChanged();
     }
     else
@@ -249,7 +251,7 @@ void MainWindowMyDataTab::setSetupOperator(const QString &_op)
     operatorQRZ = _op.toUpper();
     operatorLineEdit->setText (operatorQRZ);
 }
-
+/*
 void MainWindowMyDataTab::setSetupStationQRZ(const QString &_op)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _op ;
@@ -260,6 +262,7 @@ void MainWindowMyDataTab::setSetupStationQRZ(const QString &_op)
     stationQRZ = _op.toUpper();
     stationCallSignLineEdit->setText(stationQRZ);
 }
+*/
 
 void MainWindowMyDataTab::setSetupMyLocator(const QString &_op)
 {
@@ -275,7 +278,7 @@ void MainWindowMyDataTab::setSetupMyLocator(const QString &_op)
 
 void MainWindowMyDataTab::setMyPower(const double _power)
 {
-      //qDebug() << "MainWindowMyDataTab::setMyPower: " << QString::number(_power) << endl;
+      //qDebug() << "MainWindowMyDataTab::setMyPower: " << QString::number(_power) << QT_ENDL;
     //qDebug() << Q_FUNC_INFO;
     myPowerSpinBox->setValue(_power);
 }
@@ -311,13 +314,20 @@ QString MainWindowMyDataTab::getOperator()
 }
 
 
-void MainWindowMyDataTab::setStationQRZ(const QString &_op)
+void MainWindowMyDataTab::setStationCallsign(const QString &_op)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _op;
-    stationCallSignLineEdit->setText(_op);
+    if (util->isValidCall (_op))
+    {
+        stationCallSignLineEdit->setText(_op);
+    }
+    else
+    {
+        stationCallsign.clear ();
+    }
 }
 
-QString MainWindowMyDataTab::getStationQRZ()
+QString MainWindowMyDataTab::getStationCallsign()
 {
     //qDebug() << Q_FUNC_INFO << ": " << (stationCallSignLineEdit->text()).toUpper();
     return (stationCallSignLineEdit->text()).toUpper();
@@ -338,7 +348,7 @@ QString MainWindowMyDataTab::getMyLocator()
 }
 
 
-void MainWindowMyDataTab::setData(const double _power, const QString &_stationQRZ, const QString &_operator, const QString &_myLocator)
+void MainWindowMyDataTab::setData(const double _power, const QString &_stationCallsign, const QString &_operator, const QString &_myLocator)
 {
     //qDebug() << Q_FUNC_INFO;
     if (_power > 0.0)
@@ -349,16 +359,16 @@ void MainWindowMyDataTab::setData(const double _power, const QString &_stationQR
     {
         myPower = 0;
     }
-
-    if (_stationQRZ.length()>0)
+    if (util->isValidCall (_stationCallsign))
     {
-        setStationQRZ (_stationQRZ);
-        //stationQRZ = _stationQRZ;
+        stationCallsign = _stationCallsign;
     }
     else
     {
-        stationQRZ = QString();
+        stationCallsign = QString();
     }
+    //qDebug() << Q_FUNC_INFO << ": Setting station Callsign: " << stationCallsign;
+    setStationCallsign (stationCallsign);
 
     if (_operator.length()>0)
     {
@@ -434,10 +444,10 @@ void MainWindowMyDataTab::slotStationCallSignTextChanged()
             stationCallSignLineEdit->setPalette(palBlack);
         }
 
-        if (!modify)
-        {
-            stationQRZ = (stationCallSignLineEdit->text());
-        }
+        //if (!modify)
+        //{
+        //    stationCallsign = (stationCallSignLineEdit->text());
+        //}
     }
     else
     {
@@ -462,7 +472,7 @@ bool MainWindowMyDataTab::setInitialADIFValues()
 {
     //qDebug() << Q_FUNC_INFO;
     adifValidTypes.clear ();
-    adifValidTypes << "01-" + tr("My Rig") << "02-" + tr("My Antenna") << "03-" + tr("My SOTA_Ref");
+    adifValidTypes << "01-" + tr("My Rig") << "02-" + tr("My Antenna") << "03-" + tr("My SOTA_Ref")<< "04-" + tr("My VUCC_GRIDS");
     myUserADIFComboBox->clear ();
     myUserADIFComboBox->addItems (adifValidTypes);
     return true;
@@ -483,6 +493,10 @@ bool MainWindowMyDataTab::setUserADIFTypeComboBox(const QString &_value)
     {
         myUserADIFComboBox->setCurrentIndex (2);
     }
+    else if (_value == "MY_VUCC_GRIDS")
+    {
+        myUserADIFComboBox->setCurrentIndex (3);
+    }
     else
     {
         myUserADIFComboBox->setCurrentIndex (0);
@@ -504,6 +518,8 @@ QString MainWindowMyDataTab::getUserADIFTypeComboBox()
         return "MY_ANTENNA";
     case 3:
         return "MY_SOTA_REF";
+    case 4:
+        return "MY_VUCC_GRIDS";
     default:
         return QString();
     }
@@ -564,11 +580,66 @@ QString MainWindowMyDataTab::getMySOTA()
     return my_sota;
 }
 
+bool MainWindowMyDataTab::setMyVUCCGrids(const QString &_op)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _op;
+    if (checkMyVUCC_GRIDS(_op))
+    {
+        my_vucc_grids = _op;
+        slotMyUserADIFComboBoxChanged();
+        return true;
+    }
+    return false;
+}
+
+bool MainWindowMyDataTab::checkMyVUCC_GRIDS(const QString &_string)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _string;
+
+    if (util->isValidVUCCGrids (_string))
+    {
+        setColorsForMyUserADIFLineEdit();
+        return true;
+    }
+    else
+    {
+        myUserADIFLineEdit->setPalette (palRed);
+        return false;
+    }
+
+}
+
+QString MainWindowMyDataTab::getMyVUCCGrids()
+{
+    if (checkMyVUCC_GRIDS (my_vucc_grids))
+    {
+        return my_vucc_grids;
+    }
+    else
+    {
+        return QString();
+    }
+}
+
+void MainWindowMyDataTab::setColorsForMyUserADIFLineEdit()
+{
+    if (getDarkMode())
+    {
+        myUserADIFLineEdit->setPalette(palWhite);
+    }
+    else
+    {
+        myUserADIFLineEdit->setPalette(palBlack);
+    }
+}
+
 void MainWindowMyDataTab::slotMyUserADIFComboBoxChanged()
 {
     //qDebug() << Q_FUNC_INFO << ": " << getUserADIFTypeComboBox ();
     QString currentTag = getUserADIFTypeComboBox ();
 
+    setColorsForMyUserADIFLineEdit();
+
     if (currentTag == "MY_RIG")
     {
         myUserADIFLineEdit->setText (my_rig);
@@ -581,12 +652,18 @@ void MainWindowMyDataTab::slotMyUserADIFComboBoxChanged()
     {
         myUserADIFLineEdit->setText (my_sota);
     }
+    else if (currentTag == "MY_VUCC_GRIDS")
+    {
+        myUserADIFLineEdit->setText (my_vucc_grids);
+    }
 }
 
 
 void MainWindowMyDataTab::slotSetCurrentMyUSerData()
 {
     QString currentTag = getUserADIFTypeComboBox ();
+    //qDebug() << Q_FUNC_INFO << ": " << currentTag;
+    int currentPos = myUserADIFLineEdit->cursorPosition ();
 
     if (currentTag == "MY_RIG")
     {
@@ -600,6 +677,16 @@ void MainWindowMyDataTab::slotSetCurrentMyUSerData()
     {
         my_sota = myUserADIFLineEdit->text();
     }
+    else if (currentTag == "MY_VUCC_GRIDS")
+    {
+        //if (checkMyVUCC_GRIDS(myUserADIFLineEdit->text()))
+        //{}
+
+        my_vucc_grids = myUserADIFLineEdit->text().toUpper();
+        myUserADIFLineEdit->setText (my_vucc_grids);
+    }
+
+    myUserADIFLineEdit->setCursorPosition (currentPos);
 }
 
 void MainWindowMyDataTab::setModify(const bool _modify)
