@@ -31,7 +31,7 @@ This class implements the Satellite TAB of the MainWindow
 MainWindowSatTab::MainWindowSatTab(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
 {
-       //qDebug() << "MainWindowSatTab::MainWindowSatTab"   << endl;
+       //qDebug() << "MainWindowSatTab::MainWindowSatTab"   << QT_ENDL;
     satNameComboBox = new QComboBox;
     satNameLineEdit = new QLineEdit;
     satModeLineEdit = new QLineEdit;
@@ -63,7 +63,7 @@ MainWindowSatTab::MainWindowSatTab(DataProxy_SQLite *dp, QWidget *parent) :
     palWhite.setColor(QPalette::Text, Qt::white);
 
     setDefaultBands(); //TODO: Check how the bands are included not to create an inconsistence with the selected (in the setup) bands
-       //qDebug() << "MainWindowSatTab::MainWindowSatTab - END"   << endl;
+       //qDebug() << "MainWindowSatTab::MainWindowSatTab - END"   << QT_ENDL;
 }
 
 MainWindowSatTab::~MainWindowSatTab(){}
@@ -77,10 +77,10 @@ void MainWindowSatTab::createUI()
     connect(satModeLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed()) );
     connect(satDXLocatorLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed()) );
 
-    connect(satNameComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotSatNameComboBoxChanged() ) ) ;
+    connect(satNameComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSatNameComboBoxChanged() ) ) ;
 
-    connect(satBandRXComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotSatBandRXComboBoxChanged()) ) ;
-    connect(satBandTXComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotSatBandTXComboBoxChanged()) ) ;
+    connect(satBandRXComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSatBandRXComboBoxChanged()) ) ;
+    connect(satBandTXComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSatBandTXComboBoxChanged()) ) ;
 
     connect(txFreqSpinBox, SIGNAL(valueChanged(double)), this, SLOT(slotSatFreqTXChanged(double)) ) ;
     connect(rxFreqSpinBox, SIGNAL(valueChanged(double)), this, SLOT(slotSatFreqRXChanged(double)) ) ;
@@ -124,7 +124,6 @@ void MainWindowSatTab::createUI()
     satDXLocLabel->setText(tr("DX Locator"));
     satDXLocLabel->setAlignment(Qt::AlignVCenter| Qt::AlignRight);
 
-
     //QLabel *satOtherLabel = new QLabel();
     satOtherLabel->setText(tr("Other"));
     satOtherLabel->setAlignment(Qt::AlignVCenter| Qt::AlignRight);
@@ -137,7 +136,6 @@ void MainWindowSatTab::createUI()
     rxFreqSpinBox->setMaximum(99999);
     rxFreqSpinBox->setSuffix(" " + tr("MHz"));
 
-
     QHBoxLayout *keepLayout = new QHBoxLayout;
     keepLayout->addWidget(keepLabel);
     keepLayout->addWidget(keepThisDataForNextQSOQcheckbox);
@@ -169,19 +167,18 @@ void MainWindowSatTab::createUI()
     tabLayout->addLayout(keepLayout,3,2);
     tabLayout->setSizeConstraint(QLayout::SetFixedSize);
     setLayout(tabLayout);
-
 }
 
 void MainWindowSatTab::slotSatNameComboBoxChanged()
 {
-    //qDebug() << "MainWindowSatTab::slotSatNameComboBoxChanged: " << satNameComboBox->currentText() << endl;
+    //qDebug() << "MainWindowSatTab::slotSatNameComboBoxChanged: " << satNameComboBox->currentText() << QT_ENDL;
     if (modifying || (satNameComboBox->currentText().length()<4))
     {
         return;
     }
 
     int i = satNameComboBox->currentIndex();
-   //qDebug() << "MainWindowSatTab::slotSatNameComboBoxChanged: " << QString::number(i) << endl;
+   //qDebug() << "MainWindowSatTab::slotSatNameComboBoxChanged: " << QString::number(i) << QT_ENDL;
     //QString _pm = (((satNameComboBox->currentText()).split(' ')).at(0)).simplified();
 
     satNameLineEdit->clear();
@@ -192,7 +189,6 @@ void MainWindowSatTab::slotSatNameComboBoxChanged()
         satNameLineEdit->setEnabled(false);
         satOtherLabel->setEnabled(false);
         satModeLineEdit->clear();
-
     }
     else if(i == 1)
     {
@@ -206,20 +202,15 @@ void MainWindowSatTab::slotSatNameComboBoxChanged()
         satNameLineEdit->setEnabled(false);
         satOtherLabel->setEnabled(false);
         setBandsOfSat(satNameComboBox->currentText());
-
-        //dataProxy->getSatelliteMode(satNameComboBox->currentText())
+       //dataProxy->getSatelliteMode(satNameComboBox->currentText())
     }
-
-    //autofillSatMode();
-
+   //autofillSatMode();
 }
 
 void MainWindowSatTab::slotSatNameTextChanged()
 {
-    //qDebug() << "MainWindowSatTab::slotSatNameTextChanged: " << satNameLineEdit->text() << endl;
+    //qDebug() << "MainWindowSatTab::slotSatNameTextChanged: " << satNameLineEdit->text() << QT_ENDL;
     int cursor = satNameLineEdit->cursorPosition ();
-
-
     satNameLineEdit->setText((util->getClearSQLi (satNameLineEdit->text())).toUpper());
 
     if (modifying )
@@ -237,13 +228,11 @@ void MainWindowSatTab::slotSatNameTextChanged()
         emit setPropModeSat("Not", false);
     }
     satNameLineEdit->setCursorPosition (cursor);
-
-
 }
 
 void MainWindowSatTab::slotSatModeTextChanged()
 {
-    //qDebug() << "MainWindowSatTab::slotSatModeTextChanged: " << satModeLineEdit->text() << endl;
+    //qDebug() << "MainWindowSatTab::slotSatModeTextChanged: " << satModeLineEdit->text() << QT_ENDL;
 /*
     satModeLineEdit->setText((satModeLineEdit->text()).toUpper());
 
@@ -256,19 +245,18 @@ void MainWindowSatTab::slotSatModeTextChanged()
         emit setPropModeSat("Not");
     }
 */
-
 }
 
 void MainWindowSatTab::setLocator(const QString &_t)
 {
-    //qDebug() << "MainWindowSatTab::setLocator: " << _t << endl;
+    //qDebug() << "MainWindowSatTab::setLocator: " << _t << QT_ENDL;
     satDXLocatorLineEdit->setText(_t.toUpper());
-    //qDebug() << "MainWindowSatTab::setLocator - END: "  << endl;
+    //qDebug() << "MainWindowSatTab::setLocator - END: "  << QT_ENDL;
 }
 
 void MainWindowSatTab::slotSatDXLocTextChanged()
 {
-    //qDebug() << "MainWindowSatTab::slotSatDXLocTextChanged: " << satDXLocatorLineEdit->text() << endl;
+    //qDebug() << "MainWindowSatTab::slotSatDXLocTextChanged: " << satDXLocatorLineEdit->text() << QT_ENDL;
     int cursorP = satDXLocatorLineEdit->cursorPosition();
 
     satDXLocatorLineEdit->setText((util->getClearSQLi(satDXLocatorLineEdit->text())).toUpper());
@@ -299,7 +287,7 @@ void MainWindowSatTab::slotSatDXLocTextChanged()
     satDXLocatorLineEdit->setCursorPosition(cursorP);
     emit dxLocatorChanged(satDXLocatorLineEdit->text());
 
-    //qDebug() << "MainWindowSatTab::slotSatDXLocTextChanged - END"  << endl;
+    //qDebug() << "MainWindowSatTab::slotSatDXLocTextChanged - END"  << QT_ENDL;
 }
 
 QString MainWindowSatTab::getSatName()
@@ -313,13 +301,13 @@ QString MainWindowSatTab::getSatName()
     //TODO: Check that the format is OK
     return satName;
  */
-    //qDebug() << "MainWindowSatTab::getSatName:" << satNameComboBox->currentText() << endl;
+    //qDebug() << "MainWindowSatTab::getSatName:" << satNameComboBox->currentText() << QT_ENDL;
     QString _pm = QString();
     QString satName = QString();
 
     _pm = (((satNameComboBox->currentText()).split(' ')).at(0)).simplified();
 
-       //qDebug() << "MainWindowSatTab::satNameComboBox: " << _pm << endl;
+       //qDebug() << "MainWindowSatTab::satNameComboBox: " << _pm << QT_ENDL;
     if (satNameComboBox->currentIndex() == 0)
     {
         return QString();
@@ -340,7 +328,6 @@ QString MainWindowSatTab::getSatName()
     {
         return _pm;
     }
-
 }
 
 void MainWindowSatTab::setNoSat()
@@ -352,7 +339,7 @@ void MainWindowSatTab::setNoSat()
 void MainWindowSatTab::setSatName(const QString &_t)
 {
      //TODO: Check that the format is OK
-    //qDebug() << "MainWindowSatTab::setSatName: " << _t << endl;
+    //qDebug() << "MainWindowSatTab::setSatName: " << _t << QT_ENDL;
     //satNameLineEdit->setText(_t);
     if (getSatIndex(_t) > 0)
     {
@@ -367,13 +354,13 @@ void MainWindowSatTab::setSatName(const QString &_t)
 
 QString MainWindowSatTab::getSatMode()
 {
-    //qDebug() << "MainWindowSatTab::getSatMode: " << satModeLineEdit->text() << endl;
+    //qDebug() << "MainWindowSatTab::getSatMode: " << satModeLineEdit->text() << QT_ENDL;
     return satModeLineEdit->text();
 }
 
 void MainWindowSatTab::setSatMode(const QString &_t)
 {
-    //qDebug() << "MainWindowSatTab::setSatMode: " << _t << endl;
+    //qDebug() << "MainWindowSatTab::setSatMode: " << _t ;
     if (_t == "-CLEAR-")
     {
         satModeLineEdit->clear();
@@ -386,19 +373,19 @@ void MainWindowSatTab::setSatMode(const QString &_t)
 
 bool MainWindowSatTab::getRepeatThis()
 {
-    //qDebug() << "MainWindowSatTab::getRepeatThis: "  << endl;
+    //qDebug() << "MainWindowSatTab::getRepeatThis: "  << QT_ENDL;
     return keepThisDataForNextQSOQcheckbox->isChecked();
 }
 
 void MainWindowSatTab::setRepeatThis(const bool _t)
 {
-    //qDebug() << "MainWindowSatTab::setRepeatThis: "  << endl;
+    //qDebug() << "MainWindowSatTab::setRepeatThis: "  << QT_ENDL;
     keepThisDataForNextQSOQcheckbox->setChecked(_t);
 }
 
 void MainWindowSatTab::clear(bool _full)
 {
-    //qDebug() << "MainWindowSatTab::clear"  << endl;
+    //qDebug() << "MainWindowSatTab::clear"  << QT_ENDL;
     modifying = false;
     if ((keepThisDataForNextQSOQcheckbox->isChecked()) || (!_full))
     {
@@ -415,19 +402,18 @@ void MainWindowSatTab::clear(bool _full)
     {
         keepThisDataForNextQSOQcheckbox->setChecked (false);
     }
-
 }
 
 void MainWindowSatTab::refreshData()
 {
-    //qDebug() << "MainWindowSatTab::refreshData"  << endl;
+    //qDebug() << "MainWindowSatTab::refreshData"  << QT_ENDL;
     populateSatComboBox();
     //autofillSatMode();
 }
 
 void MainWindowSatTab::populateSatComboBox()
 {
-    //qDebug() << "MainWindowSatTab::populateSatComboBox: " << endl;
+    //qDebug() << "MainWindowSatTab::populateSatComboBox: " << QT_ENDL;
 
     QString nosat = tr("Not Sat QSO");
     QString othersat = tr("Other - Sat not in the list");
@@ -450,11 +436,11 @@ void MainWindowSatTab::populateSatComboBox()
 
 void MainWindowSatTab::setSatelliteCombo(const QString &_p)
 {
-    //qDebug() << "MainWindowsatTab::setSatelliteCombo: " << _p << endl;
+    //qDebug() << "MainWindowsatTab::setSatelliteCombo: " << _p << QT_ENDL;
     QString aux = QString();
     int indexC = getSatIndex(_p);
     //int indexC = satNameComboBox->findText(_p, Qt::MatchContains);
-       //qDebug() << "MainWindowsatTab::setSatelliteCombo: N=" << QString::number(indexC) << endl;
+       //qDebug() << "MainWindowsatTab::setSatelliteCombo: N=" << QString::number(indexC) << QT_ENDL;
     if (indexC>0)
     {
         satNameComboBox->setCurrentIndex(indexC);
@@ -481,30 +467,29 @@ void MainWindowSatTab::setSatelliteCombo(const QString &_p)
             }
         }
     }
-
 }
 
 void MainWindowSatTab::setOtherSatName(const QString &_t)
 {
-    //qDebug() << "MainWindowsatTab::setOtherSatName: " << _t << endl;
+    //qDebug() << "MainWindowsatTab::setOtherSatName: " << _t << QT_ENDL;
     satNameLineEdit->setText(_t);
 }
 
 QString MainWindowSatTab::getOtherSatName()
 {
-    //qDebug() << "MainWindowSatTab::getOtherSatName"  << endl;
+    //qDebug() << "MainWindowSatTab::getOtherSatName"  << QT_ENDL;
     return QString();
 }
 
 int MainWindowSatTab::getSatIndex(const QString &_p)
 {
-    //qDebug() << "MainWindowSatTab::getSatIndex: " << QString::number(satNameComboBox->findText(_p, Qt::MatchContains))  << endl;
+    //qDebug() << "MainWindowSatTab::getSatIndex: " << QString::number(satNameComboBox->findText(_p, Qt::MatchContains))  << QT_ENDL;
     return satNameComboBox->findText(_p, Qt::MatchContains);
 }
 
 void MainWindowSatTab::addBands(QStringList _bands)
 {
-    //qDebug() << "MainWindowSatTab::addBands: " << QString::number(_bands.length()) << endl;
+    //qDebug() << "MainWindowSatTab::addBands: " << QString::number(_bands.length()) << QT_ENDL;
     updatingBands = true;
     QString _txBand = satBandTXComboBox->currentText();
     QString _rxBand = satBandRXComboBox->currentText();
@@ -517,24 +502,23 @@ void MainWindowSatTab::addBands(QStringList _bands)
     satBandRXComboBox->setCurrentIndex(satBandRXComboBox->findText(_rxBand, Qt::MatchCaseSensitive));
     //txBandsBeingChanged = false;
     updatingBands = false;
-    //qDebug() << "MainWindowSatTab::addBands - END"  << endl;
+    //qDebug() << "MainWindowSatTab::addBands - END"  << QT_ENDL;
 }
 
 void MainWindowSatTab::setDefaultBands()
 {//Defines the default bands for SAT communications: 10m/2m/70cm/23CM only if they exist in the selected bands
-    //qDebug() << "MainWindowsatTab::setDefaultBands: " << endl;
+    //qDebug() << "MainWindowsatTab::setDefaultBands: " << QT_ENDL;
     QStringList _b;
     _b.clear();
 
     _b << "10M" << "2M" << "70CM" << "23CM";
     satBandRXComboBox->addItems(_b);
     satBandTXComboBox->addItems(_b);
-
 }
 
 void MainWindowSatTab::slotSatBandRXComboBoxChanged()
 {
-    //qDebug() << "MainWindowsatTab::slotSatBandRXComboBoxChanged" << endl;
+    //qDebug() << "MainWindowsatTab::slotSatBandRXComboBoxChanged" << QT_ENDL;
     if (updatingBands || modifying)
     {
         return;
@@ -544,14 +528,15 @@ void MainWindowSatTab::slotSatBandRXComboBoxChanged()
     { // If the freq does not belong to the current band, we need to update the band
         rxFreqSpinBox->setValue(dataProxy->getLowLimitBandFromBandName(satBandRXComboBox->currentText()));
     }
-    //qDebug() << "MainWindowsatTab::slotSatBandRXComboBoxChanged-END" << endl;
+    //qDebug() << "MainWindowsatTab::slotSatBandRXComboBoxChanged-END" << QT_ENDL;
     autofillSatMode();
 }
 
 void MainWindowSatTab::slotSatFreqRXChanged(const double _f)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << QString::number(rxFreqSpinBox->value()) << endl;
-
+    //qDebug() << Q_FUNC_INFO << ": spingBox: " << QString::number(rxFreqSpinBox->value()) << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ": f: " << QString::number(_f) << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ": freqRx:" << QString::number(freqRX) << QT_ENDL;
     if (util->isSameFreq (freqRX, _f))
     {
         return;
@@ -575,7 +560,7 @@ void MainWindowSatTab::slotSatFreqRXChanged(const double _f)
     int bandId = dataProxy->getBandIdFromFreq(rxFreqSpinBox->value());
     if (bandId<1)
     { //This prevent that a non-hamradio frequency is used on TX
-        //qDebug() << Q_FUNC_INFO << ":  Not in band, exiting... " << endl;
+        //qDebug() << Q_FUNC_INFO << ":  Not in band, exiting... " << QT_ENDL;
         rxFreqSpinBox->setToolTip(tr("RX Frequency in MHz.\nFrequency is not in a hamradio band!"));
         rxFreqSpinBox->setPalette(palRed);
     }
@@ -586,18 +571,15 @@ void MainWindowSatTab::slotSatFreqRXChanged(const double _f)
         if(!freqInBand)
         { // If the freq does not belong to the current band, we need to update the band
             satBandRXComboBox->setCurrentIndex(satBandRXComboBox->findText(dataProxy->getBandNameFromFreq(rxFreqSpinBox->value()), Qt::MatchCaseSensitive));
-
         }
     }
-
     emit satRxFreqChanged(rxFreqSpinBox->value());
-
     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void MainWindowSatTab::slotSatBandTXComboBoxChanged()
 {
-    //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged: -" << satBandTXComboBox->currentText()  << endl;
+    //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged: -" << satBandTXComboBox->currentText()  << QT_ENDL;
     if (updatingBands || modifying || (satBandTXComboBox->currentText().length()<2))
     {
         return;
@@ -605,18 +587,18 @@ void MainWindowSatTab::slotSatBandTXComboBoxChanged()
     bool freqInBand = dataProxy->isThisFreqInBand(satBandTXComboBox->currentText(), QString::number(txFreqSpinBox->value()));
     if(!freqInBand)
     { // If the freq does not belong to the current band, we need to update the band
-       //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: Band: " << satBandTXComboBox->currentText()  << endl;
-       //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: " << QString::number(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()))  << endl;
+       //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: Band: " << satBandTXComboBox->currentText()  << QT_ENDL;
+        //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: " << QString::number(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()))  << QT_ENDL;
         txFreqSpinBox->setValue(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
         //setUpLinkFreq(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
     }
-   //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged-END" << endl;
+   //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged-END" << QT_ENDL;
     autofillSatMode();
 }
 
 void MainWindowSatTab::slotSatFreqTXChanged(const double _f)
 {
-   //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: " << QString::number(txFreqSpinBox->value()) << endl;
+   //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: " << QString::number(txFreqSpinBox->value()) << QT_ENDL;
     // user changes TX Freq
     // If band is real and band is configured, bandcombo is selected
     // If band is real and not configured, we launch the band config and select the band.
@@ -644,7 +626,7 @@ void MainWindowSatTab::slotSatFreqTXChanged(const double _f)
     int bandId = dataProxy->getBandIdFromFreq(txFreqSpinBox->value());
     if (bandId<1)
     { //This prevent that a non-hamradio frequency is used on TX
-          //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: Not in band, exiting... " << endl;
+          //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: Not in band, exiting... " << QT_ENDL;
         txFreqSpinBox->setToolTip(tr("TX Frequency in MHz.\nFrequency is not in a hamradio band!"));
         txFreqSpinBox->setPalette(palRed);
     }
@@ -654,37 +636,37 @@ void MainWindowSatTab::slotSatFreqTXChanged(const double _f)
         bool freqInBand = dataProxy->isThisFreqInBand(satBandTXComboBox->currentText(), QString::number(txFreqSpinBox->value()));
         if(!freqInBand)
         { // If the freq does not belong to the current band, we need to update the band
-            //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: If the freq does not belong to the current band, we need to update the band" << endl;
-            //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: We define UoLink to: " << dataProxy->getBandNameFromFreq(txFreqSpinBox->value()) << endl;
+            //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: If the freq does not belong to the current band, we need to update the band" << QT_ENDL;
+            //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: We define UoLink to: " << dataProxy->getBandNameFromFreq(txFreqSpinBox->value()) << QT_ENDL;
             satBandTXComboBox->setCurrentIndex(satBandTXComboBox->findText(dataProxy->getBandNameFromFreq(txFreqSpinBox->value()), Qt::MatchCaseSensitive));
             //setUpLinkFreq(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
         }
     //autofillSatMode();
     }
 
-    //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: Emitting: " << QString::number(txFreqSpinBox->value()) << endl;
+    //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: Emitting: " << QString::number(txFreqSpinBox->value()) << QT_ENDL;
     emit satTxFreqChanged(txFreqSpinBox->value());
 
-    //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged-END" << endl;
+    //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged-END" << QT_ENDL;
 }
 
 void MainWindowSatTab::setUpLink(const QString &_t)
 {
-    //qDebug() << "MainWindowsatTab::setUpLink: " << _t << endl;
+    //qDebug() << "MainWindowsatTab::setUpLink: " << _t << QT_ENDL;
     if (satBandTXComboBox->currentText () == _t)
     {
         return;
     }
     int index = satBandTXComboBox->findText(_t, Qt::MatchCaseSensitive);
-    //qDebug() << "MainWindowsatTab::setUpLink: new index: " << QString::number(index) << endl;
-    //qDebug() << "MainWindowsatTab::setUpLink: current index: " << QString::number(satBandTXComboBox->currentIndex()) << endl;
+    //qDebug() << "MainWindowsatTab::setUpLink: new index: " << QString::number(index) << QT_ENDL;
+    //qDebug() << "MainWindowsatTab::setUpLink: current index: " << QString::number(satBandTXComboBox->currentIndex()) << QT_ENDL;
     int indexRX;
     if (index>=0)
     {
         satBandTXComboBox->setCurrentIndex(index);
          if ( dataProxy->getIdFromBandName("2M") ==  dataProxy->getIdFromBandName(_t) )
          {
-             //qDebug() << satNameComboBox->currentText() << endl;
+             //qDebug() << satNameComboBox->currentText() << QT_ENDL;
              if (satNameComboBox->findText("AO-7 - AMSAT-OSCAT 7", Qt::MatchCaseSensitive))
              {
                  indexRX = satBandRXComboBox->findText("10M", Qt::MatchCaseSensitive);
@@ -706,7 +688,7 @@ void MainWindowSatTab::setUpLink(const QString &_t)
 
 void MainWindowSatTab::setUpLinkFreq(const double _t)
 {
-    //qDebug() << "MainWindowsatTab::setUpLinkFreq: " << QString::number(_t) << endl;
+    //qDebug() << "MainWindowsatTab::setUpLinkFreq: " << QString::number(_t) << QT_ENDL;
     if (util->isSameFreq (freqTX, _t))
     {
         return;
@@ -715,19 +697,21 @@ void MainWindowSatTab::setUpLinkFreq(const double _t)
     txFreqSpinBox->setValue(_t);
     setUpLink(dataProxy->getBandNameFromFreq(_t));
 
-   //qDebug() << "MainWindowsatTab::setUpLinkFreq END" << endl;
+   //qDebug() << "MainWindowsatTab::setUpLinkFreq END" << QT_ENDL;
 }
+
 double MainWindowSatTab::getRXFreq()
 {
-    //qDebug() << "MainWindowsatTab::getRXFreq " << endl;
+    //qDebug() << "MainWindowsatTab::getRXFreq " << QT_ENDL;
     return rxFreqSpinBox->value();
 }
 
 void MainWindowSatTab::setDownLinkFreq(const double _t)
 {
-    //qDebug() << "MainWindowsatTab::setDownLinkFreq: " << QString::number(_t) << endl;
+    //qDebug() << "MainWindowsatTab::setDownLinkFreq: " << QString::number(_t) << QT_ENDL;
     if (util->isSameFreq (freqRX, _t))
     {
+        //qDebug() << Q_FUNC_INFO << " - I same freq";
         return;
     }
 
@@ -740,7 +724,7 @@ void MainWindowSatTab::setDownLinkFreq(const double _t)
         satBandRXComboBox->setCurrentIndex(index);
     }
 
-    //qDebug() << "MainWindowsatTab::setDownLinkFreq END" << endl;
+    //qDebug() << "MainWindowsatTab::setDownLinkFreq END" << QT_ENDL;
 }
 
 void MainWindowSatTab::setBandsOfSat(const QString &_p)
@@ -748,7 +732,7 @@ void MainWindowSatTab::setBandsOfSat(const QString &_p)
     // Until the data is in the DB, this function tries to solve data of active sats from: http://www.amsat.org/status/
     // This functio:
     //  - identifies the freqs & bands that the sat is using
-    //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - Short: " << _p.section(' ', 0, 0) << endl;
+    //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - Short: " << _p.section(' ', 0, 0) << QT_ENDL;
     //"AO-7 - AMSAT-OSCAT 7"
     //2M/10M << 2M/70CM
     if (modifying)
@@ -759,55 +743,52 @@ void MainWindowSatTab::setBandsOfSat(const QString &_p)
     double upLink = (dataProxy->getSatelliteUplink(_p.section(' ', 0, 0))).toDouble();
     double downLink = (dataProxy->getSatelliteDownlink(_p.section(' ', 0, 0))).toDouble();
 
-    //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: " << QString::number(upLink)<< endl;
-    //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: " << QString::number(downLink)<< endl;
+    //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: " << QString::number(upLink)<< QT_ENDL;
+    //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: " << QString::number(downLink)<< QT_ENDL;
 
     if (upLink>0)
     {
-        //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: emitting: " << QString::number(upLink)<< endl;
+        //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: emitting: " << QString::number(upLink)<< QT_ENDL;
         emit satTXFreqNeeded(upLink);
-          //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: emitted: " << QString::number(upLink)<< endl;
+          //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: emitted: " << QString::number(upLink)<< QT_ENDL;
     }
     else
     {
-        //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: setting to ZERO (should be = RX) " <<  endl;
+        //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: setting to ZERO (should be = RX) " <<  QT_ENDL;
         txFreqSpinBox->setValue(0);
         //satBandTXComboBox->setCurrentIndex(0);
     }
 
     if (downLink>0)
     {
-          //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emitting: " << QString::number(downLink)<< endl;
+          //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emitting: " << QString::number(downLink)<< QT_ENDL;
         emit satRXFreqNeeded(downLink);
-          //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emitted: " << QString::number(downLink)<< endl;
-
+          //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emitted: " << QString::number(downLink)<< QT_ENDL;
     }
     else
     {
-          //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: setting to ZERO" <<  endl;
+          //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: setting to ZERO" <<  QT_ENDL;
         rxFreqSpinBox->setValue(0);
         //satBandRXComboBox->setCurrentIndex(0);
     }
-      //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emiting: " << QString::number(downLink)<< endl;
+      //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emiting: " << QString::number(downLink)<< QT_ENDL;
     //emit satRxFreqChanged(downLink);
-
-
-      //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - END "  << endl;
+      //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - END "  << QT_ENDL;
 }
 
 void MainWindowSatTab::addNewBand(const QString &_p)
 {
-    //qDebug() << "MainWindowSatTab::addNewBand: " << _p << endl;
+    //qDebug() << "MainWindowSatTab::addNewBand: " << _p << QT_ENDL;
     if (dataProxy->getIdFromBandName(_p)<0)
     {
-        //qDebug() << "MainWindowSatTab::addNewBand: Id: " <<  QString::number(dataProxy->getIdFromBandName(_p)) << endl;
+        //qDebug() << "MainWindowSatTab::addNewBand: Id: " <<  QString::number(dataProxy->getIdFromBandName(_p)) << QT_ENDL;
         return;
     }
     QStringList bands;
     bands.clear();
 
-       //qDebug() << "MainWindowSatTab::addNewBand: RX Id: " <<  QString::number(satBandRXComboBox->count()) << endl;
-       //qDebug() << "MainWindowSatTab::addNewBand: TX Id: " <<  QString::number(satBandTXComboBox->count()) << endl;
+       //qDebug() << "MainWindowSatTab::addNewBand: RX Id: " <<  QString::number(satBandRXComboBox->count()) << QT_ENDL;
+       //qDebug() << "MainWindowSatTab::addNewBand: TX Id: " <<  QString::number(satBandTXComboBox->count()) << QT_ENDL;
 
     for (int i = 0; i < satBandTXComboBox->count(); i++)
     {
@@ -824,46 +805,47 @@ void MainWindowSatTab::addNewBand(const QString &_p)
 
     emit newBandsToBeAdded(bands);
     //addBands(bands);
-    //qDebug() << "MainWindowSatTab::addNewBand: 2 RX Id: " <<  QString::number(satBandRXComboBox->count()) << endl;
-    //qDebug() << "MainWindowSatTab::addNewBand: 2 TX Id: " <<  QString::number(satBandTXComboBox->count()) << endl;
-
+    //qDebug() << "MainWindowSatTab::addNewBand: 2 RX Id: " <<  QString::number(satBandRXComboBox->count()) << QT_ENDL;
+    //qDebug() << "MainWindowSatTab::addNewBand: 2 TX Id: " <<  QString::number(satBandTXComboBox->count()) << QT_ENDL;
 }
 
 void MainWindowSatTab::setModifying (const bool _m)
 {
-    //qDebug() << "MainWindowsatTab::setModifying" << endl;
+    //qDebug() << "MainWindowsatTab::setModifying" << QT_ENDL;
     modifying = _m;
 }
 
 void MainWindowSatTab::slotReturnPressed()
 {
-    //qDebug() << "MainWindowsatTab::slotReturnPressed" << endl;
+    //qDebug() << "MainWindowsatTab::slotReturnPressed" << QT_ENDL;
     emit returnPressed();
 }
 
 void MainWindowSatTab::slotSatKeepThisDataClicked()
 {
-    //qDebug() << Q_FUNC_INFO << endl;
+    //qDebug() << Q_FUNC_INFO << QT_ENDL;
     if (keepThisDataForNextQSOQcheckbox->isChecked())
     {
-        //qDebug() << Q_FUNC_INFO << ": True" << endl;
+        //qDebug() << Q_FUNC_INFO << ": True" << QT_ENDL;
     }
     else
     {
-        //qDebug() << Q_FUNC_INFO << ": False" << endl;
+        //qDebug() << Q_FUNC_INFO << ": False" << QT_ENDL;
     }
     slotSatNameComboBoxChanged();
 }
 
 void MainWindowSatTab::autofillSatMode()
 {
+    //qDebug() << Q_FUNC_INFO ;
     QString downLinkBand = bandToLetter(dataProxy->getBandNameFromFreq(rxFreqSpinBox->value()));
     QString upLinkBand = bandToLetter(dataProxy->getBandNameFromFreq(txFreqSpinBox->value()));
     satModeLineEdit->setText(upLinkBand + "/" + downLinkBand);
 }
 
-QString MainWindowSatTab::bandToLetter(const QString _band)
+QString MainWindowSatTab::bandToLetter(const QString &_band)
 {
+    //qDebug() << Q_FUNC_INFO << ": " << _band;
    QString letter = "";
 
    if (_band == "15M")
@@ -906,6 +888,7 @@ QString MainWindowSatTab::bandToLetter(const QString _band)
    {
        letter = "-";
    }
+   //qDebug() << Q_FUNC_INFO << ": " << _band << " -> " << letter;
    return letter;
 }
 
