@@ -33,7 +33,10 @@
 
 LoTWUtilities::LoTWUtilities(const QString &_klogDir, const QString &_klogVersion, const QString &_parentFunction, DataProxy_SQLite *dp)
 {
-   //qDebug() << "LoTWUtilities::LoTWUtilities(): " << _klogDir << endl;
+#ifdef QT_DEBUG
+  //qDebug() << Q_FUNC_INFO << ": "  << _klogDir << " - " << _parentFunction;
+#else
+#endif
     dataProxy = dp;
     calendar = new QCalendarWidget;
     util = new Utilities;
@@ -59,17 +62,17 @@ LoTWUtilities::LoTWUtilities(const QString &_klogDir, const QString &_klogVersio
 
     connect(calendar, SIGNAL(activated(QDate)), this, SLOT(slotCalendarDateSelected(QDate)));
 
-   //qDebug() << "LoTWUtilities::LoTWUtilities(): - END"  << endl;
+   //qDebug() << "LoTWUtilities::LoTWUtilities(): - END"  << QT_ENDL;
 }
 
 LoTWUtilities::~LoTWUtilities()
 {
-      //qDebug() << "LoTWUtilities::~LoTWUtilities"  << endl;
+      //qDebug() << "LoTWUtilities::~LoTWUtilities"  << QT_ENDL;
 }
 
 void LoTWUtilities::slotCalendarDateSelected(const QDate _d)
 {
-   //qDebug() << "LoTWUtilities::slotCalendarDateSelected: " << _d.toString("yyyyMMdd")  << endl;
+   //qDebug() << "LoTWUtilities::slotCalendarDateSelected: " << _d.toString("yyyyMMdd")  << QT_ENDL;
     firstDate = _d;
     startThefullDownload();
 
@@ -77,23 +80,23 @@ void LoTWUtilities::slotCalendarDateSelected(const QDate _d)
 
 void LoTWUtilities::setFileName(const QString &_fn)
 {
-    //qDebug() << "LoTWUtilities::setFileName: " << _fn  << endl;
+    //qDebug() << "LoTWUtilities::setFileName: " << _fn  << QT_ENDL;
     if (_fn.length()>0)
     {
         fileName = _fn;
     }
-    //qDebug() << "LoTWUtilities::setFileName - END"   << endl;
+    //qDebug() << "LoTWUtilities::setFileName - END"   << QT_ENDL;
 }
 
 QString LoTWUtilities::getFileName()
 {
-    //qDebug() << "LoTWUtilities::getFileName: " << fileName   << endl;
+    //qDebug() << "LoTWUtilities::getFileName: " << fileName   << QT_ENDL;
     return fileName;
 }
 
 bool LoTWUtilities::selectQuery(const int _queryId)
 {
-     //qDebug() << "LoTWUtilities::selectQuery: - Start: " << QString::number(_queryId) << endl;
+     //qDebug() << "LoTWUtilities::selectQuery: - Start: " << QString::number(_queryId) << QT_ENDL;
     bool savePassword = true;
     if (lotwPassword.length()<1)
     {
@@ -104,7 +107,7 @@ bool LoTWUtilities::selectQuery(const int _queryId)
                                                    tr("Please enter your LoTW password: "), QLineEdit::Password, "", &ok);
         if (!ok)
         {
-             //qDebug() << "LoTWUtilities::selectQuery: - END 1" <<  endl;
+             //qDebug() << "LoTWUtilities::selectQuery: - END 1" <<  QT_ENDL;
             return false;
         }
     }
@@ -128,52 +131,52 @@ bool LoTWUtilities::selectQuery(const int _queryId)
     }
     url = QUrl(lotwQuery);
 
-     //qDebug() << "LoTWUtilities::selectQuery: - END" <<  endl;
+     //qDebug() << "LoTWUtilities::selectQuery: - END" <<  QT_ENDL;
 
     return true;
 }
 
 bool LoTWUtilities::setStationCallSign(const QString &_call)
 {
-    //qDebug() << "LoTWUtilities::setStationCallSign: " << _call << endl;
+    //qDebug() << "LoTWUtilities::setStationCallSign: " << _call << QT_ENDL;
     if (!util->isValidCall(_call))
     {
-        //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 1"  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 1"  << QT_ENDL;
         return false;
     }
     if (((dataProxy->getStationCallSignsFromLog(-1)).contains(_call)))
     {
-        //qDebug() << "LoTWUtilities::setStationCallSign: TRUE"  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: TRUE"  << QT_ENDL;
         stationCallsign = _call;
         QDate date = dataProxy->getFirstQSODateFromCall(stationCallsign);
-        //qDebug() << "LoTWUtilities::setStationCallSign: Date: " << startDate  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: Date: " << startDate  << QT_ENDL;
         if (date.isValid())
         {
             startDate = date.toString("yyyyMMdd");
-             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate" << startDate  << endl;
+             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate" << startDate  << QT_ENDL;
         }
         else
         {
             startDate.clear();
-             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate not valid Date" << endl;
+             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate not valid Date" << QT_ENDL;
              //qDebug() << Q_FUNC_INFO << "False 2 - END";
             return false;
         }
 
-        //qDebug() << "LoTWUtilities::setStationCallSign: startDate: " << startDate  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: startDate: " << startDate  << QT_ENDL;
         //qDebug() << Q_FUNC_INFO << "True 1 - END";
         return true;
     }
     else if (dataProxy->getHowManyQSOInLog(-1) <1)
     {
-        //qDebug() << "LoTWUtilities::setStationCallSign:TRUE Empty log"  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign:TRUE Empty log"  << QT_ENDL;
         stationCallsign = _call;
         //qDebug() << Q_FUNC_INFO << "True 2 - END";
         return true;
     }
     else
     {
-        //qDebug() << "LoTWUtilities::setStationCallSign: Not a single QSO in the log with that StationCallsign: " << stationCallsign  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: Not a single QSO in the log with that StationCallsign: " << stationCallsign  << QT_ENDL;
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Question);
         msgBox.setWindowTitle(tr("KLog - LoTW Station callsign"));
@@ -192,7 +195,7 @@ bool LoTWUtilities::setStationCallSign(const QString &_call)
         }
         else
         {
-            //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 2"  << endl;
+            //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 2"  << QT_ENDL;
             //qDebug() << Q_FUNC_INFO << "FALSE 3 - END";
             return false;
         }
@@ -201,7 +204,7 @@ bool LoTWUtilities::setStationCallSign(const QString &_call)
 
 void LoTWUtilities::startRequest(QUrl url)
 {
-    //qDebug() << "LoTWUtilities::startRequest: " << url.toString()  << endl;
+    //qDebug() << "LoTWUtilities::startRequest: " << url.toString()  << QT_ENDL;
     QByteArray agent = QString("KLog-" + klogVersion).toUtf8();
     QNetworkRequest request;
     request.setUrl(url);
@@ -209,7 +212,7 @@ void LoTWUtilities::startRequest(QUrl url)
     //request.setRawHeader("User-Agent", agent);
     //reply = manager->get(QNetworkRequest(url));
     reply = manager->get(request);
-    //qDebug() << "LoTWUtilities::startRequest - 10"  << endl;
+    //qDebug() << "LoTWUtilities::startRequest - 10"  << QT_ENDL;
     // Whenever more data is received from the network,
     // this readyRead() signal is emitted
     connect(reply, SIGNAL(readyRead()), this, SLOT(slotReadyRead()));
@@ -220,24 +223,24 @@ void LoTWUtilities::startRequest(QUrl url)
     // After this signal is emitted,
     // there will be no more updates to the reply's data or metadata.
     connect(reply, SIGNAL(finished()), this, SLOT(slotFinished()));
-    //qDebug() << "LoTWUtilities::startRequest: - END" << endl;
+    //qDebug() << "LoTWUtilities::startRequest: - END" << QT_ENDL;
 }
 
 int LoTWUtilities::download()
 {
-    //qDebug() << "LoTWUtilities::download - Start" << endl;
+    //qDebug() << "LoTWUtilities::download - Start" << QT_ENDL;
     if (!selectQuery(-1))
     {
-        //qDebug() << "LoTWUtilities::download - END-1" << endl;
+        //qDebug() << "LoTWUtilities::download - END-1" << QT_ENDL;
         return -1;
     }
-    //qDebug() << "LoTWUtilities::download: - 10" << endl;
+    //qDebug() << "LoTWUtilities::download: - 10" << QT_ENDL;
     QFileInfo fileInfo(url.path());
 
-    //qDebug() << "LoTWUtilities::download: - 11" << endl;
+    //qDebug() << "LoTWUtilities::download: - 11" << QT_ENDL;
     if (QFile::exists(fileName))
     {
-        //qDebug() << "LoTWUtilities::download: - 12" << endl;
+        //qDebug() << "LoTWUtilities::download: - 12" << QT_ENDL;
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Question);
         msgBox.setWindowTitle(tr("KLog - LoTW File already exists"));
@@ -247,21 +250,21 @@ int LoTWUtilities::download()
         msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
         msgBox.setDefaultButton(QMessageBox::Yes);
         int ret = msgBox.exec();
-        //qDebug() << "LoTWUtilities::download: - 13" << endl;
+        //qDebug() << "LoTWUtilities::download: - 13" << QT_ENDL;
         if (ret == QMessageBox::No)
         {
-             //qDebug() << "LoTWUtilities::download - END- 2" << endl;
+             //qDebug() << "LoTWUtilities::download - END- 2" << QT_ENDL;
             return -2;
         }
       }
-        //qDebug() << "LoTWUtilities::download: - 20 Filename: -" << fileName << "-" << endl;
+        //qDebug() << "LoTWUtilities::download: - 20 Filename: -" << fileName << "-" << QT_ENDL;
         if (!file->isOpen())
         {
-            //qDebug() << "LoTWUtilities::download: - 21 Filename: -" << endl;
+            //qDebug() << "LoTWUtilities::download: - 21 Filename: -" << QT_ENDL;
             file->setFileName(fileName);
-            //qDebug() << "LoTWUtilities::download: - 22 Filename: -" << endl;
+            //qDebug() << "LoTWUtilities::download: - 22 Filename: -" << QT_ENDL;
         }
-        //qDebug() << "LoTWUtilities::download: - 23 Filename: -" << endl;
+        //qDebug() << "LoTWUtilities::download: - 23 Filename: -" << QT_ENDL;
 
       if (!file->open(QIODevice::WriteOnly)) /* Flawfinder: ignore */
       {
@@ -277,49 +280,49 @@ int LoTWUtilities::download()
           //file->close();
           //delete file;
           //file = nullptr;
-           //qDebug() << "LoTWUtilities::download - END - 3" << endl;
+           //qDebug() << "LoTWUtilities::download - END - 3" << QT_ENDL;
           return -3;
       }
-    //qDebug() << "LoTWUtilities::download: - 30" << endl;
+    //qDebug() << "LoTWUtilities::download: - 30" << QT_ENDL;
       // used for progressDialog
       // This will be set true when canceled from progress dialog
     downloadAborted = false;
-    //qDebug() << "LoTWUtilities::download: - 31" << endl;
+    //qDebug() << "LoTWUtilities::download: - 31" << QT_ENDL;
     //progressDialog = new QProgressDialog(nullptr);
-    //qDebug() << "LoTWUtilities::download: - 40" << endl;
+    //qDebug() << "LoTWUtilities::download: - 40" << QT_ENDL;
     pDialog->setLabelText(tr("Downloading data to file: %1.").arg(fileName));
-    //qDebug() << "LoTWUtilities::download: - 41" << endl;
+    //qDebug() << "LoTWUtilities::download: - 41" << QT_ENDL;
     pDialog->setWindowTitle(tr("KLog - LoTW download"));
-    //qDebug() << "LoTWUtilities::download: - 42" << endl;
+    //qDebug() << "LoTWUtilities::download: - 42" << QT_ENDL;
     pDialog->setWindowModality(Qt::WindowModal);
-    //qDebug() << "LoTWUtilities::download: - 43" << endl;
+    //qDebug() << "LoTWUtilities::download: - 43" << QT_ENDL;
     pDialog->reset();
-    //qDebug() << "LoTWUtilities::download: - 44" << endl;
+    //qDebug() << "LoTWUtilities::download: - 44" << QT_ENDL;
     pDialog->setRange(0, 0);
-    //qDebug() << "LoTWUtilities::download: - 45" << endl;
+    //qDebug() << "LoTWUtilities::download: - 45" << QT_ENDL;
     pDialog->setMinimumDuration(0);
-    //qDebug() << "LoTWUtilities::download: - 46" << endl;
+    //qDebug() << "LoTWUtilities::download: - 46" << QT_ENDL;
     pDialog->show();
-    //qDebug() << "LoTWUtilities::download: - 47" << endl;
+    //qDebug() << "LoTWUtilities::download: - 47" << QT_ENDL;
 
     connect(pDialog, SIGNAL(canceled()), this, SLOT(slotCancelDownload()));
-    //qDebug() << "LoTWUtilities::download: - 50" << endl;
+    //qDebug() << "LoTWUtilities::download: - 50" << QT_ENDL;
 
     startRequest(url);
-     //qDebug() << "LoTWUtilities::download - END" << endl;
+     //qDebug() << "LoTWUtilities::download - END" << QT_ENDL;
     return 1;
 
 }
 
 int LoTWUtilities::fullDownload()
 {
-   //qDebug() << "LoTWUtilities::fullDownload" << endl;
+   //qDebug() << "LoTWUtilities::fullDownload" << QT_ENDL;
     QDate date = dataProxy->getFirstQSODateFromCall(stationCallsign);
-   //qDebug() << "LoTWUtilities::fullDownload: Date: " << startDate  << endl;
+   //qDebug() << "LoTWUtilities::fullDownload: Date: " << startDate  << QT_ENDL;
     if (date.isValid())
     {
         startDate = date.toString("yyyyMMdd");
-        //qDebug() << "LoTWUtilities::fullDownload: StartDate" << startDate  << endl;
+        //qDebug() << "LoTWUtilities::fullDownload: StartDate" << startDate  << QT_ENDL;
     }
     QMessageBox msgBox;
     msgBox.setIcon(QMessageBox::Question);
@@ -332,7 +335,7 @@ int LoTWUtilities::fullDownload()
     int ret = msgBox.exec();
     if (ret == QMessageBox::Yes)
     {
-         //qDebug() << "LoTWUtilities::fulldownload - Yes" << endl;
+         //qDebug() << "LoTWUtilities::fulldownload - Yes" << QT_ENDL;
           firstDate = date;
           startThefullDownload();
           return 1;
@@ -342,14 +345,14 @@ int LoTWUtilities::fullDownload()
     calendar->setGridVisible(true);
     calendar->setMaximumDate(QDate::currentDate());
     calendar->show();
-   //qDebug() << "LoTWUtilities::fullDownload - END" << endl;
+   //qDebug() << "LoTWUtilities::fullDownload - END" << QT_ENDL;
     return 2;
 }
 
 int LoTWUtilities::startThefullDownload()
 {
 
-   //qDebug() << "LoTWUtilities::startThefulldownload - Start" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload - Start" << QT_ENDL;
     if (calendar->isVisible())
     {
         calendar->close();
@@ -357,16 +360,16 @@ int LoTWUtilities::startThefullDownload()
 
     if (!selectQuery(2))
     {
-       //qDebug() << "LoTWUtilities::startThefulldownload - END-1" << endl;
+       //qDebug() << "LoTWUtilities::startThefulldownload - END-1" << QT_ENDL;
         return -1;
     }
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 10" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 10" << QT_ENDL;
     QFileInfo fileInfo(url.path());
 
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 11" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 11" << QT_ENDL;
    if (QFile::exists(fileName))
    {
-       //qDebug() << "LoTWUtilities::startThefulldownload: - 12" << endl;
+       //qDebug() << "LoTWUtilities::startThefulldownload: - 12" << QT_ENDL;
        QMessageBox msgBox;
        msgBox.setIcon(QMessageBox::Question);
        msgBox.setWindowTitle(tr("KLog - LoTW File already exists"));
@@ -376,21 +379,21 @@ int LoTWUtilities::startThefullDownload()
        msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
        msgBox.setDefaultButton(QMessageBox::Yes);
        int ret = msgBox.exec();
-       //qDebug() << "LoTWUtilities::startThefulldownload: - 13" << endl;
+       //qDebug() << "LoTWUtilities::startThefulldownload: - 13" << QT_ENDL;
        if (ret == QMessageBox::No)
        {
-            //qDebug() << "LoTWUtilities::startThefulldownload - END- 2" << endl;
+            //qDebug() << "LoTWUtilities::startThefulldownload - END- 2" << QT_ENDL;
            return -2;
        }
      }
-       //qDebug() << "LoTWUtilities::startThefulldownload: - 20 Filename: -" << fileName << "-" << endl;
+       //qDebug() << "LoTWUtilities::startThefulldownload: - 20 Filename: -" << fileName << "-" << QT_ENDL;
        if (!file->isOpen())
        {
-           //qDebug() << "LoTWUtilities::startThefulldownload: - 21 Filename: -" << endl;
+           //qDebug() << "LoTWUtilities::startThefulldownload: - 21 Filename: -" << QT_ENDL;
            file->setFileName(fileName);
-           //qDebug() << "LoTWUtilities::startThefulldownload: - 22 Filename: -" << endl;
+           //qDebug() << "LoTWUtilities::startThefulldownload: - 22 Filename: -" << QT_ENDL;
        }
-       //qDebug() << "LoTWUtilities::startThefulldownload: - 23 Filename: -" << endl;
+       //qDebug() << "LoTWUtilities::startThefulldownload: - 23 Filename: -" << QT_ENDL;
 
      if (!file->open(QIODevice::WriteOnly)) /* Flawfinder: ignore */
      {
@@ -406,65 +409,65 @@ int LoTWUtilities::startThefullDownload()
          //file->close();
          //delete file;
          //file = nullptr;
-          //qDebug() << "LoTWUtilities::startThefulldownload - END - 3" << endl;
+          //qDebug() << "LoTWUtilities::startThefulldownload - END - 3" << QT_ENDL;
          return -3;
      }
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 30" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 30" << QT_ENDL;
      // used for progressDialog
      // This will be set true when canceled from progress dialog
    downloadAborted = false;
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 31" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 31" << QT_ENDL;
    //progressDialog = new QProgressDialog(nullptr);
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 40" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 40" << QT_ENDL;
    pDialog->setLabelText(tr("Downloading data to file: %1.").arg(fileName));
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 41" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 41" << QT_ENDL;
    pDialog->setWindowTitle(tr("KLog - LoTW download"));
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 42" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 42" << QT_ENDL;
    pDialog->setWindowModality(Qt::WindowModal);
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 43" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 43" << QT_ENDL;
    pDialog->reset();
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 44" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 44" << QT_ENDL;
    pDialog->setRange(0, 0);
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 45" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 45" << QT_ENDL;
    pDialog->setMinimumDuration(0);
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 46" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 46" << QT_ENDL;
    pDialog->show();
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 47" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 47" << QT_ENDL;
 
    connect(pDialog, SIGNAL(canceled()), this, SLOT(slotCancelDownload()));
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 50" << endl;
+   //qDebug() << "LoTWUtilities::startThefulldownload: - 50" << QT_ENDL;
 
    startRequest(url);
-    //qDebug() << "LoTWUtilities::startThefulldownload - END" << endl;
+    //qDebug() << "LoTWUtilities::startThefulldownload - END" << QT_ENDL;
 
     return 1;
 }
 
 void LoTWUtilities::slotDownloadProgress(qint64 bytesRead) {
-    //qDebug() << "LoTWUtilities::slotDownloadProgress: " << QString::number(bytesRead) << endl;
+    //qDebug() << "LoTWUtilities::slotDownloadProgress: " << QString::number(bytesRead) << QT_ENDL;
     if (downloadAborted)
     {
-         //qDebug() << "LoTWUtilities::slotDownloadProgress: CANCELLED" << endl;
+         //qDebug() << "LoTWUtilities::slotDownloadProgress: CANCELLED" << QT_ENDL;
         return;
     }
 
     pDialog->setValue(bytesRead);
-     //qDebug() << "LoTWUtilities::slotDownloadProgress - END " << endl;
+     //qDebug() << "LoTWUtilities::slotDownloadProgress - END " << QT_ENDL;
 }
 
 void LoTWUtilities::slotReadyRead()
 {
-    //qDebug() << "LoTWUtilities::slotReadyRead: " << reply->readLine() << endl;
+    //qDebug() << "LoTWUtilities::slotReadyRead: " << reply->readLine() << QT_ENDL;
     if (file)
     {
         file->write(reply->readAll());
     }
-    //qDebug() << "LoTWUtilities::slotReadyRead - END" << endl;
+    //qDebug() << "LoTWUtilities::slotReadyRead - END" << QT_ENDL;
 }
 
 void LoTWUtilities::slotFinished()
 {
-    //qDebug() << "LoTWUtilities::slotFinished - Started" << endl;
+    //qDebug() << "LoTWUtilities::slotFinished - Started" << QT_ENDL;
     // when canceled
      if (downloadAborted)
      {
@@ -478,21 +481,21 @@ void LoTWUtilities::slotFinished()
          //reply->deleteLater();
          pDialog->cancel();
          reply->close();
-         //qDebug() << "LoTWUtilities::slotFinished - END Canceled" << endl;
+         //qDebug() << "LoTWUtilities::slotFinished - END Canceled" << QT_ENDL;
          return;
      }
-    //qDebug() << "LoTWUtilities::slotFinished - 10" << endl;
+    //qDebug() << "LoTWUtilities::slotFinished - 10" << QT_ENDL;
      // download finished normally
     pDialog->cancel();
-    //qDebug() << "LoTWUtilities::slotFinished - 11" << endl;
+    //qDebug() << "LoTWUtilities::slotFinished - 11" << QT_ENDL;
     file->flush();
-    //qDebug() << "LoTWUtilities::slotFinished - 12" << endl;
+    //qDebug() << "LoTWUtilities::slotFinished - 12" << QT_ENDL;
     file->close();
-    //qDebug() << "LoTWUtilities::slotFinished - 13" << endl;
+    //qDebug() << "LoTWUtilities::slotFinished - 13" << QT_ENDL;
 
      // get redirection url
      QVariant redirectionTarget = reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
-     //qDebug() << "LoTWUtilities::slotFinished - 14" << endl;
+     //qDebug() << "LoTWUtilities::slotFinished - 14" << QT_ENDL;
      if (reply->error())
      {
          file->remove();
@@ -509,7 +512,7 @@ void LoTWUtilities::slotFinished()
     }
     else if (!redirectionTarget.isNull())
     {
-         //qDebug() << "LoTWUtilities::slotFinished - Redirection" << endl;
+         //qDebug() << "LoTWUtilities::slotFinished - Redirection" << QT_ENDL;
         QUrl newUrl = url.resolved(redirectionTarget.toUrl());
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Question);
@@ -527,52 +530,52 @@ void LoTWUtilities::slotFinished()
             file->open(QIODevice::WriteOnly); /* Flawfinder: ignore */
             file->resize(0);
             startRequest(url);
-             //qDebug() << "LoTWUtilities::slotFinished - END-1" << endl;
+             //qDebug() << "LoTWUtilities::slotFinished - END-1" << QT_ENDL;
             return;
         }
      }
     else
     {
-        //qDebug() << "LoTWUtilities::slotFinished:  "  << endl;
+        //qDebug() << "LoTWUtilities::slotFinished:  "  << QT_ENDL;
     }
-    //qDebug() << "LoTWUtilities::slotReadyRead - Going to parse ..." << endl;
+    //qDebug() << "LoTWUtilities::slotReadyRead - Going to parse ..." << QT_ENDL;
     parseDownloadedFile(file->fileName());
-    //qDebug() << "LoTWUtilities::slotReadyRead - END" << endl;
+    //qDebug() << "LoTWUtilities::slotReadyRead - END" << QT_ENDL;
 }
 
 void LoTWUtilities::slotCancelDownload()
 {
-     //qDebug() << "LoTWUtilities::slotCancelDownload - Start" << endl;
+     //qDebug() << "LoTWUtilities::slotCancelDownload - Start" << QT_ENDL;
     downloadAborted = true;
     reply->abort();
-     //qDebug() << "LoTWUtilities::slotCancelDownload - END" << endl;
+     //qDebug() << "LoTWUtilities::slotCancelDownload - END" << QT_ENDL;
 }
 
 void LoTWUtilities::setUser(const QString &_call)
 {
-     //qDebug() << "LoTWUtilities::setUser: " << _call << endl;
+     //qDebug() << "LoTWUtilities::setUser: " << _call << QT_ENDL;
     lotwUser = _call;
-     //qDebug() << "LoTWUtilities::setUser: END" << endl;
+     //qDebug() << "LoTWUtilities::setUser: END" << QT_ENDL;
 }
 
 void LoTWUtilities::setPass(const QString &_pass)
 {
-     //qDebug() << "LoTWUtilities::setPass: " << _pass << endl;
+     //qDebug() << "LoTWUtilities::setPass: " << _pass << QT_ENDL;
     lotwPassword = _pass;
-     //qDebug() << "LoTWUtilities::setPass: END" << endl;
+     //qDebug() << "LoTWUtilities::setPass: END" << QT_ENDL;
 }
 
 bool LoTWUtilities::getIsReady()
 {
-     //qDebug() << "LoTWUtilities::getIsReady: user/station: -" << lotwUser <<"/" << stationCallsign << "-" << endl;
+     //qDebug() << "LoTWUtilities::getIsReady: user/station: -" << lotwUser <<"/" << stationCallsign << "-" << QT_ENDL;
     if ((lotwUser.length()>1) && (stationCallsign.length()>1))
     {
-         //qDebug() << "LoTWUtilities::getIsReady: true" << endl;
+         //qDebug() << "LoTWUtilities::getIsReady: true" << QT_ENDL;
         return true;
     }
     else
     {
-         //qDebug() << "LoTWUtilities::getIsReady: false" << endl;
+         //qDebug() << "LoTWUtilities::getIsReady: false" << QT_ENDL;
       return false;
     }
 
@@ -580,7 +583,7 @@ bool LoTWUtilities::getIsReady()
 
 void LoTWUtilities::parseDownloadedFile(const QString &_fn)
 {
-    //qDebug() << "LoTWUtilities::parseDownloadedFile: " << _fn << endl;
+    //qDebug() << "LoTWUtilities::parseDownloadedFile: " << _fn << QT_ENDL;
     QString _fileName = _fn;
     QMessageBox msgBox;
     QString aux;
@@ -588,7 +591,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
     QFile file( _fileName );
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) /* Flawfinder: ignore */
     {
-        //qDebug() << "LoTWUtilities::parseDownloadedFile File not found" << _fileName << endl;
+        //qDebug() << "LoTWUtilities::parseDownloadedFile File not found" << _fileName << QT_ENDL;
         msgBox.setIcon(QMessageBox::Warning);
         msgBox.setWindowTitle(tr("KLog - LoTW File not found"));
         msgBox.setText(tr("KLog can't find the downloaded file."));
@@ -598,7 +601,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
         msgBox.setStandardButtons(QMessageBox::Ok);
         msgBox.setDefaultButton(QMessageBox::Ok);
         msgBox.exec();
-        //qDebug() << "LoTWUtilities::parseDownloadedFile: END-1" << endl;
+        //qDebug() << "LoTWUtilities::parseDownloadedFile: END-1" << QT_ENDL;
         return ;
     }
     else
@@ -615,28 +618,29 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
         {
             QByteArray line = file.readLine();
             QString lineU = line.toUpper();
-            //qDebug() << "LoTWUtilities::parseDownloadedFile: lineU: " << lineU << endl;
+            //qDebug() << "LoTWUtilities::parseDownloadedFile: lineU: " << lineU << QT_ENDL;
             if (lineU.contains("<EOH>"))
             {
-                 //qDebug() << "LoTWUtilities::parseDownloadedFile: EOH found" << endl;
+                 //qDebug() << "LoTWUtilities::parseDownloadedFile: EOH found" << QT_ENDL;
                 hasHeader = true;
             }
             //else if (lineU.contains("<PROGRAMID:4>LOTW"))
             //{
-            //     //qDebug() << "LoTWUtilities::parseDownloadedFile: ProgramID found" << endl;
+            //     //qDebug() << "LoTWUtilities::parseDownloadedFile: ProgramID found" << QT_ENDL;
             //    hasProgramID = true;
             //}
             //else if (lineU.contains(Lotw_owncall))
             //{
-            //     //qDebug() << "LoTWUtilities::parseDownloadedFile: OWNCALL found" << endl;
+            //     //qDebug() << "LoTWUtilities::parseDownloadedFile: OWNCALL found" << QT_ENDL;
             //    hasOwnCall = true;
             //}
             else if (lineU.contains("<APP_LOTW_NUMREC:"))
             {
                 QStringList data;
-                data << lineU.split('>', QString::SkipEmptyParts);
+                data << lineU.split('>', QT_SKIP);
+
                 numQSO = (data.at(1)).toInt();
-                 //qDebug() << "LoTWUtilities::parseDownloadedFile: QSOs: " << QString::number(numQSO) << endl;
+                 //qDebug() << "LoTWUtilities::parseDownloadedFile: QSOs: " << QString::number(numQSO) << QT_ENDL;
             }
             else if (lineU.contains("<I>USERNAME/PASSWORD INCORRECT</I>"))
             {
@@ -647,7 +651,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
         if (!hasHeader || (numQSO<1))
         {
 
-             //qDebug() << "LoTWUtilities::parseDownloadedFile Header not found" << _fileName << endl;
+             //qDebug() << "LoTWUtilities::parseDownloadedFile Header not found" << _fileName << QT_ENDL;
             QString aux;
             if (userPasswordError)
             {
@@ -674,7 +678,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
             msgBox.setStandardButtons(QMessageBox::Ok);
             msgBox.setDefaultButton(QMessageBox::Ok);
             msgBox.exec();
-            //qDebug() << "LoTWUtilities::parseDownloadedFile: END-2" << endl;
+            //qDebug() << "LoTWUtilities::parseDownloadedFile: END-2" << QT_ENDL;
             file.remove();
             return ;
         }
@@ -689,7 +693,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
         msgBox.setDefaultButton(QMessageBox::Yes);
         if (msgBox.exec() == QMessageBox::No)
         {
-            //qDebug() << "LoTWUtilities::parseDownloadedFile: END-2" << endl;
+            //qDebug() << "LoTWUtilities::parseDownloadedFile: END-2" << QT_ENDL;
             return ;
         }
         //file.seek(startOfFile);
@@ -701,7 +705,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
    //Procesar los QSOs y meterlos en una tabla? o en un QStringList o alguna otra estructura
 
 
-    //qDebug() << "LoTWUtilities::parseDownloadedFile - END"  << endl;
+    //qDebug() << "LoTWUtilities::parseDownloadedFile - END"  << QT_ENDL;
 }
 
 /*void LoTWUtilities::showMessage(const int _messageIcon, const QString &_msg, const QString &_msgExt)
