@@ -23,8 +23,6 @@
  *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
-
-
 #include <QtWidgets>
 //#include <QtSql>
 #include <QTranslator>
@@ -36,40 +34,40 @@
 #include <QSystemSemaphore>
 #include <QSharedMemory>
 #include <QMessageBox>
-
-//#include <QDebug>
-
-
+#include "klogdefinitions.h"
 #include "startwizard.h"
 #include "mainwindow.h"
 #include "utilities.h"
 
 
+
 int main(int argc, char *argv[])
 {
-    //qDebug() << "KLog Main: Start! " << endl;
-    //qDebug() << "KLog Main: " << QSslSocket::supportsSsl() << QSslSocket::sslLibraryBuildVersionString() << QSslSocket::sslLibraryVersionString() << endl;
-    QT_REQUIRE_VERSION(argc, argv, "5.11")
+    //qDebug() << "KLog Main: Start! " << QT_ENDL;
+    //qDebug() << "KLog Main: " << QSslSocket::supportsSsl() << QSslSocket::sslLibraryBuildVersionString() << QSslSocket::sslLibraryVersionString() << QT_ENDL;
+    QT_REQUIRE_VERSION(argc, argv, "5.9")
+
     QDir d1 = QDir();
-    QString version = "1.7";
-    //qDebug() << "KLog Main STARTED: " << version << endl;
+    //QCoreApplication::setApplicationVersion(QString(APP_VERSION));
+    //qDebug() << "KLog Main STARTED: " << version << QT_ENDL;
     Utilities util = Utilities();
     QStringList arguments;
     QTextStream cout(stdout);
-    QCoreApplication::setOrganizationName("EA4K");
-    QCoreApplication::setOrganizationDomain("klog.xyz");
-    QCoreApplication::setApplicationName("KLog");
+    //QCoreApplication::setOrganizationName("EA4K");
+    //QCoreApplication::setOrganizationDomain("klog.xyz");
+    //QCoreApplication::setApplicationName("KLog");
     QApplication app(argc, argv);
 
     QString iconSt;
     iconSt = ":/img/klog.ico";
     QIcon KLogIcon(iconSt);
     QApplication::setWindowIcon(KLogIcon);
-
-    //QApplication app(argc, argv);
     app.setApplicationName(QString("KLog"));
-    app.setApplicationVersion(QString(version));
-    //qDebug() << "KLog Main: -10 " << endl;
+    app.setOrganizationName("EA4K");
+    app.setOrganizationDomain("klog.xyz");
+    app.setApplicationVersion(QString(APP_VERSION));
+    QString version = QCoreApplication::applicationVersion();
+    //qDebug() << "KLog Main: -10 " << QT_ENDL;
     // Now we check if the user is executing from the command line
     arguments.clear();
     arguments << app.arguments();
@@ -77,39 +75,42 @@ int main(int argc, char *argv[])
     {
         if (arguments.contains("-h"))
         {
-            //cout << "Usage: klog [OPTION]... [FILE]..." << endl;
-            cout << "Usage: klog [OPTION]..." << endl;
-            cout << "Options:" << endl;
-            cout << "     -?           Display this help" << endl;
-            cout << "     -h           Display this help" << endl;
-            cout << "     -v           Display program version" << endl;
-            //cout << "     -e <file>    Export Adif file <file>" << endl;
+            //cout << "Usage: klog [OPTION]... [FILE]..." << QT_ENDL;
+
+            cout << "Usage: klog [OPTION]..." << QT_ENDL;
+            cout << "Options:" << QT_ENDL;
+            cout << "     -?           Display this help" << QT_ENDL;
+            cout << "     -h           Display this help" << QT_ENDL;
+            cout << "     -v           Display program version" << QT_ENDL;
+
+            //cout << "     -e <file>    Export Adif file <file>" << QT_ENDL;
         }
         else if (arguments.contains("-?"))
         {
-            cout << "Usage: klog [OPTION]..." << endl;
-            cout << "Options:" << endl;
-            cout << "     -?           Display this help" << endl;
-            cout << "     -h           Display this help" << endl;
-            cout << "     -v           Display program version" << endl;
+            cout << "Usage: klog [OPTION]..." << QT_ENDL;
+            cout << "Options:" << QT_ENDL;
+            cout << "     -?           Display this help" << QT_ENDL;
+            cout << "     -h           Display this help" << QT_ENDL;
+            cout << "     -v           Display program version" << QT_ENDL;
         }
         else if (arguments.contains("-v"))
         {
-            cout << "Version: KLog-" << app.applicationVersion() << endl;
+            cout << "Version: KLog-" << app.applicationVersion() << QT_ENDL;
+
         }
         else
         {
-            cout << "Usage: klog [OPTION]..." << endl;
-            cout << "Options:" << endl;
-            cout << "     -?           Display this help" << endl;
-            cout << "     -h           Display this help" << endl;
-            cout << "     -v           Display program version" << endl;
+            cout << "Usage: klog [OPTION]..." << QT_ENDL;
+            cout << "Options:" << QT_ENDL;
+            cout << "     -?           Display this help" << QT_ENDL;
+            cout << "     -h           Display this help" << QT_ENDL;
+            cout << "     -v           Display program version" << QT_ENDL;
         }
         app.quit();
         return 0;
     }
-    //qDebug() << "KLog Main: Start of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << endl;
-    //qDebug() << "KLog Main: Detected language: " << (QLocale::system().name()).left(2) << ".qm" << endl;
+    //qDebug() << "KLog Main: Start of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << "KLog Main: Detected language: " << (QLocale::system().name()).left(2) << ".qm" << QT_ENDL;
     // Translations begin
     QTranslator qtTranslator;
     qtTranslator.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)); /* Flawfinder: ignore */
@@ -120,8 +121,8 @@ int main(int argc, char *argv[])
     //QString msgOSFilePath = QString();        // The OS depending part of the message to be printed if no translation is found.
 
     #if defined(Q_OS_WIN)
-        //qDebug() << "KLog WIN " << endl;
-        //qDebug() << "KLog Main: -20 - WIN" << endl;
+        //qDebug() << "KLog WIN " << QT_ENDL;
+        //qDebug() << "KLog Main: -20 - WIN" << QT_ENDL;
         if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
             myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm"); /* Flawfinder: ignore */
@@ -138,9 +139,9 @@ int main(int argc, char *argv[])
             missingTranslation = true;
             //msgOSFilePath = QCoreApplication::applicationDirPath() + "/translations/" ;
         }
-      //qDebug() << "KLog Main: -20 - end WIN " << endl;
+      //qDebug() << "KLog Main: -20 - end WIN " << QT_ENDL;
     #elif defined(Q_OS_OSX)
-    //qDebug() << "KLog OSX " << endl;
+    //qDebug() << "KLog OSX " << QT_ENDL;
 
         if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" +  (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
@@ -155,19 +156,19 @@ int main(int argc, char *argv[])
             missingTranslation = true;
         }
     #else
-           //qDebug() << "KLog OTHER OS: " << (QLocale::system()).name() << endl;
+           //qDebug() << "KLog OTHER OS: " << (QLocale::system()).name() << QT_ENDL;
         if (QFile::exists("klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
             myappTranslator.load("klog_" + (QLocale::system().name()).left(2)); /* Flawfinder: ignore */
         }
         else if (QFile::exists("/usr/share/klog/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
-               //qDebug() << "KLog OTHER -2: " << "/usr/share/klog/klog_" + (QLocale::system().name()).left(2) << endl; /* Flawfinder: ignore */
+               //qDebug() << "KLog OTHER -2: " << "/usr/share/klog/klog_" + (QLocale::system().name()).left(2) << QT_ENDL; /* Flawfinder: ignore */
             myappTranslator.load("/usr/share/klog/translations/klog_" + (QLocale::system().name()));  /* Flawfinder: ignore */
         }
         else if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm")) /* Flawfinder: ignore */
         {
-            //qDebug() << "KLog OTHER -3: " << QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) << endl;
+            //qDebug() << "KLog OTHER -3: " << QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) << QT_ENDL;
             myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name())); /* Flawfinder: ignore */
         }
 
@@ -182,10 +183,10 @@ int main(int argc, char *argv[])
         }
 
     #endif
-    //qDebug() << "KLog Main: -40 " << endl;
+    //qDebug() << "KLog Main: -40 " << QT_ENDL;
     if (missingTranslation)
         {
-            //qDebug() << "KLog Main: Translation missing! " << endl;
+            //qDebug() << "KLog Main: Translation missing! " << QT_ENDL;
             QMessageBox msgBox;
             QString urlTranslate = QString();
             urlTranslate = "<p><a href=\"https://translate.google.com/?sl=auto&tl=auto#en/auto/No%20translation%20files%20for%20your%20language%20have%20been%20found%20so%20KLog%20will%20be%20shown%20in%20English.%0A%0AIf%20you%20have%20the%20klog_en.qm%20file%20for%20your%20language%2C%20you%20can%20copy%20it%20in%20the%20%2Fhome%2Fdevel%2F.klog%2F%20folder%20and%20restart%20KLog%20again.%0A%0A%20If%20you%20want%20to%20help%20to%20translate%20KLog%20into%20your%20language%2C%20please%20contact%20the%20author.\">TRANSLATE</a></p>";
@@ -208,10 +209,10 @@ int main(int argc, char *argv[])
 
         }
 
-    //qDebug() << "KLog Main-1" << (QTime::currentTime()).toString("HH:mm:ss")  << endl;
+    //qDebug() << "KLog Main-1" << (QTime::currentTime()).toString("HH:mm:ss")  << QT_ENDL;
 
     app.installTranslator(&myappTranslator);
-    //qDebug() << "KLog Main: End of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << endl;
+    //qDebug() << "KLog Main: End of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
     // Traslations end
 
     /* Application Singleton
@@ -221,7 +222,7 @@ int main(int argc, char *argv[])
     QSystemSemaphore semaphore("klogapp", 1);  // create semaphore with unique ID klogapp
     semaphore.acquire();                       // Raise the semaphore, barring other instances to work with shared memory
 
-#ifndef Q_OS_WIN32
+#ifndef Q_OS_WIN
     // in linux / unix shared memory is not freed when the application terminates abnormally,
     // so you need to get rid of the garbage
     QSharedMemory nix_fix_shared_memory("klogshm");
@@ -271,51 +272,52 @@ int main(int argc, char *argv[])
     klogDir = util.getHomeDir();
     configFileName = util.getCfgFile();
 
-    //qDebug() << "KLog Main-10" << endl;
+    //qDebug() << "KLog Main-10" << QT_ENDL;
 
-    //qDebug() << "KLog Main: Setting klog dir: " << (QTime::currentTime()).toString("HH:mm:ss")<< endl;;
+    //qDebug() << "KLog Main: Setting klog dir: " << (QTime::currentTime()).toString("HH:mm:ss")<< QT_ENDL;;
     if (!QDir::setCurrent (klogDir) )
     {
-        //qDebug() << "MAIN:  KLogDir does not exist.... creating " << endl;
+        //qDebug() << "MAIN:  KLogDir does not exist.... creating " << QT_ENDL;
         if (d1.mkdir(klogDir))
         {
             if (QDir::setCurrent (klogDir) )
             {
-                    //qDebug() << "MAIN:  KLogDir has just been created and pointed " << endl;
+                    //qDebug() << "MAIN:  KLogDir has just been created and pointed " << QT_ENDL;
             }
             else
             {
-                    //qDebug() << "MAIN:  KLogDir has just been created and pointed FAILED! " << endl;
+                    //qDebug() << "MAIN:  KLogDir has just been created and pointed FAILED! " << QT_ENDL;
             }
         }
         else
         {
-                //qDebug() << "MAIN:  KLogDir can not be created?? " << endl;
+                //qDebug() << "MAIN:  KLogDir can not be created?? " << QT_ENDL;
         }
     }
     else
     {
-        //qDebug() << "MAIN:  KLogDir already existed!! " << endl;
+        //qDebug() << "MAIN:  KLogDir already existed!! " << QT_ENDL;
     }
-    //qDebug() << "KLog Main: Setting klog dir - finished: " << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+    //qDebug() << "KLog Main: Setting klog dir - finished: " << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
 
-    //qDebug() << "KLog Main: Setting config file: " << (QTime::currentTime()).toString("HH:mm:ss")  << endl;
+    //qDebug() << "KLog Main: Setting config file: " << (QTime::currentTime()).toString("HH:mm:ss")  << QT_ENDL;
     QPixmap pixmap(":img/klog_512x512.png");
-    //qDebug() << "KLog Main-51" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+    //qDebug() << "KLog Main-51" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
     QSplashScreen splash(pixmap);
+
     if(!QFile::exists(configFileName))
     {
-        //qDebug() << "MAIN:  Starting wizard... " << endl;
+        //qDebug() << "MAIN:  Starting wizard... " << QT_ENDL;
 
         StartWizard *wizard = new StartWizard(klogDir, version);
         wizard->setModal(true);
         int inMemory = wizard->exec();
-        //qDebug() << "MAIN: Wizard inMemory: " << QString::number(inMemory) << endl;
+        //qDebug() << "MAIN: Wizard inMemory: " << QString::number(inMemory) << QT_ENDL;
         inMemory = 1;
 
         if (inMemory == 1)
         {
-            //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in Memory " << endl;
+            //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in Memory " << QT_ENDL;
             MainWindow mw(klogDir, version);
             mw.init();
             splash.finish(&mw);
@@ -327,7 +329,7 @@ int main(int argc, char *argv[])
 
         else
         {
-               //qDebug() << "MAIN: Wizard cancelled " << QString::number(inMemory) << " ... should close " << endl;
+               //qDebug() << "MAIN: Wizard cancelled " << QString::number(inMemory) << " ... should close " << QT_ENDL;
 
             QMessageBox msgBox;
             msgBox.setText(QObject::tr("Install wizard was canceled before completing..."));
@@ -373,41 +375,42 @@ int main(int argc, char *argv[])
 
     else
     {
-            //qDebug() << "Main: Start of DB Activities" << endl;
+        //qDebug() << "Main: Start of DB Activities" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         DataBase *db = new DataBase(Q_FUNC_INFO, version, util.getKLogDBFile());
-           //qDebug() << "Main: After Start of DB Activities" << endl;
+        //qDebug() << "Main: After Start of DB Activities" << QT_ENDL;
         if (!db->createConnection(Q_FUNC_INFO))
         {
-                //qDebug() << "Main: Conection not created" << endl;
+            //qDebug() << "Main: Conection not created" << QT_ENDL;
             return -1; // Exits with an error; no DB has been created
         }
         else
         {
-            //qDebug() << "Main: DB to be updated" << endl;
+            //qDebug() << "Main: DB to be updated" << QT_ENDL;
             db->updateIfNeeded(); // Check if we need to update the DB
-            //qDebug() << "Main: DB Updated" << endl;
+            //qDebug() << "Main: DB Updated" << QT_ENDL;
         }
+        //qDebug() << "Main: DB Updated" << QT_ENDL;
+        //qDebug() << "KLog Main-98" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         db->~DataBase();
-
+        //qDebug() << "KLog Main-99" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         splash.show();
-          //qDebug() << "KLog Main-100" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+        //qDebug() << "KLog Main-100" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         MainWindow mw(klogDir, version);
-
+        //qDebug() << "KLog Main-101" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         mw.init();
+        //qDebug() << "KLog Main-102" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         splash.finish(&mw);
+        //qDebug() << "KLog Main-103" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         mw.checkIfNewVersion();
+        //qDebug() << "KLog Main-104" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         mw.recommendBackupIfNeeded();
-
-            //qDebug() << "KLog Main-101" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+        //qDebug() << "KLog Main-105" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         mw.show();
-            //qDebug() << "KLog Main-101.5" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
-
-           //qDebug() << "KLog Main-102" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
-
+        //qDebug() << "KLog Main-106" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
         return app.exec();
-           //qDebug() << "KLog Main-103" << (QTime::currentTime()).toString("HH:mm:ss") << endl;
+        //qDebug() << "KLog Main-107" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
     }
-       //qDebug() << "KLog Main-END: " << (QTime::currentTime()).toString("HH:mm:ss")  << endl;
+        //qDebug() << "KLog Main-END: " << (QTime::currentTime()).toString("HH:mm:ss")  << QT_ENDL;
 
     //return app.exec();
 }
