@@ -28,7 +28,7 @@
 
 MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
 {
-      //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget " << endl;
+      //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget " << QT_ENDL;
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
 
     upAndRunning = false;
@@ -40,6 +40,7 @@ MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) :
     timeEdit = new QTimeEdit;
     realtimeCheckBox = new QCheckBox;
     enabledCR = realtimeCheckBox->backgroundRole();
+    manualModeCheckBox = new QCheckBox;
 
     OKButton = new QPushButton(tr("&Add"), this);
     clearButton = new QPushButton(tr("&Clear"), this);
@@ -49,12 +50,14 @@ MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) :
     duplicatedQSOSlotInSecs = 0;
     delayInputTimer = new QTimer;
 
+    //hamlib = new HamLibClass();
+
 
     createUI();
     setInitialData();
     //installEventFilter (this);
     emit debugLog(Q_FUNC_INFO, "END", Debug);
-      //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget: - END" << endl;
+      //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget: - END" << QT_ENDL;
 }
 
 /*
@@ -68,7 +71,7 @@ void MainQSOEntryWidget::slotRealTimeButtonResize()
 */
 void MainQSOEntryWidget::createUI()
 {
-      //qDebug()<< "MainQSOEntryWidget::createUI" << endl;
+      //qDebug()<< "MainQSOEntryWidget::createUI" << QT_ENDL;
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
     qrzLineEdit->setToolTip(tr("Callsign of the QSO."));
     bandComboBox->setToolTip(tr("Band of the QSO."));
@@ -80,11 +83,15 @@ void MainQSOEntryWidget::createUI()
     realtimeCheckBox->setToolTip(tr("KLog will show real time if enabled."));
     realtimeCheckBox->setText (tr("Real time"));
     //realtimeButton->setToolTip(tr("KLog will show real time if enabled."));
+    manualModeCheckBox->setToolTip(tr("Stop wsjt-x and hamlib from automatically updating QSO information."));
+    manualModeCheckBox->setText (tr("Manual Mode"));
+
     QHBoxLayout *TimeLayout = new QHBoxLayout;
     TimeLayout->addWidget(dateEdit);
     TimeLayout->addWidget(timeEdit);
     //TimeLayout->addWidget(realtimeButton);
     TimeLayout->addWidget(realtimeCheckBox);
+    TimeLayout->addWidget(manualModeCheckBox);
     TimeLayout->addItem(new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Fixed));
 
     QHBoxLayout *BandModeLayout = new QHBoxLayout;
@@ -134,7 +141,8 @@ void MainQSOEntryWidget::createUI()
     connect(timer, SIGNAL(timeout()), this, SLOT(slotUpdateTime()) );
     //connect(realtimeButton, SIGNAL(clicked()), this, SLOT(slotRealtimeButtonClicked()) );
     connect(realtimeCheckBox, SIGNAL(clicked()), this, SLOT(slotCheckBoxClicked()));
-      //qDebug()<< "MainQSOEntryWidget::createUI-END" << endl;
+    connect(manualModeCheckBox, SIGNAL(clicked()), this, SLOT(slotManualModeCheckBoxClicked()));
+      //qDebug()<< "MainQSOEntryWidget::createUI-END" << QT_ENDL;
 
     QWidget::setTabOrder (qrzLineEdit, dateEdit);
     QWidget::setTabOrder (dateEdit, timeEdit);
@@ -171,6 +179,24 @@ void MainQSOEntryWidget::slotCheckBoxClicked()
     }
 }
 
+void MainQSOEntryWidget::slotManualModeCheckBoxClicked()
+{
+   //qDebug() << Q_FUNC_INFO;
+    if (manualModeCheckBox->isChecked())
+    {
+        slotClearButtonClicked();
+        emit hamlibSetActiveSignal(false);
+        //hamlib->stop();
+        //stop hamlib and wsjt-x communication;
+    }
+    else
+    {
+        //hamlib->initClass();
+        emit hamlibSetActiveSignal(true);
+        //start hamlib and wsjt-x communication;
+    }
+}
+
 /*
 void MainQSOEntryWidget::slotRealtimeButtonClicked()
 {
@@ -201,7 +227,7 @@ void MainQSOEntryWidget::setCleaning (const bool _c)
 
 void MainQSOEntryWidget::slotQRZTextChanged()
 {
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << "###### START ######" << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << "###### START ######" << QT_ENDL;
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
 
     if ((qrzLineEdit->text()).length()<1)
@@ -210,22 +236,22 @@ void MainQSOEntryWidget::slotQRZTextChanged()
         //qDebug() << Q_FUNC_INFO;
         slotClearButtonClicked();
         emit debugLog(Q_FUNC_INFO, "END-1", Debug);
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ <1 - END" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ <1 - END" << QT_ENDL;
     return;
     }
     int cursorP = qrzLineEdit->cursorPosition();
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position: " << QString::number(cursorP) << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position: " << QString::number(cursorP) << QT_ENDL;
     qrzLineEdit->setText((qrzLineEdit->text()).toUpper());
     if (cleaning)
     {
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Cleaning - END" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Cleaning - END" << QT_ENDL;
         emit debugLog(Q_FUNC_INFO, "END-2", Debug);
         return;
     }
 
     if (qrzAutoChanging)
     {
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: qrzAutoChanging - END" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: qrzAutoChanging - END" << QT_ENDL;
         qrzAutoChanging = false;
         emit debugLog(Q_FUNC_INFO, "END-3", Debug);
         return;
@@ -233,33 +259,33 @@ void MainQSOEntryWidget::slotQRZTextChanged()
 
     qrzAutoChanging = true;
 
-   //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.1: " << QString::number(cursorP) << endl;
+   //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.1: " << QString::number(cursorP) << QT_ENDL;
 
     if ( (qrzLineEdit->text()).endsWith(' ') )
     {/*Remove the space and moves the focus to SRX to write the RX exchange*/
         previousQRZ = (qrzLineEdit->text()).simplified();
         qrzLineEdit->setText(previousQRZ);
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Space detected" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Space detected" << QT_ENDL;
     }
 
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Simplifiying & Capitalizing" << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Simplifiying & Capitalizing" << QT_ENDL;
     qrzLineEdit->setText(((qrzLineEdit->text())).simplified());
     qrzLineEdit->setText((qrzLineEdit->text()).remove(" "));
 
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars" << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars" << QT_ENDL;
     //TODO: This validCharactersInCall may be removed?
     InValidCharsInPrevCall = validCharactersInCall(qrzLineEdit->text());
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars 00 " << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars 00 " << QT_ENDL;
     if (!util->isValidCall(qrzLineEdit->text()))
     {
         qrzLineEdit->setPalette(palRed);
         //emit showInfoLabel(tr("Callsign not valid"));
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ not valid - Red" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ not valid - Red" << QT_ENDL;
         emit debugLog(Q_FUNC_INFO, "END-4", Debug);
     }
     else
     {
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ is valid - Black" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ is valid - Black" << QT_ENDL;
         if (getDarkMode())
         {
             qrzLineEdit->setPalette(palWhite);
@@ -273,7 +299,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
         //emit showInfoLabel(tr(""));
     }
     /*
-      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for length" << endl;
+      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for length" << QT_ENDL;
     if (((qrzLineEdit->text()).length() < 1))
     { // If QRZ box is blank, Information labels should be cleared.
         slotClearButtonClicked();
@@ -282,62 +308,57 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     }
     */
 
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for modify or length<1" << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for modify or length<1" << QT_ENDL;
     if (qrzSmallModDontCalculate)
     //if ((modify) || ((qrzLineEdit->text()).length() < 1) || (qrzSmallModDontCalculate))
     {
-        //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: qrzSmallModDontCalculate < 1" << endl;
+        //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: qrzSmallModDontCalculate < 1" << QT_ENDL;
         qrzSmallModDontCalculate=false;
         emit debugLog(Q_FUNC_INFO, "END-6", Debug);
         return;
     }
 
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: running..." << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: running..." << QT_ENDL;
     qrzSmallModDontCalculate = true; // A kind of flag to prevent multiple calls to this method.
     currentQrz = qrzLineEdit->text();
 
     if ((currentQrz).count('\\'))
     { // Replaces \ by / to ease operation.
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Replacing \\ by /" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Replacing \\ by /" << QT_ENDL;
         currentQrz.replace(QChar('\\'), QChar('/'));
         qrzLineEdit->setText(currentQrz);
     }
 
     currentQrz = qrzLineEdit->text();
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.3: " << QString::number(cursorP) << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.3: " << QString::number(cursorP) << QT_ENDL;
     if (cursorP>currentQrz.length())
     {// A Space that has been removed without updating the cursor
-         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursorP > currentQRZ.length" << endl;
+         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursorP > currentQRZ.length" << QT_ENDL;
     }
     else
     {
-        if (cursorP==0)
+        if (((currentQrz.at(cursorP-1)).isSpace()) && (cursorP!=0))
         {
-
-        }
-        else if ((currentQrz.at(cursorP-1)).isSpace())
-        {
-            //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.5: " << QString::number(cursorP) << endl;
+            //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.5: " << QString::number(cursorP) << QT_ENDL;
             previousQRZ = currentQrz.remove(cursorP-1, 1);
-            //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.6: " << QString::number(cursorP) << endl;
+            //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.6: " << QString::number(cursorP) << QT_ENDL;
             cursorP--;
-            //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.7: " << QString::number(cursorP) << endl;
+            //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.7: " << QString::number(cursorP) << QT_ENDL;
             qrzLineEdit->setText(previousQRZ);
         }
     }
-
     currentQrz = qrzLineEdit->text();
-    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: Emitting: " << currentQrz << endl;
+    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: Emitting: " << currentQrz << QT_ENDL;
     emit currentQRZSignal(currentQrz);
 
     qrzSmallModDontCalculate = false; // If the text has not been modified in this method
-    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP) << endl;
+    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP) << QT_ENDL;
     qrzLineEdit->setCursorPosition(cursorP);
     checkIfDupe(Q_FUNC_INFO);
     qrzAutoChanging = false;
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
 
-    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: END" << endl;
+    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: END" << QT_ENDL;
 }
 
 void MainQSOEntryWidget::setCurrentQRZ(const QString &_qrz)
@@ -347,7 +368,7 @@ void MainQSOEntryWidget::setCurrentQRZ(const QString &_qrz)
     emit debugLog(Q_FUNC_INFO, "END", Debug);
 }
 
-void MainQSOEntryWidget::slotBandComboBoxChanged(const QString _b){
+void MainQSOEntryWidget::slotBandComboBoxChanged(const QString &_b){
     //qDebug() << Q_FUNC_INFO << ": " << _b;
 
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
@@ -359,7 +380,7 @@ void MainQSOEntryWidget::slotBandComboBoxChanged(const QString _b){
     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
-void MainQSOEntryWidget::slotModeComboBoxChanged(const QString _m)
+void MainQSOEntryWidget::slotModeComboBoxChanged(const QString &_m)
 {
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
 
@@ -381,7 +402,7 @@ void MainQSOEntryWidget::slotOKButtonClicked()
 
 void MainQSOEntryWidget::slotClearButtonClicked()
 {
-    //qDebug() << "MainQSOEntryWidget::slotClearButtonClicked" << endl;
+    //qDebug() << "MainQSOEntryWidget::slotClearButtonClicked" << QT_ENDL;
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
     clear();
     emit clearForNextQSOSignal();
@@ -394,7 +415,7 @@ void MainQSOEntryWidget::clear()
 {
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
 
-    //qDebug() << Q_FUNC_INFO << endl;
+    //qDebug() << Q_FUNC_INFO << QT_ENDL;
 
     //cleaning = true;
 
@@ -408,7 +429,7 @@ void MainQSOEntryWidget::clear()
 
 void MainQSOEntryWidget::setInitialData()
 {
-      //qDebug()<< "MainQSOEntryWidget::setInitialData" << endl;
+      //qDebug()<< "MainQSOEntryWidget::setInitialData" << QT_ENDL;
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
     //Default band/modes
     modify = false;
@@ -422,7 +443,6 @@ void MainQSOEntryWidget::setInitialData()
     bands << "10M" << "15M" << "20M" << "40M" << "80M" << "160M";
     modes << "SSB" << "CW" << "RTTY";
 
-
     setBands(bands);
     setModes(modes);
 
@@ -438,23 +458,21 @@ void MainQSOEntryWidget::setInitialData()
     timer->start(1000);
 
     emit debugLog(Q_FUNC_INFO, "END", Debug);
-     //qDebug()<< "MainQSOEntryWidget::setInitialData-END" << endl;
-
+     //qDebug()<< "MainQSOEntryWidget::setInitialData-END" << QT_ENDL;
 }
 
 bool MainQSOEntryWidget::updateBandComboBox(const QString &_band)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << _band << endl;
-
+    //qDebug() << Q_FUNC_INFO << ": " << _band << QT_ENDL;
     //QString _currentBand = getBand();
     if (!isBandExisting(_band))
     {// The selected frequency is of a band that is not currently selected
         QString _currentBand = bandComboBox->currentText ();
-        //qDebug() << Q_FUNC_INFO << ":  New band found: " << _band << endl;
+        //qDebug() << Q_FUNC_INFO << ":  New band found: " << _band << QT_ENDL;
         if (dataProxy->getIdFromBandName(_band) > 1)
         {// Not affected if 0 (light) is the frequency
          // In this case the user should select the band in the setup
-            //qDebug() << Q_FUNC_INFO << ":  Band is valid: " << _band << endl;
+            //qDebug() << Q_FUNC_INFO << ":  Band is valid: " << _band << QT_ENDL;
             QStringList qsTemp;
             qsTemp.clear();
             qsTemp << bands;
@@ -462,10 +480,10 @@ bool MainQSOEntryWidget::updateBandComboBox(const QString &_band)
             qsTemp.removeDuplicates();
             bands.clear();
             bands = dataProxy->sortBandNamesBottonUp(qsTemp);
-            //qDebug() << Q_FUNC_INFO << ": Before setBands" << endl;
+            //qDebug() << Q_FUNC_INFO << ": Before setBands" << QT_ENDL;
             setBands(bands);
             bandComboBox->setCurrentIndex(bandComboBox->findText(_currentBand, Qt::MatchCaseSensitive));
-            //qDebug() << Q_FUNC_INFO << ": Band has been added : " << _band << endl;
+            //qDebug() << Q_FUNC_INFO << ": Band has been added : " << _band << QT_ENDL;
         }
         else
         {
@@ -473,25 +491,18 @@ bool MainQSOEntryWidget::updateBandComboBox(const QString &_band)
             return false;
         }
     }
-
-
-    //qDebug() << Q_FUNC_INFO << ": Band already existing, no need to add"  << endl;
+    //qDebug() << Q_FUNC_INFO << ": Band already existing, no need to add"  << QT_ENDL;
     return true;
-
-
-
-
 }
 
 void MainQSOEntryWidget::setBands(const QStringList _bands)
 {
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
-    //qDebug()<< "MainQSOEntryWidget::setBands" << endl;
-    foreach(QString i, _bands)
-    {
-        //qDebug()<< "MainQSOEntryWidget::setBands - received: " << i << endl;
-    }
-
+    //qDebug()<< "MainQSOEntryWidget::setBands" << QT_ENDL;
+    //foreach(QString i, _bands)
+    //{
+        //qDebug()<< "MainQSOEntryWidget::setBands - received: " << i << QT_ENDL;
+    //}
     bands.clear();
     bands = _bands;
     bands.removeDuplicates();
@@ -501,7 +512,7 @@ void MainQSOEntryWidget::setBands(const QStringList _bands)
     emit validBands(_bands);
     //selectDefaultBand(true);
     emit debugLog(Q_FUNC_INFO, "END", Debug);
-    //qDebug()<< "MainQSOEntryWidget::setBands-END" << endl;
+    //qDebug()<< "MainQSOEntryWidget::setBands-END" << QT_ENDL;
 }
 
 void MainQSOEntryWidget::setModes(const QStringList _modes)
@@ -526,7 +537,6 @@ QStringList MainQSOEntryWidget::getModes()
 bool MainQSOEntryWidget::setFreq(const double _f, bool isRX)
 {
     //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f);
-
     if (isRX)
     {
         if (util->isSameFreq (freqRX, _f))
@@ -548,16 +558,15 @@ bool MainQSOEntryWidget::setFreq(const double _f, bool isRX)
         {
             return true;
         }
-        //qDebug() << Q_FUNC_INFO << ": Freq is not in the current band" << endl;
+        //qDebug() << Q_FUNC_INFO << ": Freq is not in the current band" << QT_ENDL;
         QString _newBand = dataProxy->getBandNameFromFreq(_f);
-        //qDebug() << Q_FUNC_INFO << ": before setting band: " << _newBand  << endl;
+        //qDebug() << Q_FUNC_INFO << ": before setting band: " << _newBand  << QT_ENDL;
         if (isRX)
         {
-            //qDebug() << Q_FUNC_INFO << ": RX Freq no more actions "  << endl;
+            //qDebug() << Q_FUNC_INFO << ": RX Freq no more actions "  << QT_ENDL;
             return true;
         }
         return setBand(_newBand);
-
     }
     return false;
 }
@@ -579,29 +588,29 @@ bool MainQSOEntryWidget::newBandNeededForFreq(const double _f)
 
 bool MainQSOEntryWidget::setBand(const QString &_band)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << _band << endl;
+    //qDebug() << Q_FUNC_INFO << ": " << _band << QT_ENDL;
 
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
     if (bandComboBox->findText(_band, Qt::MatchCaseSensitive) < 0)
     {
-        //qDebug() << "MainQSOEntryWidget::setBand-1: Band not found " << _band << endl;
+        //qDebug() << "MainQSOEntryWidget::setBand-1: Band not found " << _band << QT_ENDL;
         if (!updateBandComboBox(_band))
         {
             emit debugLog(Q_FUNC_INFO, "END-1", Debug);
             return false;
         }
     }
-    //qDebug() << "MainQSOEntryWidget::setBand-1: Band found " << _band << endl;
+    //qDebug() << "MainQSOEntryWidget::setBand-1: Band found " << _band << QT_ENDL;
     bandComboBox->setCurrentIndex(bandComboBox->findText(_band, Qt::MatchCaseSensitive));
     emit debugLog(Q_FUNC_INFO, "END-2", Debug);
-    //qDebug() << Q_FUNC_INFO << " - END"  << endl;
+    //qDebug() << Q_FUNC_INFO << " - END"  << QT_ENDL;
     return true;
 }
 
 bool MainQSOEntryWidget::setMode(const QString &_mode)
 {
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
-    //qDebug() << "MainQSOEntryWidget::setMode: " << _mode << endl;
+    //qDebug() << "MainQSOEntryWidget::setMode: " << _mode << QT_ENDL;
     if (modeComboBox->findText(_mode, Qt::MatchCaseSensitive) < 0)
     {
         emit debugLog(Q_FUNC_INFO, "END-1", Debug);
@@ -618,7 +627,7 @@ bool MainQSOEntryWidget::setMode(const QString &_mode)
 bool MainQSOEntryWidget::setQRZ(const QString &_qrz)
 {
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
-    //qDebug() << "MainQSOEntryWidget::setQRZ: " << _qrz << endl;
+    //qDebug() << "MainQSOEntryWidget::setQRZ: " << _qrz << QT_ENDL;
     //TODO: Add validations to prevent that non valid qrz are sent from the outside of this function or at least manage this appropriately.
     qrzLineEdit->setText(_qrz.toUpper());
     emit debugLog(Q_FUNC_INFO, "END", Debug);
@@ -632,13 +641,12 @@ bool MainQSOEntryWidget::setDateTime(const QDateTime _date)
     {
         dateEdit->setDate(_date.date());
         timeEdit->setTime(_date.time());
-
         emit debugLog(Q_FUNC_INFO, "END", Debug);
         return true;
     }
     else
     {
-        //qDebug() << "MainQSOEntryWidget::setDate - NO VALID DATE" << endl;
+        //qDebug() << "MainQSOEntryWidget::setDate - NO VALID DATE" << QT_ENDL;
         emit debugLog(Q_FUNC_INFO, "END", Debug);
         return false;
     }
@@ -673,7 +681,7 @@ QString MainQSOEntryWidget::getBand(const int _b)
     if (_b<0)
     {
         emit debugLog(Q_FUNC_INFO, "END", Debug);
-        //qDebug() << "MainQSOEntryWidget::getBand(1): " << bandComboBox->currentText()<< endl;
+        //qDebug() << "MainQSOEntryWidget::getBand(1): " << bandComboBox->currentText()<< QT_ENDL;
         return bandComboBox->currentText();
     }
     else
@@ -681,13 +689,13 @@ QString MainQSOEntryWidget::getBand(const int _b)
         if (bandComboBox->count()>=_b)
         {
             emit debugLog(Q_FUNC_INFO, "END-1", Debug);
-            //qDebug() << "MainQSOEntryWidget::getBand(2): " << bandComboBox->currentText()<< endl;
+            //qDebug() << "MainQSOEntryWidget::getBand(2): " << bandComboBox->currentText()<< QT_ENDL;
             return bandComboBox->itemText(_b);
         }
         else
         {
             emit debugLog(Q_FUNC_INFO, "END-2", Debug);
-            //qDebug() << "MainQSOEntryWidget::getBand(3): " << bandComboBox->currentText()<< endl;
+            //qDebug() << "MainQSOEntryWidget::getBand(3): " << bandComboBox->currentText()<< QT_ENDL;
             return bandComboBox->currentText();
         }
     }
@@ -732,7 +740,6 @@ QDateTime MainQSOEntryWidget::getDateTime()
     dateTime.setDate(dateEdit->date());
     dateTime.setTime(timeEdit->time());
     return dateTime;
-
 }
 
 QTime MainQSOEntryWidget::getTime()
@@ -749,7 +756,8 @@ void MainQSOEntryWidget::toggleRealTime()
     {
         setRealTime (false);
     }
-    else {
+    else
+    {
         setRealTime (true);
     }
 }
@@ -758,7 +766,6 @@ bool MainQSOEntryWidget::getRealTime()
 {
     //return realtimeButton->isChecked ();
     return realtimeCheckBox->isChecked ();
-
 }
 
 void MainQSOEntryWidget::setRealTime(const bool _realTime)
@@ -795,7 +802,6 @@ void MainQSOEntryWidget::setModify(const bool _modify)
 {
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
     modify = _modify;
-
     if (modify)
     {
         OKButton->setText(tr("&Modify"));
@@ -815,13 +821,13 @@ bool MainQSOEntryWidget::getModifying()
 
 void MainQSOEntryWidget::slotUpdateTime()
 {
-    //qDebug()<< "MainQSOEntryWidget::slotUpdateTime" << endl;
+    //qDebug()<< "MainQSOEntryWidget::slotUpdateTime" << QT_ENDL;
     //emit debugLog(Q_FUNC_INFO, "Start", Debug);
 
     //if ( (!modify) && (realtimeButton->isChecked())  )
     if ( (!modify) && (realtimeCheckBox->isChecked())  )
     {
-        //qDebug()<< "MainQSOEntryWidget::slotUpdateTime - Real Time & update" << endl;
+        //qDebug()<< "MainQSOEntryWidget::slotUpdateTime - Real Time & update" << QT_ENDL;
         setDateAndTimeInternally();
     }
 
@@ -844,7 +850,7 @@ void MainQSOEntryWidget::setDateAndTimeInternally()
 
 bool MainQSOEntryWidget::validCharactersInCall(const QString &_qrz)
 {
-    //qDebug()<< "MainQSOEntryWidget::validCharactersInCall: " << _qrz << endl;
+    //qDebug()<< "MainQSOEntryWidget::validCharactersInCall: " << _qrz << QT_ENDL;
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
     for (int i = 0; i<_qrz.size()-1;i++)
     {
@@ -853,7 +859,6 @@ bool MainQSOEntryWidget::validCharactersInCall(const QString &_qrz)
             emit debugLog(Q_FUNC_INFO, "END-1", Debug);
             return false;
         }
-
     }
     emit debugLog(Q_FUNC_INFO, "END", Debug);
     return true;
@@ -872,23 +877,22 @@ bool MainQSOEntryWidget::isModeExisting(const QString &_m)
         emit debugLog(Q_FUNC_INFO, "END-2", Debug);
         return false;
     }
-
 }
 
 bool MainQSOEntryWidget::isBandExisting(const QString &_b)
 {
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
-    //qDebug() << Q_FUNC_INFO << ": " << _b << endl;
+    //qDebug() << Q_FUNC_INFO << ": " << _b << QT_ENDL;
     if (bandComboBox->findText(_b, Qt::MatchCaseSensitive) >= 0)
     {
         emit debugLog(Q_FUNC_INFO, "END-1", Debug);
-        //qDebug() << Q_FUNC_INFO << " - END true" << endl;
+        //qDebug() << Q_FUNC_INFO << " - END true" << QT_ENDL;
         return true;
     }
     else
     {
         emit debugLog(Q_FUNC_INFO, "END-2", Debug);
-        //qDebug() << Q_FUNC_INFO << " - END false" << endl;
+        //qDebug() << Q_FUNC_INFO << " - END false" << QT_ENDL;
         return false;
     }
 }
@@ -902,36 +906,33 @@ void MainQSOEntryWidget::setUpAndRunning(const bool _u)
 
 void MainQSOEntryWidget::selectDefaultBand(const bool _init)
 {
-      //qDebug() << "MainQSOEntryWidget::selectDefaultBand" << endl;
+      //qDebug() << "MainQSOEntryWidget::selectDefaultBand" << QT_ENDL;
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
     if ((upAndRunning) || (!_init))
     {
         emit debugLog(Q_FUNC_INFO, "END-1", Debug);
-          //qDebug() << "MainQSOEntryWidgetselectDefaultBand-END-1" << endl;
+          //qDebug() << "MainQSOEntryWidgetselectDefaultBand-END-1" << QT_ENDL;
         return;
     }
     QString aux;
     aux = QString();
     int defaultBand = dataProxy->getMostUsedBand(-1); //TODO: The log could be defined here
-      //qDebug() << "MainQSOEntryWidget::selectDefaultBand: " << QString::number(defaultBand) << dataProxy->getNameFromBandId (defaultBand)<< endl;
+      //qDebug() << "MainQSOEntryWidget::selectDefaultBand: " << QString::number(defaultBand) << dataProxy->getNameFromBandId (defaultBand)<< QT_ENDL;
     if (defaultBand<1)
     {
-
         defaultBand = dataProxy->getIdFromBandName(getBand(0));
-
     }
 
     aux = dataProxy->getNameFromBandId(defaultBand);
-    //qDebug() << Q_FUNC_INFO << ": before setting band: " << aux << endl;
+    //qDebug() << Q_FUNC_INFO << ": before setting band: " << aux << QT_ENDL;
     setBand(aux);
     emit debugLog(Q_FUNC_INFO, "END", Debug);
-
-      //qDebug() << "MainQSOEntryWidgetselectDefaultBand_END" << endl;
+      //qDebug() << "MainQSOEntryWidgetselectDefaultBand_END" << QT_ENDL;
 }
 
 void MainQSOEntryWidget::selectDefaultMode(const bool _init)
 {
-      //qDebug() << "MainQSOEntryWidgetselectDefaultMode" << endl;
+      //qDebug() << "MainQSOEntryWidgetselectDefaultMode" << QT_ENDL;
     emit debugLog(Q_FUNC_INFO, "Start", Debug);
     if ((upAndRunning) || (!_init))
     {
@@ -939,7 +940,7 @@ void MainQSOEntryWidget::selectDefaultMode(const bool _init)
         return;
     }
     int defaultMode = dataProxy->getMostUsedMode(-1); //TODO: The log could be defined here
-      //qDebug() << "MainQSOEntryWidgetselectDefaultMode: " << QString::number(defaultMode) << endl;
+      //qDebug() << "MainQSOEntryWidgetselectDefaultMode: " << QString::number(defaultMode) << QT_ENDL;
 
     if (defaultMode < 1)
     {
@@ -948,9 +949,9 @@ void MainQSOEntryWidget::selectDefaultMode(const bool _init)
     setMode(dataProxy->getNameFromSubModeId(defaultMode));
     //modeComboBox->setCurrentIndex(modeComboBox->findText(dataProxy->getNameFromSubModeId(defaultMode)));
 
-     //qDebug() << "MainQSOEntryWidgetselectDefaultMode3: " << QString::number(defaultMode) << endl;
+     //qDebug() << "MainQSOEntryWidgetselectDefaultMode3: " << QString::number(defaultMode) << QT_ENDL;
     emit debugLog(Q_FUNC_INFO, "END", Debug);
-     //qDebug() << "MainQSOEntryWidgetselectDefaultMode-END" << endl;
+     //qDebug() << "MainQSOEntryWidgetselectDefaultMode-END" << QT_ENDL;
 }
 
 void MainQSOEntryWidget::setDuplicatedQSOSlot (const int _secs)
@@ -963,7 +964,10 @@ void MainQSOEntryWidget::setDuplicatedQSOSlot (const int _secs)
 
 void MainQSOEntryWidget::checkIfDupe(const QString &_func)
 {
-   //qDebug() << Q_FUNC_INFO << "(" << _func << ")" << endl;
+#ifdef QT_DEBUG
+   //qDebug() << Q_FUNC_INFO << "(" << _func << ")" << QT_ENDL;
+#else
+#endif
 
     QDateTime _dateTime;
     _dateTime.setDate(dateEdit->date());
@@ -971,14 +975,13 @@ void MainQSOEntryWidget::checkIfDupe(const QString &_func)
 
     if ((dataProxy->isThisQSODuplicated(Q_FUNC_INFO, qrzLineEdit->text(), _dateTime, dataProxy->getIdFromBandName(bandComboBox->currentText()), dataProxy->getIdFromModeName(modeComboBox->currentText()), duplicatedQSOSlotInSecs).length()<2) || modify)
     {
-        //qDebug() << Q_FUNC_INFO << " - NOT DUPE " << endl;
-        //qDebug() << Q_FUNC_INFO << " - Modify: " << util->boolToQString(modify) << endl;
-
+        //qDebug() << Q_FUNC_INFO << " - NOT DUPE " << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " - Modify: " << util->boolToQString(modify) << QT_ENDL;
         qrzgroupBox->setTitle(tr("Callsign"));
     }
     else
     {
-        //qDebug() << Q_FUNC_INFO << " - NOT DUPE " << endl;
+        //qDebug() << Q_FUNC_INFO << " - NOT DUPE " << QT_ENDL;
         qrzgroupBox->setTitle(tr("DUPE", "Translator: DUPE is a common world for hams. Do not translate of not sure"));
     }
 }
@@ -1016,14 +1019,7 @@ void MainQSOEntryWidget::slotDelayInputTimedOut()
 
 bool MainQSOEntryWidget::getDarkMode()
 {
-    if (OKButton->palette().color (QPalette::Base) == "#646464")
-    {
-        return true;
-    }
-    else
-    {
-        return false;
-    }
+    return (OKButton->palette().color (QPalette::Base) == "#646464");
 }
 
 /*
@@ -1066,7 +1062,6 @@ bool MainQSOEntryWidget::eventFilter(QObject *object, QEvent *event)
             return true;
         }
     }
-
     return QWidget::event(event);
 }
 
