@@ -86,7 +86,7 @@
 //#include "worldmapwidget.h"
 #include "widgets/showkloglogwidget.h"
 #include "qso.h"
-
+#include "klogdefinitions.h"
 
 class QTimer;
 class QDateTime;
@@ -149,12 +149,12 @@ public:
     void init();
 
 private slots:
-    //void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
+    //void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery);
     //void slotTest();        // Slot for testing purposes only
     void slotOpenWiki();
     void slotAWAImport();
     void slotClearNoMorErrorShown();
-    void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString queryFailed);
+    void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, QString nativeError, QString queryFailed);
     void slotQRZReturnPressed();
     //void slotQRZSpacePressed();
     void slotQRZTextChanged(QString _qrz);
@@ -200,10 +200,11 @@ private slots:
     void slotQSOsExportToADIF(QList<int> _id);
     void slotQRZcomUpload(QList<int> _id);
     void slotQRZCOMLogUpload();
+    void slotElogQRZCOMDisable(const bool _b);
 
     void slotShowAwards();
     void slotUpdateStatusBar(const QString &statusm);
-    void setMainWindowTitle(const QString _s);
+    void setMainWindowTitle();
     void slotSetup(const int _page=0);
 
     void slotADIFExport();
@@ -248,12 +249,13 @@ private slots:
     void slotDebugAction();
 
     // MainQSOEntryWidget
-    void slotShowInfoLabel(const QString _m);
+    void slotShowInfoLabel(const QString &_m);
     void slotAwardsWidgetSetLog();
     void slotAwardsWidgetSetYear();
+    void slotActiveHamlib(bool _enable);
 
     // MyDataTab
-    void slotMyLocatorTextChanged(const QString _loc);
+    void slotMyLocatorTextChanged(const QString &_loc);
 
     // logpanel
     //void slotRighButtonFromLog( const QPoint& pos);
@@ -291,7 +293,7 @@ private slots:
     void slotElogQRZCOMLogUploaded (QNetworkReply::NetworkError _error, QList<int> _qsos);
     // QRZCOM
     //SATELLITE
-    //void slotSatBandTXComboBoxChanged(const QString _q);
+    //void slotSatBandTXComboBoxChanged(const QString &_q);
     void slotDefineNewBands (const QStringList _bands);
 
     //HAMLIB
@@ -482,7 +484,7 @@ private:
 
 
     // <UI>
-    QGroupBox *gridGroupBox, *qrzgroupBox;//, *searchgroupBox;
+    //QGroupBox *gridGroupBox;//, *qrzgroupBox;//, *searchgroupBox;
     QFrame *dxUpLeftInputFrame;//, *dxUpRightOutputFrame;
 
     //QComboBox *bandComboBox, *modeComboBox;
@@ -609,28 +611,12 @@ private:
 
     //QComboBox *iotaContinentComboBox, *entityPrimDivComboBox, *entitySecDivComboBox, *entityNameComboBox, *propModeComboBox;
 
-    QLineEdit *operatorLineEdit, *stationCallSignLineEdit;//, *commentLineEdit, *iotaNumberLineEdit;
-    QTextEdit *notesTextEdit;
-    QDoubleSpinBox *rxPowerSpinBox;//  *txFreqSpinBox, *rxFreqSpinBox, *myPowerSpinBox,
+    //QLineEdit *operatorLineEdit, *stationCallSignLineEdit;//, *commentLineEdit, *iotaNumberLineEdit;
+    //QTextEdit *notesTextEdit;
+    //QDoubleSpinBox *rxPowerSpinBox;//  *txFreqSpinBox, *rxFreqSpinBox, *myPowerSpinBox,
 
     QString lotwTQSLpath;
 
-    //eQSL
-    //QComboBox *eqslSentComboBox, *eqslRecComboBox, *lotwSentComboBox, *lotwRecComboBox, *clublogComboBox;
-    //QDateEdit *eqslSentQDateEdit, *eqslRecQDateEdit, *lotwSentQDateEdit, *lotwRecQDateEdit, *clublogQDateEdit;
-
-    //QComboBox *qslSentComboBox, *qslRecComboBox, *qslSentViaComboBox, *qslRecViaComboBox;
-    //QDateEdit *qslSentQDateEdit, *qslRecQDateEdit;
-    //QTextEdit *qslmsgTextEdit;
-    //QLineEdit *qslViaLineEdit;
-
-
-    //QLineEdit *searchBoxLineEdit;
-    //QPushButton *searchBoxClearButton, *searchBoxExportButton, *searchBoxSelectAllButton, *searchBoxReSearchButton;
-    //QCheckBox *searchAllQCheckbox;
-    //QPushButton *recalculateAwardsButton;
-    //bool searchSelectAllClicked, stationCallSignShownInSearch;
-
     bool checkNewVersions, reportInfo; // Selected in the Setup->Misc to check if new versions and report info back to KLog's servers
     bool logEvents;                     // Should KLog log the events for debugging
     bool debugFileOpen;                 //Is the debugFile open?
@@ -684,12 +670,6 @@ private:
     bool itIsANewversion;
     int dupeSlotInSeconds;
 
-
-
-
-    //QString currentQrz;
-    //QString previousQrz;
-
     QString stx;
     QString srx;
     QPalette palRed, palBlack; // To paint Text in red or black(normal)
@@ -701,8 +681,8 @@ private:
     bool configured, modify;
     bool needToEnd; // Just to control if the software needs to end.
     //bool qrzAutoChanging; //To stop executing the slotQRZTextChanged just because KLog uppercase a letter
-    QString mainQRZ, stationQRZ, operatorQRZ, dxLocator;
-    QString lastOperatorQRZ, lastStationQRZ, lastMyLocator;
+    QString mainQRZ, stationCallsign, operatorQRZ, dxLocator;
+
     double myPower, lastPower;
 
     int my_CQz, my_ITUz, defaultMode, defaultBand, currentMode, currentModeShown, currentBand, currentBandShown;
@@ -735,6 +715,7 @@ private:
     //</CLUBLOG>
     // QRZ.com
     bool qrzcomActive;
+    bool qrzcomSubscriber;
     eLogQrzLog *elogQRZcom;
     QString qrzcomUser, qrzcomPass;
     // QRz.com - END
@@ -764,16 +745,14 @@ private:
     //QString bandOld, modeOld;
     //LOGVIEW
 
-
-
 signals:
-    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+    void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
 
 
 protected:
     void keyPressEvent(QKeyEvent *event) override;
     void closeEvent(QCloseEvent *event) override;
-    void showEvent(QShowEvent *event);
+    void showEvent(QShowEvent *event) override;
 
 };
 
