@@ -73,6 +73,8 @@ void QSO::clear()
     my_sota_ref = QString();
     my_rig = QString();
     my_antenna = QString();
+    my_vucc_grids= QString();
+    vucc_grids= QString();
     qth = QString();
     name = QString();
     freq_tx = -1.0;
@@ -161,15 +163,15 @@ int QSO::getLogId()
 
 bool QSO::isValid()
 {
-   //qDebug() << "QSO::isValid: " << callsign << endl;
+   //qDebug() << "QSO::isValid: " << callsign << QT_ENDL;
     if ( (callsign.length()>0))
     {
-       //qDebug() << "QSO::isValid: TRUE" << endl;
+       //qDebug() << "QSO::isValid: TRUE" << QT_ENDL;
         return true;
     }
     else
     {
-       //qDebug() << "QSO::isValid: FALSE" << endl;
+       //qDebug() << "QSO::isValid: FALSE" << QT_ENDL;
         return false;
     }
 
@@ -177,15 +179,16 @@ bool QSO::isValid()
 
 bool QSO::setCall(const QString &_c)
 {
-   //qDebug() << "QSO::setCall: " << _c << endl;
+    //qDebug() << "QSO::setCall: " << _c << QT_ENDL;
     if (util->isValidCall(_c))
     {
-       //qDebug() << "QSO::setCall: Valid Call"  << endl;
+        //qDebug() << "QSO::setCall: Valid Call"  << QT_ENDL;
         callsign = _c;
         return true;
     }
-    else {
-       //qDebug() << "QSO::setCall: NOT valid Call"  << endl;
+    else
+    {
+        //qDebug() << "QSO::setCall: NOT valid Call"  << QT_ENDL;
         return false;
     }
 }
@@ -197,7 +200,7 @@ QString QSO::getCall()
 
 bool QSO::setBand(const QString &_c)
 {
-   //qDebug() << "QSO::setBand: "<< _c << endl;
+   //qDebug() << "QSO::setBand: "<< _c << QT_ENDL;
     if (_c.length()>0)
     {
         band = _c;
@@ -217,7 +220,7 @@ QString QSO::getBand()
 
 bool QSO::setBandRX(const QString &_c)
 {
-   //qDebug() << "QSO::setBandRX: "<< _c << endl;
+   //qDebug() << "QSO::setBandRX: "<< _c << QT_ENDL;
     if (_c.length()>0)
     {
         band = _c;
@@ -257,16 +260,16 @@ QString QSO::getMode()
 
 bool QSO::setDate(const QDate &_c)
 {
-   //qDebug() << "QSO::setDate: " << util->getDateSQLiteStringFromDate(_c) << endl;
+   //qDebug() << "QSO::setDate: " << util->getDateSQLiteStringFromDate(_c) << QT_ENDL;
     if (_c.isValid())
     {
-       //qDebug() << "QSO::setDate: VALID" << endl;
+       //qDebug() << "QSO::setDate: VALID" << QT_ENDL;
         qso_dateTime.setDate(_c);
         return true;
     }
     else
     {
-       //qDebug() << "QSO::setDate: NOT VALID" << endl;
+       //qDebug() << "QSO::setDate: NOT VALID" << QT_ENDL;
         qso_dateTime.setDate(QDate());
         return false;
     }
@@ -279,16 +282,16 @@ QDate QSO::getDate()
 
 bool QSO::setTimeOn(const QTime &_c)
 {
-   //qDebug() << "QSO::setQSLTime: " << _c.toString("mmhhss") << endl;
+   //qDebug() << "QSO::setQSLTime: " << _c.toString("mmhhss") << QT_ENDL;
     if (_c.isValid())
     {
-       //qDebug() << "QSO::setQSLTime: VALID" << endl;
+       //qDebug() << "QSO::setQSLTime: VALID" << QT_ENDL;
         qso_dateTime.setTime(_c);
         return true;
     }
     else
     {
-       //qDebug() << "QSO::setQSLTime: NOT VALID" << endl;
+       //qDebug() << "QSO::setQSLTime: NOT VALID" << QT_ENDL;
         qso_dateTime.setTime(QTime());
         return false;
     }
@@ -520,24 +523,29 @@ bool QSO::setLoTWQSL_SENT(const QString &_c)
         lotw_qsl_sent = _c;
         return true;
     }
-    else {
+    else
+    {
         return false;
     }
 }
 
-QString QSO::getLoTWQSL_SENT() {
+QString QSO::getLoTWQSL_SENT()
+{
     return lotw_qsl_sent;
 }
 
 bool QSO::setLoTWQSLSDate(const QDate &_c)
 {
+    //qDebug() << Q_FUNC_INFO;
     if (_c.isValid())
     {
+        //qDebug() << Q_FUNC_INFO << " - valid";
         QSLLoTWSDate = _c;
         return true;
     }
     else
     {
+        //qDebug() << Q_FUNC_INFO << " - NOT valid";
         QSLLoTWSDate = QDate();
         return false;
     }
@@ -550,16 +558,16 @@ QDate QSO::getLoTWQSLSDate()
 
 bool QSO::setLoTWQSL_RCVD(const QString &_c)
 {
-    //qDebug() << "QSO::setLoTWQSL_RCVD: " << _c  << endl;
+    //qDebug() << "QSO::setLoTWQSL_RCVD: " << _c  << QT_ENDL;
     if (util->isValidQSL_Rcvd(_c))
     {
-        //qDebug() << "QSO::setLoTWQSL_RCVD: VALID " << endl;
+        //qDebug() << "QSO::setLoTWQSL_RCVD: VALID " << QT_ENDL;
         lotw_qsl_rcvd = _c;
         return true;
     }
     else
     {
-        //qDebug() << "QSO::setLoTWQSL_RCVD: NOT valid " << endl;
+        //qDebug() << "QSO::setLoTWQSL_RCVD: NOT valid " << QT_ENDL;
         return false;
     }
 }
@@ -571,16 +579,16 @@ QString QSO::getLoTWQSL_RCVD()
 
 bool QSO::setLoTWQSLRDate(const QDate &_c)
 {
-    //qDebug() << "QSO::setLoTWQSLRDate: " << _c.toString("yyyy-MM-dd") << endl;
+    //qDebug() << "QSO::setLoTWQSLRDate: " << _c.toString("yyyy-MM-dd") << QT_ENDL;
     if (_c.isValid())
     {
-        //qDebug() << "QSO::setLoTWQSLRDate: TRUE" << endl;
+        //qDebug() << "QSO::setLoTWQSLRDate: TRUE" << QT_ENDL;
         QSLLoTWRDate = _c;
         return true;
     }
     else
     {
-        //qDebug() << "QSO::setLoTWQSLRDate: FALSE" << endl;
+        //qDebug() << "QSO::setLoTWQSLRDate: FALSE" << QT_ENDL;
         QSLLoTWRDate = QDate();
         return false;
     }
@@ -646,7 +654,7 @@ QString QSO::getQSL_RCVD()
     return qsl_rcvd;
 }
 
-bool QSO::setQSLSenVia(const QString _qs)
+bool QSO::setQSLSenVia(const QString &_qs)
 {
     if (!_qs.isEmpty ())
     {
@@ -664,7 +672,7 @@ QString QSO::getSentVia()
     return qslSenVia;
 }
 
-bool QSO::setQSLRecVia(const QString _qs)
+bool QSO::setQSLRecVia(const QString &_qs)
 {
     if (!_qs.isEmpty ())
     {
@@ -682,7 +690,7 @@ QString QSO::getRecVia()
     return qslRecVia;
 }
 
-bool QSO::setQSLVia(const QString _qs)
+bool QSO::setQSLVia(const QString &_qs)
 {
     if (!_qs.isEmpty ())
     {
@@ -719,7 +727,7 @@ QDate QSO::getQSLRDate()
     return QSLRDate;
 }
 
-bool QSO::setQSLMsg(const QString _qs)
+bool QSO::setQSLMsg(const QString &_qs)
 {
     if (!_qs.isEmpty ())
     {
@@ -958,6 +966,42 @@ bool QSO::setMyRig(const QString &_c)
     return false;
 }
 
+bool QSO::setVUCCGrids(const QString &_c)
+{
+    if (util->isValidVUCCGrids (_c))
+    {
+        vucc_grids = _c;
+        return true;
+    }
+    else
+    {
+        return false;
+    }
+}
+
+QString QSO::getVUCCGrids()
+{
+    return vucc_grids;
+}
+
+bool QSO::setMyVUCCGrids(const QString &_c)
+{
+    if (util->isValidVUCCGrids (_c))
+    {
+        my_vucc_grids = _c;
+        return true;
+    }
+    else
+    {
+        return false;
+    }
+}
+
+QString QSO::getMyVUCCGrids()
+{
+    return my_vucc_grids;
+}
+
 QString QSO::getMyRig()
 {
     return my_rig;
@@ -1161,16 +1205,16 @@ bool QSO::getKeepSatTab()
 // SET DATA
 bool QSO::setData(const QString &_adifPair)
 {
-    //qDebug() << "QSO::setData: " << _adifPair << endl;
+    //qDebug() << "QSO::setData: " << _adifPair << QT_ENDL;
     QStringList d;
     d.clear();
     d << util->getValidADIFFieldAndData(_adifPair);
     if (d.length()!=2)
     {
-        //qDebug() << "QSO::setData: NOT VALID ADIF: " << _adifPair << endl;
+        //qDebug() << "QSO::setData: NOT VALID ADIF: " << _adifPair << QT_ENDL;
         return false;
     }
-   //qDebug() << "QSO::setData: " << d.at(0) << "/" << d.at(1) << endl;
+    //qDebug() << "QSO::setData: " << d.at(0) << "/" << d.at(1) << QT_ENDL;
 
     QString field = d.at(0).toUpper();
     QString data = d.at(1);
@@ -1193,7 +1237,7 @@ bool QSO::setData(const QString &_adifPair)
     }
     else if (field == "QSO_DATE")
     {
-       //qDebug() << "QSO::setData: QSO_DATE: " << data  << endl;
+       //qDebug() << "QSO::setData: QSO_DATE: " << data  << QT_ENDL;
         setDate(util->getDateFromADIFDateString(data));
     }
     else if (field == "FREQ")
@@ -1250,10 +1294,22 @@ bool QSO::setData(const QString &_adifPair)
     }
     else if (field == "APP_LOTW_RXQSL")
     {
-        //qDebug() << "QSO::setData: APP_LOTW_RXQSL: " << data  << endl;
+        //qDebug() << "QSO::setData: APP_LOTW_RXQSL: " << data  << QT_ENDL;
         setLoTWQSL_RCVD("Y");
         setLoTWQSLRDate(util->getDateFromLoTWQSLDateString(data));
     }
+    else if (field == "APP_LOTW_RXQSO")
+    {
+        //qDebug() << "QSO::setData: APP_LOTW_RXQSO: " << data  << QT_ENDL;
+        setLoTWQSL_SENT("Y");
+        setLoTWQSLSDate(util->getDateFromLoTWQSLDateString(data));
+    }
+    else if (field == "APP_LOTW_QSO_TIMESTAMP")
+    {
+        //qDebug() << "QSO::setData: APP_LoTW_QSO_TIMESTAMP: " << data  << QT_ENDL;
+        setLoTWQSL_SENT("Y");
+        setLoTWQSLSDate(util->getDateFromLoTWQSLDateString(data));
+    }
 
     return true;
 }
