@@ -50,7 +50,7 @@ public:
     void setWorkedColor(const QString &_c);
     void setConfirmedColor(const QString &_c);
     void setDefaultColor(const QString &_c);
-    void setDarkMode(const QString _dm);
+    void setDarkMode(const QString &_dm);
 
 
 
