@@ -32,6 +32,8 @@
 #include <QSerialPortInfo>
 #include "hamlibclass.h"
 #include "dataproxy_sqlite.h"
+#include "hamlibserialconfigwidget.h"
+#include "hamlibnetworkconfigwidget.h"
 #include <hamlib/rig.h>
 
 class SetupPageHamLib : public QWidget
@@ -43,11 +45,11 @@ public:
     bool setRigType(const QString &_radio);
     void setPollingInterval(const int _msecs);
     bool setSerialPort(const QString &_port);
-    bool setSerialSpeed(const QString &_speed );
+    bool setSerialSpeed(const int _speed );
     void setActive(const QString &_active);
     //void setRTS(const QString &_state);
     //void setDTR(const QString &_state);
-    void setDataBits(const QString &_st);
+    void setDataBits(const int _st);
     void setFlowControl(const QString &_st);
     void setParity(const QString &_st);
     void setStopBits(const QString &_st);
@@ -56,11 +58,8 @@ public:
     void setRadioNetworkAddress(const QString &_m);
     void setRadioNetworkPort(const int _p);
 
-
-signals:
-
 public slots:
-    void slotScanPorts();
+    //void slotScanPorts();
     void slotRadioComboBoxChanged(QString _r);
     void slotTestHamlib();
 
@@ -68,48 +67,30 @@ private:
     void createUI();
     void setRig();
     void setDefaults();
-    void fillSerialPortsComboBox();
-    //static int addRigToList(const struct rig_caps* caps, void* data);
+    void setTestResult(const bool _ok);
+
     QStringList getAvailableSerialPorts();
 
-    QString getDataBits();
+    int getDataBits();
     QString getFlowControl();
     QString getParity();
-    QString getStopBits();
-    QString getPollInterval();
-    QString getNetworkSettings();
+    int getStopBits();
 
-/*
 
-DataBits { Data5, Data6, Data7, Data8, UnknownDataBits }
-FlowControl { NoFlowControl, HardwareControl, SoftwareControl, UnknownFlowControl }
-Parity { NoParity, EvenParity, OddParity, SpaceParity, MarkParity, UnknownParity }
-StopBits { OneStop, OneAndHalfStop, TwoStop, UnknownStopBits }
+    QTabWidget *tabWidget;
+    HamLibSerialConfigWidget *serialConfigWidget;
+    HamLibNetworkConfigWidget *networkConfigWidget;
+    QComboBox *rigTypeComboBox;
 
-*/
-    QPushButton *scanSerialPortButton, *testHamlibPushButton;
-    QComboBox *rigTypeComboBox, *serialBaudsComboBox, *serialPortComboBox, *dataBitsComboBox,
-                *flowControlComboBox, *parityComboBox, *stopBitsComboBox;
-    //QSpinBox *serialBaudsSpinBox;
+    QPushButton  *testHamlibPushButton;
 
-    QLineEdit *serialPort, *hostAddressLineEdit;
-    QSpinBox *pollIntervalQSpinBox, *portQSpinBox;
+    QSpinBox *pollIntervalQSpinBox;
     int pollMin, pollMax, rigctlport;
 
-
     HamLibClass *hamlib;
 
-    //RIG *my_rig;            // handle to rig (instance)
-    //freq_t freq;
-    //rig_model_t myrig_model;
-
-    QStringList strings, serialPorts;
     QCheckBox *activateHamlibCheckBox, *readOnlyModeCheckBox; //, *RTSCheckBox, *DTRCheckBox;
-    bool networkRadio, ready, hamlibTestOK;
-
-    QGroupBox *serialGroup, *networkGroup;
-
-    //int defaultPortSpeed;
+    bool networkRadio, hamlibTestOK;
 };
 
 #endif // SETUPPAGEHAMLIB_H
