@@ -51,48 +51,20 @@ public:
     void setOperators(const QString &_st);
     void setComment(const QString &_st);
     void setDateString(const QString &_st);
-    //void setTypeN(const int _n);
-
-    //void setType(const QString _st);
-    //void setCMode(const int _n);
-    //void setCOperators(const int _n);
-    //void setCAssisted(const int _n);
-    //void setCPower(const int _n);
-    //void setCBands(const int _n);
-    //void setBands(const int _n);
-    //void setCOverlay(const int _n);
-
-
 
 private slots:
     void slotOKButtonClicked();
     void slotCancelButtonClicked();
-
     void slotStationCallSignTextChanged();
     void slotOperatorsTextChanged();
-    //void slotTypeComboBoxChanged();
-    //void slotCatAssistedComboBoxChanged();
-    //void slotCatOperatorsComboBoxChanged();
-    //void slotCatPowerComboBoxChanged();
-    //void slotCatBandsComboBoxChanged();
-    //void slotBandsComboBoxChanged();
-    //void slotCatModeComboBoxChanged();
-    //void slotCatOverlayComboBoxChanged();
-
 
 signals:
     void newLogData(const QStringList _qs); //
     void cancelled(const bool _c); // Cancel button is clicked
 
 private:
-
-    //bool isThereAnyNotManagedLog();
     void createWidget();
     void gatherAndSend();
-    //QStringList getValidCatOptions(const int _currentCat, const int _higherCat);
-    //int getSelectedTypeContest();
-    //void fillWithType(const int _n);
-    //void updateAllCats();
     void showOK();
     void showNOK();
     void clear();
@@ -105,23 +77,8 @@ private:
 
     QLineEdit *stationCallsignLineEdit;
     QLineEdit *operatorsLineEdit, *commentLineEdit;
-
-    /*
-    QComboBox *typeComboBox;
-    QComboBox *contestCatModeComboBox;
-    QComboBox *contestCatOperatorsComboBox;
-    QComboBox *contestCatAssistedComboBox;
-    QComboBox *contestCatPowerComboBox;
-    QComboBox *contestCatBandsComboBox;
-    QComboBox *contestBandsComboBox;
-    QComboBox *contestCatOverlayComboBox;
-    */
-
-    QString stationCallsign, operators, comment, dateString;//, typeConteststr;
-    //int typeContest, typeContestSelected, contestCatMode, contestCatOperators, contestCatAssisted, contestCatPower, contestCatBands, contestBands, contestCatOverlay;
-
+    QString stationCallsign, operators, comment, dateString;
     bool stationCallsignFilled, operatorsFilled;
-    //int typeOperation; // DX, CQ-WW-SSB, CQ-WW-CW, CQ-WPX-SSB, CQ-WPX-CW
 
     QPushButton *okButton, *cancelButton;
 
@@ -132,8 +89,6 @@ private:
     //QLabel *typeLabel, *validCats,
     QLabel *stationCallsignLabel, *operatorsLabel, *commentLabel, *dateLabel;
 
-    //nameLabel->setBuddy();
-
     bool checking; //, bCass, bCOp, bCMo, bCPo, bCBa, bCOv, bCTy;
 
 };
