@@ -46,8 +46,8 @@ public:
     int getSelectedSat();
     void setSelectedSat(const int _i);
     void createNewSat();
-    void setDefaultStationCallsign (const QString _p);
-    void setDefaultOperators(const QString _p);
+    void setDefaultStationCallsign (const QString &_p);
+    void setDefaultOperators(const QString &_p);
 
 
 private slots:
@@ -64,7 +64,7 @@ private slots:
 signals:
    //void exitSignal(const int status); // 1 = OK, -1 = NOK, 2 = Cancel clicked
     void newSatData(const QStringList _qs); // Station QRZ + Operators to be shown in the main tab
-    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
+    void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
 
 private:
     //void createActions();
