@@ -27,12 +27,12 @@
 #include "setuppages/setuppageuserdata.h"
 
 SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent){
-      //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage" << endl;
+      //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage" << QT_ENDL;
    locator = new Locator();
    util = new Utilities;
    dataProxy = dp;
    world = new World(dataProxy, Q_FUNC_INFO);
-   operatorOK = false;
+   mainCallOK = false;
    operatorsOK = false;
    tabWidget = new QTabWidget;
    QWidget *personalTab = new QWidget;
@@ -41,7 +41,7 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *pare
    tabWidget->addTab(personalTab, tr("&Personal data"));
    tabWidget->addTab(stationTab, tr("Station &data"));
 
-   qrzLineEdit = new QLineEdit;
+   maincallsignLineEdit = new QLineEdit;
    operatorsLineEdit = new QLineEdit;
    nameLineEdit = new QLineEdit;
    cqzLineEdit = new QLineEdit;
@@ -184,18 +184,17 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *pare
     stationTab->setLayout(stationLayout);
 
     //TODO:Defining ALL the tooltips
-    qrzLineEdit->setToolTip(tr("Enter the station callsign that will be used for logging."));
+    maincallsignLineEdit->setToolTip(tr("Enter the station callsign that will be used for logging."));
     operatorsLineEdit->setToolTip(tr("Enter the operators (comma separated if more than one)."));
     myLocatorLineEdit->setToolTip(tr("Enter the locator of your station. Alternatively, KLog can use an approximate locator based on your callsign."));
 
-
     QLabel *qrzLabel = new QLabel(tr("&Callsign"));
     QLabel *operatorsLabel = new QLabel (tr("&Operators"));
     QLabel *cqzLabel = new QLabel(tr("&CQ Zone"));
     QLabel *ituzLabel = new QLabel(tr("&ITU Zone"));
     myLocatorLabel = new QLabel(tr("&Locator"));
 
-    qrzLabel->setBuddy(qrzLineEdit);
+    qrzLabel->setBuddy(maincallsignLineEdit);
     operatorsLabel->setBuddy(operatorsLineEdit);
     cqzLabel->setBuddy(cqzLineEdit);
     ituzLabel->setBuddy(ituzLineEdit);
@@ -206,35 +205,9 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *pare
     cqzLineEdit->setText("00");
     ituzLineEdit->setText("00");
 
-    //QHBoxLayout *operatorLayout = new QHBoxLayout;
-    //operatorLayout->addWidget(qrzLabel);
-    //operatorLayout->addWidget(qrzLineEdit);
-    //operatorLayout->addWidget(operatorsLabel);
-    //operatorLayout->addWidget(operatorsLineEdit);
-
-
-    //QGridLayout *operatorLayout = new QGridLayout();
-    //operatorLayout->addWidget(qrzLabel, 0, 0);
-    //operatorLayout->addWidget(qrzLineEdit, 1, 0);
-    ////operatorLayout->addWidget(nameLabel, 0, 1);
-    ////operatorLayout->addWidget(nameLineEdit, 1, 1);
-/*
-    QGridLayout *zonesBoxLayout = new QGridLayout;
-    zonesBoxLayout->addWidget(myLocatorLabel,0,0);
-    zonesBoxLayout->addWidget(cqzLabel,0,1);
-    zonesBoxLayout->addWidget(ituzLabel,0,2);
-    zonesBoxLayout->addWidget(myLocatorLineEdit,1,0);
-    zonesBoxLayout->addWidget(cqzLineEdit,1,1);
-    zonesBoxLayout->addWidget(ituzLineEdit,1,2);
-
-    QVBoxLayout *userdataLayout = new QVBoxLayout();
-    userdataLayout->addLayout(operatorLayout);
-    userdataLayout->addLayout(zonesBoxLayout);
-
-*/
     QGridLayout *userdataLayout = new QGridLayout;
     userdataLayout->addWidget(qrzLabel, 0, 0);
-    userdataLayout->addWidget(qrzLineEdit, 1, 0);
+    userdataLayout->addWidget(maincallsignLineEdit, 1, 0);
     userdataLayout->addWidget(operatorsLabel, 0, 1);
     userdataLayout->addWidget(operatorsLineEdit, 1, 1, 1, -1);
     userdataLayout->addWidget(myLocatorLabel, 3, 0);
@@ -250,8 +223,8 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *pare
     mainLayout->addWidget(tabWidget);
     //mainLayout->addStretch(1);
 
-    connect(qrzLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotQRZTextChanged() ) );
-    connect(qrzLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
+    connect(maincallsignLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotQRZTextChanged() ) );
+    connect(maincallsignLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
     connect(operatorsLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
     connect(nameLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
     connect(cqzLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
@@ -271,23 +244,23 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *pare
     connect(operatorsLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotOperatorsChanged() ) );
 
     setLayout(mainLayout);
-    qrzLineEdit->setFocus();
+    maincallsignLineEdit->setFocus();
 
-       //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage - END" << endl;
+       //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage - END" << QT_ENDL;
 }
 
 
 SetupPageUserDataPage::~SetupPageUserDataPage()
 {
-       //qDebug() << "SetupPageUserDataPage::~SetupPageUserDataPage" << endl;
+       //qDebug() << "SetupPageUserDataPage::~SetupPageUserDataPage" << QT_ENDL;
 }
 
-QString SetupPageUserDataPage::getStationQrz()
+QString SetupPageUserDataPage::getMainCallsign()
 {
-    operatorOK = world->checkQRZValidFormat(qrzLineEdit->text());
-    if (operatorOK)
+    mainCallOK = world->checkQRZValidFormat(maincallsignLineEdit->text());
+    if (mainCallOK)
     {
-        return qrzLineEdit->text();
+        return maincallsignLineEdit->text();
     }
     else
     {
@@ -304,11 +277,11 @@ void SetupPageUserDataPage::slotEnterKeyPressed()
 
 void SetupPageUserDataPage::slotQRZTextChanged()
 {
-      //qDebug() << "SetupPageUserDataPage::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << endl;
+      //qDebug() << "SetupPageUserDataPage::slotQRZTextChanged: " << maincallsignLineEdit->text() << " / Length: " << QString::number((maincallsignLineEdit->text()).size()) << QT_ENDL;
 
-    int i = qrzLineEdit->cursorPosition();
+    int i = maincallsignLineEdit->cursorPosition();
 
-    QString _a = util->getClearSQLi (qrzLineEdit->text());
+    QString _a = util->getClearSQLi (maincallsignLineEdit->text());
     if (i<1)
     {
         return;
@@ -316,26 +289,26 @@ void SetupPageUserDataPage::slotQRZTextChanged()
 
     if ((_a.at(i-1)).isSpace())
     {
-        qrzLineEdit->setText(_a.remove(i-1, 1));
+        maincallsignLineEdit->setText(_a.remove(i-1, 1));
     }
 
 
-    qrzLineEdit->setText(((qrzLineEdit->text())).simplified());
-    qrzLineEdit->setText((qrzLineEdit->text()).toUpper());
+    maincallsignLineEdit->setText(((maincallsignLineEdit->text())).simplified());
+    maincallsignLineEdit->setText((maincallsignLineEdit->text()).toUpper());
 
-    cqzLineEdit->setText(QString::number(world->getQRZCqz(qrzLineEdit->text())));
-    ituzLineEdit->setText(QString::number(world->getQRZItuz(qrzLineEdit->text())));
-    myLocatorLineEdit->setText(world->getQRZLocator(qrzLineEdit->text()));
+    cqzLineEdit->setText(QString::number(world->getQRZCqz(maincallsignLineEdit->text())));
+    ituzLineEdit->setText(QString::number(world->getQRZItuz(maincallsignLineEdit->text())));
+    myLocatorLineEdit->setText(world->getQRZLocator(maincallsignLineEdit->text()));
 
-    qrzLineEdit->setCursorPosition(i);
+    maincallsignLineEdit->setCursorPosition(i);
+
+    emit mainCallsignSignal(maincallsignLineEdit->text());
 
-    emit stationCallSignal(qrzLineEdit->text());
-    //emit stationCallSignal("TEST");
 
     /*
      if (!locator->isValidLocator(myLocatorLineEdit->text()) )
     {
-        myLocatorLineEdit->setText(world->getQRZLocator(qrzLineEdit->text()));
+        myLocatorLineEdit->setText(world->getQRZLocator(maincallsignLineEdit->text()));
     }
     */
 }
@@ -348,8 +321,8 @@ int SetupPageUserDataPage::getITUz(){
     return (ituzLineEdit->text()).toInt();
 }
 
-bool SetupPageUserDataPage::setStationQrz(const QString &_qrz){
-    qrzLineEdit->setText((_qrz).toUpper());
+bool SetupPageUserDataPage::setMainCallsign(const QString &_qrz){
+    maincallsignLineEdit->setText((_qrz).toUpper());
     return true;
 }
 
@@ -365,7 +338,7 @@ bool SetupPageUserDataPage::setITUz(const int _ituz){
 
 void SetupPageUserDataPage::slotMyLocatorTextChanged()
 {
-       //qDebug() << "SetupPageUserDataPage::slotMyLocatorTextChanged: " << myLocatorLineEdit->text() << endl;
+       //qDebug() << "SetupPageUserDataPage::slotMyLocatorTextChanged: " << myLocatorLineEdit->text() << QT_ENDL;
 
     //int i;
 
@@ -630,7 +603,7 @@ bool SetupPageUserDataPage::setAntenna3 (const QString &_aux)
 
 void SetupPageUserDataPage::slotOperatorsChanged()
 {
-       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged" << endl;
+       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged" << QT_ENDL;
     //QString _operators = operatorsLineEdit->text();
 
 
@@ -648,14 +621,14 @@ void SetupPageUserDataPage::slotOperatorsChanged()
     operatorsLineEdit->setText(util->getClearSQLi (_a).simplified().toUpper());
     _a = operatorsLineEdit->text();
 
-    QStringList operators = _a.split(",", QString::SkipEmptyParts);
+    QStringList operators = _a.split(",", QT_SKIP);
 
-       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-02" << endl;
-       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-02.5 Size: " << QString::number(operators.size()) << endl;
+       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-02" << QT_ENDL;
+       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-02.5 Size: " << QString::number(operators.size()) << QT_ENDL;
 
     for (int ii = 0; ii < operators.size(); ++ii)
     {
-           //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-03 - " << QString::number(ii) << endl;
+           //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-03 - " << QString::number(ii) << QT_ENDL;
 
         operatorsOK = world->checkQRZValidFormat(operators.at(ii));
 
@@ -663,20 +636,20 @@ void SetupPageUserDataPage::slotOperatorsChanged()
 
         if (operatorsOK)
         {
-               //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NO  VALID CALL: " <<  operators.at(ii) << endl;
+               //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NO  VALID CALL: " <<  operators.at(ii) << QT_ENDL;
         }
         else
         {
-               //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID CALL: " <<  operators.at(ii) << endl;
+               //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID CALL: " <<  operators.at(ii) << QT_ENDL;
         }
     }
-    //          cout << fonts.at(i).toLocal8Bit().constData() << endl;
+    //          cout << fonts.at(i).toLocal8Bit().constData() << QT_ENDL;
 
-       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-04" << endl;
+       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-04" << QT_ENDL;
 
     if (operatorsOK)
     {
-           //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID FORMAT" << endl;
+           //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID FORMAT" << QT_ENDL;
         //QColor defaultColor = (operatorsLineEdit->palette()).color(QPalette::WindowText);
 
         operatorsLineEdit->setPalette(*defaultPalette);
@@ -687,20 +660,20 @@ void SetupPageUserDataPage::slotOperatorsChanged()
     else
     {
          operatorsLineEdit->setPalette(*wrongPalette);
-           //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NOT VALID FORMAT" << endl;
+           //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NOT VALID FORMAT" << QT_ENDL;
     }
-       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-05" << endl;
+       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-05" << QT_ENDL;
 
  /*
-    cqzLineEdit->setText(QString::number(world->getQRZCqz(qrzLineEdit->text())));
-    ituzLineEdit->setText(QString::number(world->getQRZItuz(qrzLineEdit->text())));
-    myLocatorLineEdit->setText(world->getQRZLocator(qrzLineEdit->text()));
+    cqzLineEdit->setText(QString::number(world->getQRZCqz(maincallsignLineEdit->text())));
+    ituzLineEdit->setText(QString::number(world->getQRZItuz(maincallsignLineEdit->text())));
+    myLocatorLineEdit->setText(world->getQRZLocator(maincallsignLineEdit->text()));
 
 
   */
     //operatorsLineEdit->setText(_a);
     operatorsLineEdit->setCursorPosition(i);
-       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-END" << endl;
+       //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-END" << QT_ENDL;
 }
 
 QString SetupPageUserDataPage::getOperators()
@@ -741,6 +714,6 @@ bool  SetupPageUserDataPage::checkOperatorsLineQString(const QString &_auxLine)
 }
 void SetupPageUserDataPage::setStationFocus()
 {
-    //qDebug() << "SetupPageUserDataPage::setStationFocus" << endl;
-    qrzLineEdit->setFocus();
+    //qDebug() << "SetupPageUserDataPage::setStationFocus" << QT_ENDL;
+    maincallsignLineEdit->setFocus();
 }
