@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -119,8 +119,8 @@ signals:
     bool downloadCTYFile();
 
     QLabel *topLabel;
-    QRadioButton *memoryRadioButton;
-    QRadioButton *fileRadioButton;
+    QCheckBox *memoryQCheckbox;
+    QCheckBox *fileQCheckbox;
 
 
     bool runInMemory;
