@@ -32,7 +32,7 @@
 UDPServer::UDPServer(QObject *parent) :
     QObject(parent)
 {
-       //qDebug() << "UDPServer::UDPServer"  << endl;
+       //qDebug() << "UDPServer::UDPServer"  << QT_ENDL;
        //address = QString("127.0.0.1");
        port = 2237;
        haveNetworkInterface = false;
@@ -43,11 +43,11 @@ UDPServer::UDPServer(QObject *parent) :
        //if (socketServer->bind(QHostAddress::AnyIPv4, port, QAbstractSocket::ShareAddress))
        if (socketServer->bind(port, QAbstractSocket::ShareAddress))
        {
-            //qDebug() << "UDPServer::UDPServer - Multicast group joined OK"  << endl;
+            //qDebug() << "UDPServer::UDPServer - Multicast group joined OK"  << QT_ENDL;
        }
        else
        {
-            //qDebug() << "UDPServer::UDPServer - Multicast group joined NOK"  << endl;
+            //qDebug() << "UDPServer::UDPServer - Multicast group joined NOK"  << QT_ENDL;
        }
        */
         util = new Utilities;
@@ -59,47 +59,47 @@ UDPServer::UDPServer(QObject *parent) :
 
 void UDPServer::slotReadPendingDatagrams()
 {
-       //qDebug() << "UDPServer::slotReadPendingDatagrams"  << endl;
+       //qDebug() << "UDPServer::slotReadPendingDatagrams"  << QT_ENDL;
     while (socketServer->hasPendingDatagrams()) {
         QByteArray datagram;
         datagram.resize(socketServer->pendingDatagramSize());
         QHostAddress sender;
         quint16 senderPort;
-           //qDebug() << "UDPServer::slotReadPendingDatagrams: length = " << QString::number(socketServer->pendingDatagramSize()) << endl;
+           //qDebug() << "UDPServer::slotReadPendingDatagrams: length = " << QString::number(socketServer->pendingDatagramSize()) << QT_ENDL;
         socketServer->readDatagram(datagram.data(), datagram.size(), &sender, &senderPort);
         parse (datagram);
-        //qDebug() << "UDPServer::slotReadPendingDatagrams: = " << datagram << endl;
+        //qDebug() << "UDPServer::slotReadPendingDatagrams: = " << datagram << QT_ENDL;
     }
 
 }
 
 bool UDPServer::start()
 {
-    //qDebug() << "UDPServer::start " << endl;
+    //qDebug() << "UDPServer::start " << QT_ENDL;
     if ( (port>0) && (port<65535) )
     {
-        //qDebug() << "UDPServer::start: calling startNow " << endl;
+        //qDebug() << "UDPServer::start: calling startNow " << QT_ENDL;
         return startNow(port, groupAddress);
 
     }
     else
     {
-        //qDebug() << "UDPServer::start FALSE" << endl;
+        //qDebug() << "UDPServer::start FALSE" << QT_ENDL;
         return false;
     }
 }
 
 bool UDPServer::startNow(quint16 _port, QHostAddress const& _multicast_group_address)
 {
-    //qDebug() << "UDPServer::startNow "<< endl;
+    //qDebug() << "UDPServer::startNow "<< QT_ENDL;
     //if ((_port != port) || (_multicast_group_address != groupAddress))
     if (1)
     {
-        //qDebug() << "UDPServer::startNow starting..."<< endl;
+        //qDebug() << "UDPServer::startNow starting..."<< QT_ENDL;
         leaveMultiCastGroup();
         if (socketServer->state() == QAbstractSocket::BoundState)
         {
-            //qDebug() << "UDPServer::startNow: closing socket"<< endl;
+            //qDebug() << "UDPServer::startNow: closing socket"<< QT_ENDL;
             socketServer->close();
         }
         groupAddress = _multicast_group_address;
@@ -113,24 +113,22 @@ bool UDPServer::startNow(quint16 _port, QHostAddress const& _multicast_group_add
         }
         else
         {
-            //qDebug() << "UDPServer::startNow port = 0"<< endl;
+            //qDebug() << "UDPServer::startNow port = 0"<< QT_ENDL;
             port = 0;
         }
-
-
     }
     else
     {
-       //qDebug() << "UDPServer::startNow exiting... "<< endl;
+       //qDebug() << "UDPServer::startNow exiting... "<< QT_ENDL;
     }
-    //qDebug() << "UDPServer::startNow exiting... "<< endl;
+    //qDebug() << "UDPServer::startNow exiting... "<< QT_ENDL;
     return  socketServer->isValid();
 
 }
 
 void UDPServer::joinMultiCastGroup()
 {
-    //qDebug() << "UDPServer::joinMultiCastGroup: "<< endl;
+    //qDebug() << "UDPServer::joinMultiCastGroup: "<< QT_ENDL;
     if (!haveNetworkInterface)
     {
         return;
@@ -145,7 +143,7 @@ void UDPServer::joinMultiCastGroup()
             socketServer->bind(QHostAddress::AnyIPv4, port, QAbstractSocket::ShareAddress | QAbstractSocket::ReuseAddressHint);
             if (socketServer->isValid())
             {
-               //qDebug() << "UDPServer::joinMultiCastGroup socket valid"<< endl;
+               //qDebug() << "UDPServer::joinMultiCastGroup socket valid"<< QT_ENDL;
             }
 
         }
@@ -172,12 +170,12 @@ void UDPServer::joinMultiCastGroup()
         }
         socketServer->setMulticastInterface(mcast_interface);
     }
-    //qDebug() << "UDPServer::joinMultiCastGroup - END"<< endl;
+    //qDebug() << "UDPServer::joinMultiCastGroup - END"<< QT_ENDL;
 }
 
 void UDPServer::leaveMultiCastGroup()
 {
-    //qDebug() << "UDPServer::leaveMultiCastGroup"<< endl;
+    //qDebug() << "UDPServer::leaveMultiCastGroup"<< QT_ENDL;
     if (groupAddress.isNull() && socketServer->state() && groupAddress.isMulticast())
     {
         QList<QNetworkInterface> interfaces;
@@ -188,7 +186,7 @@ void UDPServer::leaveMultiCastGroup()
             socketServer->leaveMulticastGroup(groupAddress, interfaces.at(i));
         }
     }
-    //qDebug() << "UDPServer::leaveMultiCastGroup - END"<< endl;
+    //qDebug() << "UDPServer::leaveMultiCastGroup - END"<< QT_ENDL;
 }
 
  bool UDPServer::isStarted()
@@ -198,8 +196,8 @@ void UDPServer::leaveMultiCastGroup()
 
 void UDPServer::parse(const QByteArray &msg)
 {
-    //qDebug() << "UDPServer::parse: " << msg << endl;
-    //qDebug() << "UDPServer::parse: " << QString::fromStdString(msg.toStdString()) << endl;
+    //qDebug() << "UDPServer::parse: " << msg << QT_ENDL;
+    //qDebug() << "UDPServer::parse: " << QString::fromStdString(msg.toStdString()) << QT_ENDL;
     //in >> time_off >> dx_call >> dx_grid >> frequency >> mode >> report_sent >> report_received >>
     //        tx_power >> comments >> name >> time_on >> operatorCall >> de_call >> de_grid >>
     //        exchange_sent >> exchange_received;
@@ -272,29 +270,29 @@ void UDPServer::parse(const QByteArray &msg)
     in >> magic >> schema >> type >> id;
     //QByteArray ba4(QByteArray::fromRawData(cart, 6));
     //in.readRawData(type, size)
-       //qDebug() << "UDPServer::parse: -  Magic = " << QString::number(magic)<< endl;
-       //qDebug() << "UDPServer::parse: - schema = " << QString::number(schema)<< endl;
-       //qDebug() << "UDPServer::parse: -   type = " << QString::number(type)<< endl;
-       //qDebug() << "UDPServer::parse: -   id = " << id << endl;
+       //qDebug() << "UDPServer::parse: -  Magic = " << QString::number(magic)<< QT_ENDL;
+       //qDebug() << "UDPServer::parse: - schema = " << QString::number(schema)<< QT_ENDL;
+       //qDebug() << "UDPServer::parse: -   type = " << QString::number(type)<< QT_ENDL;
+       //qDebug() << "UDPServer::parse: -   id = " << id << QT_ENDL;
 
 
     //if ((magic != 2914831322) || (id != "WSJT-X"))
     if (magic != 2914831322)
     {
-        //qDebug() << "UDPServer::parse: - Magic BAD FORMAT = " << QString::number(magic)<< endl;
+        //qDebug() << "UDPServer::parse: - Magic BAD FORMAT = " << QString::number(magic)<< QT_ENDL;
         return;
     }
 
-    //qDebug() << "UDPServer::parse: TYPE: " << QString::number(type)<< endl;
+    //qDebug() << "UDPServer::parse: TYPE: " << QString::number(type)<< QT_ENDL;
     //QDateTime dateTime, dateTimeOff;
     //QString line;
     switch (type)
     {
         case Heartbeat:
-            //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT/IN - Heartbeat" << endl;
+            //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT/IN - Heartbeat" << QT_ENDL;
         break;
         case Status:
-            //qDebug() << "UDPServer::parse: -   type" << QString::number(type) << " - OUT - Status" << endl;
+            //qDebug() << "UDPServer::parse: -   type" << QString::number(type) << " - OUT - Status" << QT_ENDL;
             // unpack message
             //in >> ch;
 
@@ -308,91 +306,91 @@ void UDPServer::parse(const QByteArray &msg)
                 frequencyDouble = frequencyDouble/1000000; // Change to MHz
                //if (!util->isValidCall(dx_call))
                // {
-               //     //qDebug() << "UDPServer::parse: Status : Call not valid: -" << dx_call << "-" << endl;
+               //     //qDebug() << "UDPServer::parse: Status : Call not valid: -" << dx_call << "-" << QT_ENDL;
                //     return;
                //}
-               //qDebug() << "UDPServer::parse: Status - Freq double = " << QString::number(frequencyDouble)  << endl;
-               //qDebug() << "UDPServer::parse: Status - Mode = " << mode << endl;
-               //qDebug() << "UDPServer::parse: Status - DXCall = " << dx_call << endl;
-               //qDebug() << "UDPServer::parse: Status - Report = " << report << endl;
-               //qDebug() << "UDPServer::parse: Status - Rx DF = " << rx_df << endl;
-               //qDebug() << "UDPServer::parse: Status - Tx DF = " << tx_df << endl;
-               //qDebug() << "UDPServer::parse: Status - De_Call = " << de_call << endl;
-               //qDebug() << "UDPServer::parse: Status - De_Grid = " << de_grid << endl;
-               //qDebug() << "UDPServer::parse: Status - SubMode = " << sub_mode << endl;
-               //qDebug() << "UDPServer::parse: Status - SpecialOp = " << QString::number(specialOpMode) << endl;
-               //qDebug() << "UDPServer::parse: Status - Freq Tol = " << QString::number(freqTolerance) << endl;
-               //qDebug() << "UDPServer::parse: Status - T/R Period = " << QString::number(TRPeriod) << endl;
-               //qDebug() << "UDPServer::parse: Status - Conf Name = " << confName << endl;
+               //qDebug() << "UDPServer::parse: Status - Freq double = " << QString::number(frequencyDouble)  << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - Mode = " << mode << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - DXCall = " << dx_call << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - Report = " << report << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - Rx DF = " << rx_df << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - Tx DF = " << tx_df << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - De_Call = " << de_call << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - De_Grid = " << de_grid << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - SubMode = " << sub_mode << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - SpecialOp = " << QString::number(specialOpMode) << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - Freq Tol = " << QString::number(freqTolerance) << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - T/R Period = " << QString::number(TRPeriod) << QT_ENDL;
+               //qDebug() << "UDPServer::parse: Status - Conf Name = " << confName << QT_ENDL;
 
                 emit status_update (type, dx_call, frequencyDouble, mode, report, de_call, de_grid, dx_grid, sub_mode);
             }
             else
             {
-                //qDebug() << "UDPServer::parse: realtime = FALSE" << endl;
+                //qDebug() << "UDPServer::parse: realtime = FALSE" << QT_ENDL;
             }
         break;
         case Decode:
-            //() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT - Decode" << endl;
+            //() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT - Decode" << QT_ENDL;
             in >> newDecode >> time >> snr >> deltaTime >> drift >> mode >> message >> lowConfidence >> offAir;
 
 
             if (lowConfidence)
             {
-                //qDebug() << "UDPServer::parse: Decode -   Low Confidence" << endl;
+                //qDebug() << "UDPServer::parse: Decode -   Low Confidence" << QT_ENDL;
             }
             else
             {
-                //qDebug() << "UDPServer::parse: Decode -   Time = " << time.toString("hhmmss") << endl;
-                //qDebug() << "UDPServer::parse: Decode -   SNR = " << QString::number(snr) << endl;
-                //qDebug() << "UDPServer::parse: Decode -   Delta = " << QString::number(deltaTime) << endl;
-                //qDebug() << "UDPServer::parse: Decode -   Drift = " << QString::number(drift) << endl;
-                //qDebug() << "UDPServer::parse: Decode -   Mode = " << mode << endl;
-                //qDebug() << "UDPServer::parse: Decode -   Msg = " << message << endl;
+                //qDebug() << "UDPServer::parse: Decode -   Time = " << time.toString("hhmmss") << QT_ENDL;
+                //qDebug() << "UDPServer::parse: Decode -   SNR = " << QString::number(snr) << QT_ENDL;
+                //qDebug() << "UDPServer::parse: Decode -   Delta = " << QString::number(deltaTime) << QT_ENDL;
+                //qDebug() << "UDPServer::parse: Decode -   Drift = " << QString::number(drift) << QT_ENDL;
+                //qDebug() << "UDPServer::parse: Decode -   Mode = " << mode << QT_ENDL;
+                //qDebug() << "UDPServer::parse: Decode -   Msg = " << message << QT_ENDL;
             }
 
         break;
         case Clear:
-            //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT - Clear" << endl;
+            //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT - Clear" << QT_ENDL;
             emit clearSignal();
         break;
         case Reply:
-            //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Replay " << endl;
+            //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Replay " << QT_ENDL;
         break;
         case QSOLogged:
-            //qDebug() << "UDPServer::parse: -   type = QSOLogged "  << endl;
+            //qDebug() << "UDPServer::parse: -   type = QSOLogged "  << QT_ENDL;
 
 
         in >> time_off >> dx_call >> dx_grid >> frequency >> mode >> report_sent >> report_received >>
                     tx_power >> comments >> name >> time_on >> operatorCall >> de_call >> de_grid >>
                     exchange_sent >> exchange_received;
-            //qDebug() << "UDPServer::parse: QSOLogged -   Time_off = " << time_off.toString("yyyyMMdd-hhmmss") << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   DXCall = " << dx_call << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   Grid = " << dx_grid << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   Freq = " << QString::number(frequency) << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   Mode = " << mode << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   ReportSent = " << report_sent << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   ReportReceived = " << report_received << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   TX_PWR = " << tx_power << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   Comments = " << comments << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   Name = " << name << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   Time = " << time_on.toString("yyyyMMdd-hhmmss") << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   DeCall = " << de_call << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   DeGrid = " << de_grid << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   Exch Sent = " << exchange_sent << endl;
-            //qDebug() << "UDPServer::parse: QSOLogged -   Exch Recv = " << exchange_received << endl;
+            //qDebug() << "UDPServer::parse: QSOLogged -   Time_off = " << time_off.toString("yyyyMMdd-hhmmss") << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   DXCall = " << dx_call << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   Grid = " << dx_grid << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   Freq = " << QString::number(frequency) << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   Mode = " << mode << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   ReportSent = " << report_sent << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   ReportReceived = " << report_received << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   TX_PWR = " << tx_power << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   Comments = " << comments << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   Name = " << name << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   Time = " << time_on.toString("yyyyMMdd-hhmmss") << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   DeCall = " << de_call << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   DeGrid = " << de_grid << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   Exch Sent = " << exchange_sent << QT_ENDL;
+            //qDebug() << "UDPServer::parse: QSOLogged -   Exch Recv = " << exchange_received << QT_ENDL;
 
             if (logging)
             {
-                //qDebug() << "UDPServer::parse: logging = true " << endl;
+                //qDebug() << "UDPServer::parse: logging = true " << QT_ENDL;
 
 
-                //qDebug() << "UDPServer::parse: QSO to be logged: Time_on: " << time_on << endl;
-                //qDebug() << "UDPServer::parse: QSO to be logged: Time_off: " << time_off << endl;
+                //qDebug() << "UDPServer::parse: QSO to be logged: Time_on: " << time_on << QT_ENDL;
+                //qDebug() << "UDPServer::parse: QSO to be logged: Time_off: " << time_off << QT_ENDL;
                 frequencyDouble = (double)frequency;
                 frequencyDouble = frequencyDouble/1000000; // Change to MHz
 
-                //qDebug() << "UDPServer::parse: Data to be logged: Comment: " << comments << endl;
+                //qDebug() << "UDPServer::parse: Data to be logged: Comment: " << comments << QT_ENDL;
 
                 //dateTime.setDate(QDate::currentDate());
                 //dateTime.setTime(QTime::fromString(time_on, "hhmmss"));
@@ -407,77 +405,77 @@ void UDPServer::parse(const QByteArray &msg)
             }
             else
             {
-                //qDebug() << "UDPServer::parse: logging = false" << endl;
+                //qDebug() << "UDPServer::parse: logging = false" << QT_ENDL;
             }
 
         break;
         case Close:
-            //qDebug() << "UDPServer::parse: -   type = Close"  << endl;
+            //qDebug() << "UDPServer::parse: -   type = Close"  << QT_ENDL;
             socketServer->close();
-               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT - Close " << endl;
+               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT - Close " << QT_ENDL;
         break;
         case Replay:
-            //qDebug() << "UDPServer::parse: -   type = Reply"  << endl;
-               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Replay" << endl;
+            //qDebug() << "UDPServer::parse: -   type = Reply"  << QT_ENDL;
+               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Replay" << QT_ENDL;
         break;
         case HaltTx:
-            //qDebug() << "UDPServer::parse: -   type = HaltTx"  << endl;
-               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Halt TX" << endl;
+            //qDebug() << "UDPServer::parse: -   type = HaltTx"  << QT_ENDL;
+               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Halt TX" << QT_ENDL;
         break;
         case FreeText:
-            //qDebug() << "UDPServer::parse: -   type = FreeText"  << endl;
-               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Free Text" << endl;
+            //qDebug() << "UDPServer::parse: -   type = FreeText"  << QT_ENDL;
+               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Free Text" << QT_ENDL;
         break;
         case WSPRDecode:
-            //qDebug() << "UDPServer::parse: -   type = WSPRDecode"  << endl;
+            //qDebug() << "UDPServer::parse: -   type = WSPRDecode"  << QT_ENDL;
             in >> newDecode >> time >> snr >> deltaTime >> frequency >> drift >> decodedCall >> decodedGrid >> power >> offAir;
 
-            //qDebug() << "UDPServer::parse: WSPRDecode -   Time = " << time.toString("yyyyMMdd-hhmmss") << endl;
-            //qDebug() << "UDPServer::parse: WSPRDecode -   SNR = " << QString::number(snr) << endl;
-            //qDebug() << "UDPServer::parse: WSPRDecode -   Delta = " << QString::number(deltaTime) << endl;
-            //qDebug() << "UDPServer::parse: WSPRDecode -   Frec = " << QString::number(frequency) << endl;
-            //qDebug() << "UDPServer::parse: WSPRDecode -   Drift = " << QString::number(drift) << endl;
-            //qDebug() << "UDPServer::parse: WSPRDecode -   Call = " << decodedCall << endl;
-            //qDebug() << "UDPServer::parse: WSPRDecode -   Grid = " << decodedGrid << endl;
-            //qDebug() << "UDPServer::parse: WSPRDecode -   Power = " << QString::number(power) << endl;
+            //qDebug() << "UDPServer::parse: WSPRDecode -   Time = " << time.toString("yyyyMMdd-hhmmss") << QT_ENDL;
+            //qDebug() << "UDPServer::parse: WSPRDecode -   SNR = " << QString::number(snr) << QT_ENDL;
+            //qDebug() << "UDPServer::parse: WSPRDecode -   Delta = " << QString::number(deltaTime) << QT_ENDL;
+            //qDebug() << "UDPServer::parse: WSPRDecode -   Frec = " << QString::number(frequency) << QT_ENDL;
+            //qDebug() << "UDPServer::parse: WSPRDecode -   Drift = " << QString::number(drift) << QT_ENDL;
+            //qDebug() << "UDPServer::parse: WSPRDecode -   Call = " << decodedCall << QT_ENDL;
+            //qDebug() << "UDPServer::parse: WSPRDecode -   Grid = " << decodedGrid << QT_ENDL;
+            //qDebug() << "UDPServer::parse: WSPRDecode -   Power = " << QString::number(power) << QT_ENDL;
 
         break;
         case Location:
-            //qDebug() << "UDPServer::parse: -   type = Location"  << endl;
+            //qDebug() << "UDPServer::parse: -   type = Location"  << QT_ENDL;
         break;
         case LoggedADIF:
-            //qDebug() << "UDPServer::parse: -   type = LoggedADIF"  << endl;
-           //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - ADIF" << endl;
-           in >> adifReceived;
-           adifParse(adifReceived);
-            //qDebug() << "UDPServer::parse: ADIF: " << adifReceived << endl;
+           //qDebug() << "UDPServer::parse: -   type = LoggedADIF"  << QT_ENDL;
+           //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - ADIF" << QT_ENDL;
+           //in >> adifReceived;
+           //adifParse(adifReceived);
+            //qDebug() << "UDPServer::parse: ADIF: " << adifReceived << QT_ENDL;
            // Q_SIGNAL void logged_ADIF (QString const& id, QByteArray const& ADIF);
         break;
         case HighlightCallsign:
-            //qDebug() << "UDPServer::parse: -   type = HighlightCallsign"  << endl;
+            //qDebug() << "UDPServer::parse: -   type = HighlightCallsign"  << QT_ENDL;
         break;
         case SwitchConfiguration:
-            //qDebug() << "UDPServer::parse: -   type = SwitchConfiguration"  << endl;
+            //qDebug() << "UDPServer::parse: -   type = SwitchConfiguration"  << QT_ENDL;
         break;
         case Configure:
-            //qDebug() << "UDPServer::parse: -   type = Configure"  << endl;
+            //qDebug() << "UDPServer::parse: -   type = Configure"  << QT_ENDL;
         break;
         default: //NO
-               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - ERROR on Type" << endl;
+               //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - ERROR on Type" << QT_ENDL;
         break;
 
     }
 
 
 
-       //qDebug() << "UDPServer::parse: - Magic: = " << QString::number(magic)<< endl;
+       //qDebug() << "UDPServer::parse: - Magic: = " << QString::number(magic)<< QT_ENDL;
 
 }
 
 
 bool UDPServer::stop()
 {
-    //qDebug() << "UDPServer::stop"<< endl;
+    //qDebug() << "UDPServer::stop"<< QT_ENDL;
     socketServer->close();
     if (socketServer->isValid())
     {
@@ -491,7 +489,7 @@ bool UDPServer::stop()
 
 void UDPServer::setPort(const int _port)
 {
-       //qDebug() << "UDPServer::setPort: " << QString::number(_port) << endl;
+       //qDebug() << "UDPServer::setPort: " << QString::number(_port) << QT_ENDL;
     if ((_port >= 0) && (_port<=65535))
     {
         port = _port;
@@ -500,7 +498,7 @@ void UDPServer::setPort(const int _port)
 
 void UDPServer::setNetworkInterface(const QString &_t)
 {
-    //qDebug() << "UDPServer::setNetworkInterface: " << _t << endl;
+    //qDebug() << "UDPServer::setNetworkInterface: " << _t << QT_ENDL;
     QString testInterface;
     testInterface.clear();
     QList<QNetworkInterface> ifaces;
@@ -511,7 +509,7 @@ void UDPServer::setNetworkInterface(const QString &_t)
         testInterface = i.humanReadableName() + "-" + i.hardwareAddress();
         if (testInterface.contains(_t))
         {
-            //qDebug() << "UDPServer::setNetworkInterface: FOUND! " << testInterface  << endl;
+            //qDebug() << "UDPServer::setNetworkInterface: FOUND! " << testInterface  << QT_ENDL;
             if ((i.flags().testFlag(QNetworkInterface::IsUp)) )
             {
                 networkInterface = i;
@@ -553,7 +551,7 @@ void UDPServer::setRealTimeUpdate(const bool _t)
 
 void UDPServer::adifParse(QByteArray &msg)
 {
-    //qDebug() << "UDPServer::adifParse: " << msg <<  endl;
+    //qDebug() << "UDPServer::adifParse: " << msg <<  QT_ENDL;
 
 
     QString dx_call = QString();
@@ -564,6 +562,10 @@ void UDPServer::adifParse(QByteArray &msg)
     QString rstTX = QString();
     QString rstRX = QString();
     QString _comment = QString();
+    QString _name = QString();
+    QString _exchangeTX = QString();
+    QString _exchangeRX = QString();
+    QString _myPWR = QString();
     QString operatorCall = QString();
     QString stationcallsign = QString();
     double freq = 0.0;
@@ -573,52 +575,55 @@ void UDPServer::adifParse(QByteArray &msg)
     QStringList adifLine;
     adifLine.clear();
     QString line = QString(msg);
+
+
     adifLine << line.split('<');
-    //qDebug() << "UDPServer::adifParse: before the while"  <<  endl;
+    //qDebug() << "UDPServer::adifParse: before the while"  <<  QT_ENDL;
     for (int i = 0; i < adifLine.length() ;i++)
     {
-        //qDebug() << "UDPServer::adifParse: While-1"  <<  endl;
+        //qDebug() << "UDPServer::adifParse: While-1"  <<  QT_ENDL;
         QString type, data;
         QStringList field;
         field.clear();
-        //qDebug() << "UDPServer::adifParse: While-2"  <<  endl;
+        //qDebug() << "UDPServer::adifParse: While-2"  <<  QT_ENDL;
         QString aux = "<" + adifLine.at(i);
-        //qDebug() << "UDPServer::adifParse: While-3"  <<  endl;
+        //qDebug() << "UDPServer::adifParse: While-3"  <<  QT_ENDL;
         field.clear();
         field << util->getValidADIFFieldAndData(aux);
         if (field.length()==2)
         {
-            //qDebug() << "UDPServer::adifParse: While-4"  <<  endl;
+            //qDebug() << "UDPServer::adifParse: While-4"  <<  QT_ENDL;
             type = (field.at(0)).toUpper();
-            //qDebug() << "UDPServer::adifParse: While-5"  <<  endl;
+            //qDebug() << "UDPServer::adifParse: While-5"  <<  QT_ENDL;
             data = field.at(1);
-            //qDebug() << "UDPServer::adifParse: While-6"  <<  endl;
+            //qDebug() << "UDPServer::adifParse: While-6"  <<  QT_ENDL;
             if (type == "CALL")
             {
                dx_call = data;
             }
             else if (type == "GRIDSQUARE")
             {
-                //qDebug() << "UDPServer::adifParse: Rec Grid: " << data <<  endl;
+                //qDebug() << "UDPServer::adifParse: Rec Grid: " << data <<  QT_ENDL;
                 if (util->isValidGrid(data))
                 {
                     dxgrid = data;
-                    //qDebug() << "UDPServer::adifParse: Rec Grid to export: " << dxgrid <<  endl;
+                    //qDebug() << "UDPServer::adifParse: Rec Grid to export: " << dxgrid <<  QT_ENDL;
                 }
                 else {
-                    //qDebug() << "UDPServer::adifParse: INVALID GRID: " << dxgrid <<  endl;
+                    //qDebug() << "UDPServer::adifParse: INVALID GRID: " << dxgrid <<  QT_ENDL;
                 }
             }
             else if (type == "MY_GRIDSQUARE")
             {
-                //qDebug() << "UDPServer::adifParse: Rec mGrid: " << data <<  endl;
+                //qDebug() << "UDPServer::adifParse: Rec mGrid: " << data <<  QT_ENDL;
                 if (util->isValidGrid(data))
                 {
                     mygrid = data;
-                    //qDebug() << "UDPServer::adifParse: Rec mGrid to export: " << mygrid <<  endl;
+                    //qDebug() << "UDPServer::adifParse: Rec mGrid to export: " << mygrid <<  QT_ENDL;
                 }
-                else {
-                    //qDebug() << "UDPServer::adifParse: INVALID mGRID: " << mygrid <<  endl;
+                else
+                {
+                    //qDebug() << "UDPServer::adifParse: INVALID mGRID: " << mygrid <<  QT_ENDL;
                 }
             }
             else if (type == "MODE")
@@ -669,6 +674,10 @@ void UDPServer::adifParse(QByteArray &msg)
             {
               stationcallsign = data;
             }
+            else if (type == "NAME")
+            {
+              stationcallsign = data;
+            }
             else if (type == "EOR")
             {
                 if (_date_on.isValid() && _time_on.isValid())
@@ -689,27 +698,27 @@ void UDPServer::adifParse(QByteArray &msg)
                 {
                     datetime_off = QDateTime();
                 }
-                //qDebug() << "UDPServer::adifParse: Emitting"  <<  endl;
-                /*
+                //qDebug() << "UDPServer::adifParse: Emitting"  <<  QT_ENDL;
+                if ((freq < 0.1) && (band.length ()<2))
+                {
+                    return;
+                }
                 emit logged_qso (dx_call, mode, band, freq,
-                                 mygrid, dxgrid, rstTX, rstRX, _comment, stationcallsign,
-                                 operatorCall, datetime, datetime_off);
-                */
+                                 mygrid, dxgrid, rstTX, rstRX, _comment, stationcallsign, _name,
+                                 operatorCall, datetime, datetime_off, _exchangeTX, _exchangeRX, _myPWR);
+
                 return;
             }
             else
             {
-                //qDebug() << "UDPServer::adifParse: NON captured ADIF type: " << type <<  endl;
-                //qDebug() << "UDPServer::adifParse: NON captured ADIF data: " << data <<  endl;
+                //qDebug() << "UDPServer::adifParse: NON captured ADIF type: " << type <<  QT_ENDL;
+                //qDebug() << "UDPServer::adifParse: NON captured ADIF data: " << data <<  QT_ENDL;
             }
         }
         else
         {
-        //qDebug() << "UDPServer::adifParse: Not a valid ADIF pair " << aux <<  endl;
+        //qDebug() << "UDPServer::adifParse: Not a valid ADIF pair " << aux <<  QT_ENDL;
         }
-
-
     }
-
-    //qDebug() << "UDPServer::adifParse: - END" <<  endl;
+    //qDebug() << "UDPServer::adifParse: - END" <<  QT_ENDL;
 }
