@@ -44,9 +44,10 @@ class Utilities
 public:
     Utilities();
     ~Utilities();
-    void setDarkMode(const QString _dm);
+    void setDarkMode(const QString &_dm);
     bool isDarkMode();
-    bool darkMode;
+    void setCallValidation(const bool _b);
+
     int getProgresStepForDialog(int totalSteps);
     bool trueOrFalse(const QString &_s); // reads a String and return true if s.upper()== TRUE :-)
     QChar boolToCharToSQLite(const bool _b);
@@ -81,6 +82,8 @@ public:
 
     QDate getDefaultDate();
     QString getDefaultRST(const QString &_m);
+    QStringList getDefaultLogFields();
+
     int getNormalizedDXCCValue(const int _dxcc);
 
     // Validations
@@ -93,6 +96,7 @@ public:
     bool isValidModeId(const int _m);
     bool isValidFreq(const QString &_b);
     bool isValidGrid(const QString &_b);
+    bool isValidVUCCGrids(const QString &_b);
     bool isValidRST(const QString &_b);
     bool isValidPower(const QString &_b);
     bool isValidComment(const QString &_b);
@@ -120,6 +124,8 @@ public:
     QTime getTimeFromSQLiteString(const QString &_s);
     QDate getDateFromSQliteString(const QString &_s);
 
+    // Translate the LOG table fields into human readable
+    QString getLogColumnName(const QString &_column);
 
     // Creates the ADIF DATE & TIME formats
     QString getADIFDateFromQDateTime(const QDateTime &_d);  // Will produce the ADIF DATE format: "YYYYMMDD"
@@ -140,13 +146,15 @@ public:
     QString getOnlineServiceName(OnLineProvider _service);
     //QPalette getPalete(bool _ok);
 private:
+    void init();
     bool processConfigLine(const QString &_line);
     QString getKLogDefaultDatabaseFile();
+    bool isCountrySuffix (const QString &_c);
     int isAPrefix(const QString &_c);
     bool isValidSubCall(const QString &_c);
     //QPair<QString, QString> getCallParts(const QString &_c);
 
-
+    bool darkMode;//, callValidation;
     QString dbPath;
     QString softwareVersion;
     //QPalette palRed, palBlack;
