@@ -38,7 +38,9 @@ class AdifLoTWExportWidget : public QWidget
 
 public:
     explicit AdifLoTWExportWidget(DataProxy_SQLite *dp, const QString &_parentFunction, QWidget *parent = nullptr);
+    ~AdifLoTWExportWidget();
     void setExportMode(const ExportMode _EMode);
+    void setLogNumber(const int _logN);
     void setDefaultStationCallsign(const QString &_st);
 
 protected:
@@ -75,6 +77,7 @@ private:
     QTableWidget *tableWidget;
     QHeaderView *hv, *hh;
     ExportMode currentExportMode;
+    int logNumber;
 
     QString defaultStationCallsign;
 
